@@ -60,8 +60,21 @@ enum AstyleOptions {
     AS_MIN_COND_INDENT = 0x20000000,
     AS_INDENT_USES_TABS = 0x40000000,
     AS_DEFAULT = AS_LINUX | AS_BRACKETS_LINUX | AS_INDENT_PREPROCESSORS,
-    AS_ALL_INDENT_OPTIONS = AS_INDENT_CLASS | AS_INDENT_BRACKETS | AS_INDENT_SWITCHES | AS_INDENT_NAMESPACES | AS_INDENT_CASE | AS_INDENT_LABELS | AS_INDENT_BLOCKS | AS_INDENT_PREPROCESSORS | AS_MAX_INSTATEMENT_INDENT | AS_MIN_COND_INDENT,
-    AS_ALL_FORMAT_OPTIONS = AS_BREAK_BLOCKS | AS_PAD_PARENTHESIS | AS_BREAK_BLOCKS_ALL | AS_PAD_PARENTHESIS_OUT | AS_BREAK_ELSEIF | AS_PAD_PARENTHESIS_IN | AS_PAD_OPER | AS_UNPAD_PARENTHESIS | AS_ONE_LINE_KEEP_STATEMENT | AS_FILL_EMPTY_LINES | AS_ONE_LINE_KEEP_BLOCKS,
+    AS_ALL_INDENT_OPTIONS = AS_INDENT_CLASS | AS_INDENT_BRACKETS | AS_INDENT_SWITCHES | AS_INDENT_NAMESPACES |
+                            AS_INDENT_CASE |
+                            AS_INDENT_LABELS |
+                            AS_INDENT_BLOCKS |
+                            AS_INDENT_PREPROCESSORS |
+                            AS_MAX_INSTATEMENT_INDENT |
+                            AS_MIN_COND_INDENT,
+    AS_ALL_FORMAT_OPTIONS = AS_BREAK_BLOCKS | AS_PAD_PARENTHESIS | AS_BREAK_BLOCKS_ALL | AS_PAD_PARENTHESIS_OUT |
+                            AS_BREAK_ELSEIF |
+                            AS_PAD_PARENTHESIS_IN |
+                            AS_PAD_OPER |
+                            AS_UNPAD_PARENTHESIS |
+                            AS_ONE_LINE_KEEP_STATEMENT |
+                            AS_FILL_EMPTY_LINES |
+                            AS_ONE_LINE_KEEP_BLOCKS,
 };
 
 enum FormatterEngine {
@@ -70,29 +83,30 @@ enum FormatterEngine {
 };
 
 enum ClangFormatStyle {
-    kClangFormatLLVM = 0x00000001,
-    kClangFormatGoogle = 0x00000002,
-    kClangFormatWebKit = 0x00000004,
-    kClangFormatChromium = 0x00000008,
-    kClangFormatMozilla = 0x00000010,
-    kAlignEscapedNewlinesLeft = 0x00000020,
-    kAlignTrailingComments = 0x00000040,
-    kAllowAllParametersOfDeclarationOnNextLine = 0x00000080,
-    kAllowShortBlocksOnASingleLine = 0x00000100,
-    kAllowShortLoopsOnASingleLine = 0x00000200,
-    kAllowShortIfStatementsOnASingleLine = 0x00000400,
-    kAlwaysBreakBeforeMultilineStrings = 0x00000800,
-    kAlwaysBreakTemplateDeclarations = 0x00001000,
-    kBinPackParameters = 0x00002000,
-    kBreakBeforeBinaryOperators = 0x00004000,
-    kBreakBeforeTernaryOperators = 0x00008000,
-    kBreakConstructorInitializersBeforeComma = 0x00010000,
-    kIndentCaseLabels = 0x00020000,
-    kIndentFunctionDeclarationAfterType = 0x00040000,
-    kSpaceBeforeAssignmentOperators = 0x00080000,
-    kSpaceBeforeParens = 0x00100000,
-    kSpacesInParentheses = 0x00200000,
-    kAllowShortFunctionsOnASingleLine = 0x00400000,
+    kClangFormatLLVM = (1 << 0),
+    kClangFormatGoogle = (1 << 1),
+    kClangFormatWebKit = (1 << 2),
+    kClangFormatChromium = (1 << 3),
+    kClangFormatMozilla = (1 << 4),
+    kAlignEscapedNewlinesLeft = (1 << 5),
+    kAlignTrailingComments = (1 << 6),
+    kAllowAllParametersOfDeclarationOnNextLine = (1 << 7),
+    kAllowShortBlocksOnASingleLine = (1 << 8),
+    kAllowShortLoopsOnASingleLine = (1 << 9),
+    kAllowShortIfStatementsOnASingleLine = (1 << 10),
+    kAlwaysBreakBeforeMultilineStrings = (1 << 11),
+    kAlwaysBreakTemplateDeclarations = (1 << 12),
+    kBinPackParameters = (1 << 13),
+    kBreakBeforeBinaryOperators = (1 << 14),
+    kBreakBeforeTernaryOperators = (1 << 15),
+    kBreakConstructorInitializersBeforeComma = (1 << 16),
+    kIndentCaseLabels = (1 << 17),
+    kIndentFunctionDeclarationAfterType = (1 << 18),
+    kSpaceBeforeAssignmentOperators = (1 << 19),
+    kSpaceBeforeParens = (1 << 20),
+    kSpacesInParentheses = (1 << 21),
+    kAllowShortFunctionsOnASingleLine = (1 << 22),
+    kPointerAlignmentRight = (1 << 23),
 };
 
 enum ClangBreakBeforeBraceOpt {
@@ -103,6 +117,11 @@ enum ClangBreakBeforeBraceOpt {
     kGNU = 0x00000010,
 };
 
+// Genral options
+enum eCF_GeneralOptions {
+    kCF_AutoFormatOnFileSave = (1 << 0),
+};
+
 class FormatOptions : public SerializedObject
 {
     size_t m_astyleOptions;
@@ -112,6 +131,8 @@ class FormatOptions : public SerializedObject
     FormatterEngine m_engine;
     wxString m_clangFormatExe;
     size_t m_clangColumnLimit; // when indenting, limit the line to fit into a column width
+    size_t m_phpFormatOptions;
+    size_t m_generalFlags;
 
 private:
     wxString ClangFlagToBool(ClangFormatStyle flag) const;
@@ -127,55 +148,34 @@ public:
     virtual ~FormatOptions();
 
     wxString AstyleOptionsAsString() const;
-    wxString ClangFormatOptionsAsString() const;
+    wxString ClangFormatOptionsAsString(const wxFileName& filename) const;
     void Serialize(Archive& arch);
     void DeSerialize(Archive& arch);
 
-    void SetClangColumnLimit(size_t clangColumnLimit) {
-        this->m_clangColumnLimit = clangColumnLimit;
-    }
-    size_t GetClangColumnLimit() const {
-        return m_clangColumnLimit;
-    }
+    void SetClangColumnLimit(size_t clangColumnLimit) { this->m_clangColumnLimit = clangColumnLimit; }
+    size_t GetClangColumnLimit() const { return m_clangColumnLimit; }
 
-    void SetClangFormatExe(const wxString& clangFormatExe) {
-        this->m_clangFormatExe = clangFormatExe;
-    }
-    const wxString& GetClangFormatExe() const {
-        return m_clangFormatExe;
-    }
-    FormatterEngine GetEngine() const {
-        return m_engine;
-    }
+    void SetClangFormatExe(const wxString& clangFormatExe) { this->m_clangFormatExe = clangFormatExe; }
+    const wxString& GetClangFormatExe() const { return m_clangFormatExe; }
+    FormatterEngine GetEngine() const { return m_engine; }
 
-    void SetClangBreakBeforeBrace(size_t clangBreakBeforeBrace) {
+    void SetClangBreakBeforeBrace(size_t clangBreakBeforeBrace)
+    {
         this->m_clangBreakBeforeBrace = clangBreakBeforeBrace;
     }
-    size_t GetClangBreakBeforeBrace() const {
-        return m_clangBreakBeforeBrace;
-    }
-    void SetEngine(FormatterEngine engine) {
-        m_engine = engine;
-    }
+    size_t GetClangBreakBeforeBrace() const { return m_clangBreakBeforeBrace; }
+    void SetEngine(FormatterEngine engine) { m_engine = engine; }
 
-    size_t GetOptions() const {
-        return m_astyleOptions;
-    }
-    void SetOption(size_t options) {
-        m_astyleOptions = options;
-    }
-    void SetCustomFlags(const wxString& customFlags) {
-        this->m_customFlags = customFlags;
-    }
-    const wxString& GetCustomFlags() const {
-        return m_customFlags;
-    }
-    void SetClangFormatOptions(size_t clangFormatOptions) {
-        this->m_clangFormatOptions = clangFormatOptions;
-    }
-    size_t GetClangFormatOptions() const {
-        return m_clangFormatOptions;
-    }
+    size_t GetOptions() const { return m_astyleOptions; }
+    void SetOption(size_t options) { m_astyleOptions = options; }
+    void SetCustomFlags(const wxString& customFlags) { this->m_customFlags = customFlags; }
+    const wxString& GetCustomFlags() const { return m_customFlags; }
+    void SetClangFormatOptions(size_t clangFormatOptions) { this->m_clangFormatOptions = clangFormatOptions; }
+    size_t GetClangFormatOptions() const { return m_clangFormatOptions; }
+    size_t GetPHPFormatterOptions() const { return m_phpFormatOptions; }
+    size_t SetPHPFormatterOptions(size_t options) { m_phpFormatOptions = options; }
+    bool HasFlag(eCF_GeneralOptions flag) const { return m_generalFlags & flag; }
+    void SetFlag(eCF_GeneralOptions flag, bool b) { b ? m_generalFlags |= flag : m_generalFlags &= ~flag; }
 };
 
-#endif //FORMATOPTIONS_H
+#endif // FORMATOPTIONS_H
