@@ -33,19 +33,19 @@
 #include "language.h"
 #include "code_completion_api.h"
 
-wxString TagEntry::KIND_CLASS       = "class";
-wxString TagEntry::KIND_ENUM        = "enum";
-wxString TagEntry::KIND_ENUMERATOR  = "enumerator";
-wxString TagEntry::KIND_FUNCTION    = "function";
-wxString TagEntry::KIND_PROTOTYPE   = "prototype";
-wxString TagEntry::KIND_MEMBER      = "member";
-wxString TagEntry::KIND_NAMESPACE   = "namespace";
-wxString TagEntry::KIND_VARIABLE    = "variable";
-wxString TagEntry::KIND_UNION       = "union";
-wxString TagEntry::KIND_TYPEDEF     = "typedef";
-wxString TagEntry::KIND_MACRO       = "macro";
-wxString TagEntry::KIND_STRUCT      = "struct";
-wxString TagEntry::KIND_FILE        = "file";
+wxString TagEntry::KIND_CLASS = "class";
+wxString TagEntry::KIND_ENUM = "enum";
+wxString TagEntry::KIND_ENUMERATOR = "enumerator";
+wxString TagEntry::KIND_FUNCTION = "function";
+wxString TagEntry::KIND_PROTOTYPE = "prototype";
+wxString TagEntry::KIND_MEMBER = "member";
+wxString TagEntry::KIND_NAMESPACE = "namespace";
+wxString TagEntry::KIND_VARIABLE = "variable";
+wxString TagEntry::KIND_UNION = "union";
+wxString TagEntry::KIND_TYPEDEF = "typedef";
+wxString TagEntry::KIND_MACRO = "macro";
+wxString TagEntry::KIND_STRUCT = "struct";
+wxString TagEntry::KIND_FILE = "file";
 
 TagEntry::TagEntry(const tagEntry& entry)
     : m_isClangTag(false)
@@ -72,14 +72,9 @@ TagEntry::TagEntry()
 {
 }
 
-TagEntry::~TagEntry()
-{
-}
+TagEntry::~TagEntry() {}
 
-TagEntry::TagEntry(const TagEntry& rhs)
-{
-    *this = rhs;
-}
+TagEntry::TagEntry(const TagEntry& rhs) { *this = rhs; }
 
 TagEntry& TagEntry::operator=(const TagEntry& rhs)
 {
@@ -102,99 +97,84 @@ TagEntry& TagEntry::operator=(const TagEntry& rhs)
     // ref counting which may cause crash when sharing wxString among threads
     m_extFields.clear();
     std::map<wxString, wxString>::const_iterator iter = rhs.m_extFields.begin();
-    for ( ; iter != rhs.m_extFields.end(); iter ++ ) {
+    for(; iter != rhs.m_extFields.end(); iter++) {
         m_extFields[iter->first.c_str()] = iter->second.c_str();
     }
     m_comment = rhs.m_comment;
     return *this;
 }
 
-bool TagEntry::operator ==(const TagEntry& rhs)
+bool TagEntry::operator==(const TagEntry& rhs)
 {
-    //Note: tree item id is not used in this function!
-    bool res =
-        m_scope == rhs.m_scope &&
-        m_file == rhs.m_file &&
-        m_kind == rhs.m_kind &&
-        m_parent == rhs.m_parent &&
-        m_pattern == rhs.m_pattern &&
-        m_name == rhs.m_name &&
-        m_path == rhs.m_path &&
-        m_lineNumber == rhs.m_lineNumber &&
-        GetInheritsAsString() == rhs.GetInheritsAsString() &&
-        GetAccess() == rhs.GetAccess() &&
-        GetSignature() == rhs.GetSignature() &&
-        GetTyperef() == rhs.GetTyperef();
+    // Note: tree item id is not used in this function!
+    bool res = m_scope == rhs.m_scope && m_file == rhs.m_file && m_kind == rhs.m_kind && m_parent == rhs.m_parent &&
+               m_pattern == rhs.m_pattern && m_name == rhs.m_name && m_path == rhs.m_path &&
+               m_lineNumber == rhs.m_lineNumber && GetInheritsAsString() == rhs.GetInheritsAsString() &&
+               GetAccess() == rhs.GetAccess() && GetSignature() == rhs.GetSignature() &&
+               GetTyperef() == rhs.GetTyperef();
 
-    bool res2 = m_scope == rhs.m_scope &&
-                m_file == rhs.m_file &&
-                m_kind == rhs.m_kind &&
-                m_parent == rhs.m_parent &&
-                m_pattern == rhs.m_pattern &&
-                m_name == rhs.m_name &&
-                m_path == rhs.m_path &&
-                GetInheritsAsString() == rhs.GetInheritsAsString() &&
-                GetAccess() == rhs.GetAccess() &&
-                GetSignature() == rhs.GetSignature() &&
-                GetTyperef() == rhs.GetTyperef();
+    bool res2 = m_scope == rhs.m_scope && m_file == rhs.m_file && m_kind == rhs.m_kind && m_parent == rhs.m_parent &&
+                m_pattern == rhs.m_pattern && m_name == rhs.m_name && m_path == rhs.m_path &&
+                GetInheritsAsString() == rhs.GetInheritsAsString() && GetAccess() == rhs.GetAccess() &&
+                GetSignature() == rhs.GetSignature() && GetTyperef() == rhs.GetTyperef();
 
-    if (res2 && !res) {
+    if(res2 && !res) {
         // the entries are differs only in the line numbers
         m_differOnByLineNumber = true;
     }
     return res;
 }
 
-void TagEntry::Create(const wxString &fileName,
-                      const wxString &name,
+void TagEntry::Create(const wxString& fileName,
+                      const wxString& name,
                       int lineNumber,
-                      const wxString &pattern,
-                      const wxString &kind,
+                      const wxString& pattern,
+                      const wxString& kind,
                       std::map<wxString, wxString>& extFields)
 {
     m_userData = NULL;
     m_flags = 0;
     m_isClangTag = false;
-    SetName( name );
-    SetLine( lineNumber );
-    SetKind( kind.IsEmpty() ? wxT("<unknown>") : kind );
-    SetPattern( pattern );
-    SetFile( fileName );
+    SetName(name);
+    SetLine(lineNumber);
+    SetKind(kind.IsEmpty() ? wxT("<unknown>") : kind);
+    SetPattern(pattern);
+    SetFile(fileName);
     SetId(-1);
     m_extFields = extFields;
     wxString path;
 
     // Check if we can get full name (including path)
     path = GetExtField(wxT("class"));
-    if (!path.IsEmpty()) {
-        UpdatePath( path ) ;
+    if(!path.IsEmpty()) {
+        UpdatePath(path);
     } else {
         path = GetExtField(wxT("struct"));
-        if (!path.IsEmpty()) {
-            UpdatePath( path ) ;
+        if(!path.IsEmpty()) {
+            UpdatePath(path);
         } else {
             path = GetExtField(wxT("namespace"));
-            if (!path.IsEmpty()) {
-                UpdatePath( path ) ;
+            if(!path.IsEmpty()) {
+                UpdatePath(path);
             } else {
                 path = GetExtField(wxT("interface"));
-                if (!path.IsEmpty()) {
-                    UpdatePath( path ) ;
+                if(!path.IsEmpty()) {
+                    UpdatePath(path);
                 } else {
                     path = GetExtField(wxT("enum"));
-                    if (!path.IsEmpty()) {
-                        UpdatePath( path ) ;
+                    if(!path.IsEmpty()) {
+                        UpdatePath(path);
                     } else {
                         path = GetExtField(wxT("union"));
                         wxString tmpname = path.AfterLast(wxT(':'));
-                        if (!path.IsEmpty()) {
-                            if (!tmpname.StartsWith(wxT("__anon"))) {
-                                UpdatePath( path ) ;
+                        if(!path.IsEmpty()) {
+                            if(!tmpname.StartsWith(wxT("__anon"))) {
+                                UpdatePath(path);
                             } else {
                                 // anonymouse union, remove the anonymous part from its name
                                 path = path.BeforeLast(wxT(':'));
                                 path = path.BeforeLast(wxT(':'));
-                                UpdatePath( path ) ;
+                                UpdatePath(path);
                             }
                         }
                     }
@@ -203,21 +183,20 @@ void TagEntry::Create(const wxString &fileName,
         }
     }
 
-    if (!path.IsEmpty()) {
+    if(!path.IsEmpty()) {
         SetScope(path);
     } else {
         SetScope(wxT("<global>"));
     }
 
     // If there is no path, path is set to name
-    if ( GetPath().IsEmpty() )
-        SetPath( GetName() );
+    if(GetPath().IsEmpty()) SetPath(GetName());
 
     // Get the parent name
     StringTokenizer tok(GetPath(), wxT("::"));
     wxString parent;
 
-    (tok.Count() < 2) ? parent = wxT("<global>") : parent = tok[tok.Count()-2];
+    (tok.Count() < 2) ? parent = wxT("<global>") : parent = tok[tok.Count() - 2];
     SetParent(parent);
 }
 
@@ -225,17 +204,17 @@ void TagEntry::Create(const tagEntry& entry)
 {
     m_isClangTag = false;
     // Get other information from the string data and store it into map
-    for (int i = 0;  i < entry.fields.count;  ++i) {
+    for(int i = 0; i < entry.fields.count; ++i) {
         wxString key = _U(entry.fields.list[i].key);
         wxString value = _U(entry.fields.list[i].value);
         m_extFields[key] = value;
     }
-    Create( _U(entry.file),
-            _U(entry.name),
-            entry.address.lineNumber,
-            _U(entry.address.pattern),
-            _U(entry.kind),
-            m_extFields);
+    Create(_U(entry.file),
+           _U(entry.name),
+           entry.address.lineNumber,
+           _U(entry.address.pattern),
+           _U(entry.kind),
+           m_extFields);
 }
 
 void TagEntry::Print()
@@ -250,7 +229,7 @@ void TagEntry::Print()
 
     std::cout << " ---- Ext fields: ---- " << std::endl;
     std::map<wxString, wxString>::const_iterator iter = m_extFields.begin();
-    for (; iter != m_extFields.end(); iter++)
+    for(; iter != m_extFields.end(); iter++)
         std::cout << iter->first << ":\t\t" << iter->second << std::endl;
     std::cout << "======================================" << std::endl;
 }
@@ -258,7 +237,7 @@ void TagEntry::Print()
 wxString TagEntry::Key() const
 {
     wxString key;
-    if (GetKind() == wxT("prototype") || GetKind() == wxT("macro")) {
+    if(GetKind() == wxT("prototype") || GetKind() == wxT("macro")) {
         key << GetKind() << wxT(": ");
     }
 
@@ -277,7 +256,7 @@ wxString TagEntry::GetFullDisplayName() const
 {
     wxString name;
 
-    if ( GetParent() == wxT("<global>") ) {
+    if(GetParent() == wxT("<global>")) {
         name << GetDisplayName();
     } else {
         name << GetParent() << wxT("::") << GetName() << GetSignature();
@@ -290,10 +269,7 @@ wxString TagEntry::GetFullDisplayName() const
 // Database operations
 //----------------------------------------------------------------------------
 
-wxString TagEntry::GetScopeName() const
-{
-    return GetScope();
-}
+wxString TagEntry::GetScopeName() const { return GetScope(); }
 
 wxString TagEntry::GetKind() const
 {
@@ -302,19 +278,15 @@ wxString TagEntry::GetKind() const
     return kind;
 }
 
-
 const bool TagEntry::IsContainer() const
 {
-    return	GetKind() == wxT("class")  ||
-            GetKind() == wxT("struct") ||
-            GetKind() == wxT("union")  ||
-            GetKind() == wxT("namespace") ||
-            GetKind() == wxT("project");
+    return GetKind() == wxT("class") || GetKind() == wxT("struct") || GetKind() == wxT("union") ||
+           GetKind() == wxT("namespace") || GetKind() == wxT("project");
 }
 
-void TagEntry::UpdatePath(wxString & path)
+void TagEntry::UpdatePath(wxString& path)
 {
-    if (!path.IsEmpty()) {
+    if(!path.IsEmpty()) {
         wxString name(path);
         name += wxT("::");
         name += GetName();
@@ -325,23 +297,23 @@ void TagEntry::UpdatePath(wxString & path)
 wxString TagEntry::TypeFromTyperef() const
 {
     wxString typeref = GetTyperef();
-    if ( typeref.IsEmpty() == false ) {
+    if(typeref.IsEmpty() == false) {
         wxString name = typeref.BeforeFirst(wxT(':'));
         return name;
     }
     return wxEmptyString;
 }
 
-static bool GetMacroArgList(CppScanner &scanner, wxArrayString& argList)
+static bool GetMacroArgList(CppScanner& scanner, wxArrayString& argList)
 {
-    int  depth(0);
-    int  type (0);
-    bool cont (true);
-    bool isOk (false);
+    int depth(0);
+    int type(0);
+    bool cont(true);
+    bool isOk(false);
 
     wxString word;
 
-    while( cont ) {
+    while(cont) {
         type = scanner.yylex();
         if(type == 0) {
             // eof
@@ -349,16 +321,15 @@ static bool GetMacroArgList(CppScanner &scanner, wxArrayString& argList)
         }
 
         switch(type) {
-        case (int)'(':
+        case(int)'(':
             isOk = true;
             depth++;
 
-            if(word.empty() == false)
-                word << wxT("(");
+            if(word.empty() == false) word << wxT("(");
 
             break;
 
-        case (int)')':
+        case(int)')':
             depth--;
             if(depth == 0) {
                 cont = false;
@@ -368,10 +339,10 @@ static bool GetMacroArgList(CppScanner &scanner, wxArrayString& argList)
             }
             break;
 
-        case (int)',':
+        case(int)',':
             word.Trim().Trim(false);
             if(!word.empty()) {
-                argList.Add( word );
+                argList.Add(word);
             }
             word.clear();
             break;
@@ -383,25 +354,25 @@ static bool GetMacroArgList(CppScanner &scanner, wxArrayString& argList)
     }
 
     if(word.empty() == false) {
-        argList.Add( word );
+        argList.Add(word);
     }
 
     return (depth == 0) && isOk;
 }
 
-wxString TagEntry::NameFromTyperef(wxString &templateInitList, bool nameIncludeTemplate)
+wxString TagEntry::NameFromTyperef(wxString& templateInitList, bool nameIncludeTemplate)
 {
     wxString typeref = GetTyperef();
-    if ( typeref.IsEmpty() == false ) {
+    if(typeref.IsEmpty() == false) {
         wxString name = typeref.AfterFirst(wxT(':'));
         return name;
     }
 
     // incase our entry is a typedef, and it is not marked as typeref,
     // try to get the real name from the pattern
-    if ( GetKind() == wxT("typedef")) {
+    if(GetKind() == wxT("typedef")) {
 
-        wxString pat ( GetPattern() );
+        wxString pat(GetPattern());
         if(!GetPattern().Contains(wxT("typedef"))) {
             // The pattern does not contain 'typedef' however this *is* a typedef
             // try to see if this is a macro
@@ -410,7 +381,7 @@ wxString TagEntry::NameFromTyperef(wxString &templateInitList, bool nameIncludeT
 
             // we take the first token
             CppScanner scanner;
-            scanner.SetText( pat.To8BitData() );
+            scanner.SetText(pat.To8BitData());
             int type = scanner.yylex();
             if(type == IDENTIFIER) {
                 wxString token = wxString::From8BitData(scanner.YYText());
@@ -421,28 +392,31 @@ wxString TagEntry::NameFromTyperef(wxString &templateInitList, bool nameIncludeT
                     if(tok.flags & PPToken::IsFunctionLike) {
                         wxArrayString argList;
                         if(GetMacroArgList(scanner, argList)) {
-                            tok.expandOnce( argList );
+                            tok.expandOnce(argList);
                         }
                     }
                     pat = tok.replacement;
                     pat << wxT(";");
 
                     // Remove double spaces
-                    while(pat.Replace(wxT("  "), wxT(" "))) {}
+                    while(pat.Replace(wxT("  "), wxT(" "))) {
+                    }
                 }
             }
         }
 
         wxString name;
-        if (TypedefFromPattern(pat, GetName(),name, templateInitList, nameIncludeTemplate))
-            return name;
+        if(TypedefFromPattern(pat, GetName(), name, templateInitList, nameIncludeTemplate)) return name;
     }
 
-
     return wxEmptyString;
 }
 
-bool TagEntry::TypedefFromPattern(const wxString &tagPattern, const wxString &typedefName, wxString &name, wxString &templateInit, bool nameIncludeTemplate)
+bool TagEntry::TypedefFromPattern(const wxString& tagPattern,
+                                  const wxString& typedefName,
+                                  wxString& name,
+                                  wxString& templateInit,
+                                  bool nameIncludeTemplate)
 {
     wxString pattern(tagPattern);
 
@@ -463,7 +437,7 @@ bool TagEntry::TypedefFromPattern(const wxString &tagPattern, const wxString &ty
             name << wxT("::");
         }
 
-        name         << _U(td.m_realType.m_type.c_str());
+        name << _U(td.m_realType.m_type.c_str());
         return true;
     }
     return false;
@@ -471,8 +445,8 @@ bool TagEntry::TypedefFromPattern(const wxString &tagPattern, const wxString &ty
 
 wxString TagEntry::GetPattern() const
 {
-    wxString pattern ( m_pattern );
-    //since ctags's pattern is regex, forward slashes are escaped. ('/' becomes '\/')
+    wxString pattern(m_pattern);
+    // since ctags's pattern is regex, forward slashes are escaped. ('/' becomes '\/')
     pattern.Replace(wxT("\\\\"), wxT("\\"));
     pattern.Replace(wxT("\\/"), wxT("/"));
     return pattern;
@@ -485,50 +459,50 @@ void TagEntry::FromLine(const wxString& line)
     long lineNumber = wxNOT_FOUND;
     std::map<wxString, wxString> extFields;
 
-    //get the token name
+    // get the token name
     wxString name = strLine.BeforeFirst(wxT('\t'));
-    strLine	= strLine.AfterFirst(wxT('\t'));
+    strLine = strLine.AfterFirst(wxT('\t'));
 
-    //get the file name
+    // get the file name
     wxString fileName = strLine.BeforeFirst(wxT('\t'));
-    strLine	= strLine.AfterFirst(wxT('\t'));
+    strLine = strLine.AfterFirst(wxT('\t'));
 
-    //here we can get two options:
-    //pattern followed by ;"
-    //or
-    //line number followed by ;"
+    // here we can get two options:
+    // pattern followed by ;"
+    // or
+    // line number followed by ;"
     int end = strLine.Find(wxT(";\""));
-    if (end == wxNOT_FOUND) {
-        //invalid pattern found
+    if(end == wxNOT_FOUND) {
+        // invalid pattern found
         return;
     }
 
-    if (strLine.StartsWith(wxT("/^"))) {
-        //regular expression pattern found
+    if(strLine.StartsWith(wxT("/^"))) {
+        // regular expression pattern found
         pattern = strLine.Mid(0, end);
-        strLine	= strLine.Right(strLine.Length() - (end + 2));
+        strLine = strLine.Right(strLine.Length() - (end + 2));
     } else {
-        //line number pattern found, this is usually the case when
-        //dealing with macros in C++
+        // line number pattern found, this is usually the case when
+        // dealing with macros in C++
         pattern = strLine.Mid(0, end);
-        strLine	= strLine.Right(strLine.Length() - (end + 2));
+        strLine = strLine.Right(strLine.Length() - (end + 2));
 
         pattern = pattern.Trim();
         pattern = pattern.Trim(false);
         pattern.ToLong(&lineNumber);
     }
 
-    //next is the kind of the token
-    if (strLine.StartsWith(wxT("\t"))) {
-        strLine	= strLine.AfterFirst(wxT('\t'));
+    // next is the kind of the token
+    if(strLine.StartsWith(wxT("\t"))) {
+        strLine = strLine.AfterFirst(wxT('\t'));
     }
 
     kind = strLine.BeforeFirst(wxT('\t'));
-    strLine	= strLine.AfterFirst(wxT('\t'));
+    strLine = strLine.AfterFirst(wxT('\t'));
 
-    if (strLine.IsEmpty() == false) {
+    if(strLine.IsEmpty() == false) {
         wxStringTokenizer tkz(strLine, wxT('\t'));
-        while (tkz.HasMoreTokens()) {
+        while(tkz.HasMoreTokens()) {
             wxString token = tkz.NextToken();
             wxString key = token.BeforeFirst(wxT(':'));
             wxString val = token.AfterFirst(wxT(':'));
@@ -537,21 +511,21 @@ void TagEntry::FromLine(const wxString& line)
 
             val = val.Trim();
             val = val.Trim(false);
-            if (key == wxT("line") && !val.IsEmpty()) {
+            if(key == wxT("line") && !val.IsEmpty()) {
                 val.ToLong(&lineNumber);
             } else {
-                if (key == wxT("union") || key == wxT("struct")) {
+                if(key == wxT("union") || key == wxT("struct")) {
 
                     // remove the anonymous part of the struct / union
-                    if (!val.StartsWith(wxT("__anon"))) {
+                    if(!val.StartsWith(wxT("__anon"))) {
                         // an internal anonymous union / struct
                         // remove all parts of the
                         wxArrayString scopeArr;
                         wxString tmp, new_val;
 
                         scopeArr = wxStringTokenize(val, wxT(":"), wxTOKEN_STRTOK);
-                        for (size_t i=0; i<scopeArr.GetCount(); i++) {
-                            if (scopeArr.Item(i).StartsWith(wxT("__anon")) == false) {
+                        for(size_t i = 0; i < scopeArr.GetCount(); i++) {
+                            if(scopeArr.Item(i).StartsWith(wxT("__anon")) == false) {
                                 tmp << scopeArr.Item(i) << wxT("::");
                             }
                         }
@@ -571,30 +545,31 @@ void TagEntry::FromLine(const wxString& line)
     fileName = fileName.Trim();
     pattern = pattern.Trim();
 
-    if (kind == wxT("enumerator")) {
+    if(kind == wxT("enumerator")) {
         // enums are specials, they are a scope, when they declared as "enum class ..." (C++11),
         // but not a scope when declared as "enum ...". So, for "enum class ..." declaration
         //(and anonymous enums) we appear enumerators when typed:
         // enumName::
-        //Is global scope there aren't appears. For "enum ..." declaration we appear
-        //enumerators when typed:
+        // Is global scope there aren't appears. For "enum ..." declaration we appear
+        // enumerators when typed:
         // enumName::
-        //and when it global (or same namespace) scope.
-        std::map<wxString,wxString>::iterator enumField = extFields.find(wxT("enum"));
-        if (enumField != extFields.end()) {
+        // and when it global (or same namespace) scope.
+        std::map<wxString, wxString>::iterator enumField = extFields.find(wxT("enum"));
+        if(enumField != extFields.end()) {
             wxString enumName = enumField->second;
             bool isAnonymous = enumName.AfterLast(wxT(':')).StartsWith(wxT("__anon"));
 
             bool isInEnumNamespace = false;
-            std::map<wxString,wxString>::const_iterator isInEnumNamespaceField = extFields.find(wxT("isInEnumNamespace"));
-            if (isInEnumNamespaceField != extFields.end()) {
+            std::map<wxString, wxString>::const_iterator isInEnumNamespaceField =
+                extFields.find(wxT("isInEnumNamespace"));
+            if(isInEnumNamespaceField != extFields.end()) {
                 wxString isInEnumNamespaceValue = isInEnumNamespaceField->second;
                 isInEnumNamespace = isInEnumNamespaceValue.AfterLast(wxT(':')) == wxT("1") ? true : false;
             }
 
-            if (!isInEnumNamespace) {
+            if(!isInEnumNamespace) {
                 enumField->second = enumField->second.BeforeLast(wxT(':')).BeforeLast(wxT(':'));
-                if (!isAnonymous) {
+                if(!isAnonymous) {
                     extFields[wxT("typeref")] = enumName;
                 }
             }
@@ -606,21 +581,18 @@ void TagEntry::FromLine(const wxString& line)
 
 bool TagEntry::IsConstructor() const
 {
-    if(GetKind() != wxT("function") && GetKind() != wxT("prototype"))
-        return false;
+    if(GetKind() != wxT("function") && GetKind() != wxT("prototype")) return false;
 
     return GetName() == GetScope();
 }
 
 bool TagEntry::IsDestructor() const
 {
-    if(GetKind() != wxT("function") && GetKind() != wxT("prototype"))
-        return false;
+    if(GetKind() != wxT("function") && GetKind() != wxT("prototype")) return false;
 
     return GetName().StartsWith(wxT("~"));
 }
 
-
 wxString TagEntry::GetReturnValue() const
 {
     wxString returnValue = GetExtField(_T("returns"));
@@ -629,61 +601,33 @@ wxString TagEntry::GetReturnValue() const
     return returnValue;
 }
 
-bool TagEntry::IsFunction() const
-{
-    return GetKind() == wxT("function");
-}
+bool TagEntry::IsFunction() const { return GetKind() == wxT("function"); }
 
-bool TagEntry::IsMethod() const
-{
-    return IsPrototype() || IsFunction();
-}
+bool TagEntry::IsMethod() const { return IsPrototype() || IsFunction(); }
 
-bool TagEntry::IsPrototype() const
-{
-    return GetKind() == wxT("prototype") ;
-}
+bool TagEntry::IsPrototype() const { return GetKind() == wxT("prototype"); }
 
+bool TagEntry::IsClass() const { return GetKind() == wxT("class"); }
 
-bool TagEntry::IsClass() const
-{
-    return GetKind() == wxT("class");
-}
+bool TagEntry::IsMacro() const { return GetKind() == wxT("macro"); }
 
-bool TagEntry::IsMacro() const
-{
-    return GetKind() == wxT("macro");
-}
+bool TagEntry::IsStruct() const { return GetKind() == wxT("struct"); }
 
-bool TagEntry::IsStruct() const
-{
-    return GetKind() == wxT("struct");
-}
+bool TagEntry::IsScopeGlobal() const { return GetScope().IsEmpty() || GetScope() == wxT("<global>"); }
 
-bool TagEntry::IsScopeGlobal() const
-{
-    return GetScope().IsEmpty() || GetScope() == wxT("<global>");
-}
+bool TagEntry::IsTypedef() const { return GetKind() == wxT("typedef"); }
 
-bool TagEntry::IsTypedef() const
-{
-    return GetKind() == wxT("typedef");
-}
-
-wxString TagEntry::GetInheritsAsString() const
-{
-    return GetExtField(_T("inherits"));
-}
+wxString TagEntry::GetInheritsAsString() const { return GetExtField(_T("inherits")); }
 
 wxArrayString TagEntry::GetInheritsAsArrayNoTemplates() const
 {
     // Parse the input string
-    wxString      inherits = GetInheritsAsString();
-    wxString      parent;
+    wxString inherits = GetInheritsAsString();
+    wxString parent;
     wxArrayString parentsArr;
 
     int depth(0);
-    for(size_t i=0; i<inherits.Length(); i++) {
+    for(size_t i = 0; i < inherits.Length(); i++) {
         wxChar ch = inherits.GetChar(i);
 
         switch(ch) {
@@ -726,12 +670,12 @@ wxArrayString TagEntry::GetInheritsAsArrayNoTemplates() const
 wxArrayString TagEntry::GetInheritsAsArrayWithTemplates() const
 {
     // Parse the input string
-    wxString      inherits = GetInheritsAsString();
-    wxString      parent;
+    wxString inherits = GetInheritsAsString();
+    wxString parent;
     wxArrayString parentsArr;
 
     int depth(0);
-    for(size_t i=0; i<inherits.Length(); i++) {
+    for(size_t i = 0; i < inherits.Length(); i++) {
         wxChar ch = inherits.GetChar(i);
 
         switch(ch) {
@@ -753,7 +697,6 @@ wxArrayString TagEntry::GetInheritsAsArrayWithTemplates() const
 
             } else if(depth != 0) {
                 parent << ch;
-
             }
             break;
 
@@ -773,7 +716,7 @@ wxArrayString TagEntry::GetInheritsAsArrayWithTemplates() const
 TagEntryPtr TagEntry::ReplaceSimpleMacro()
 {
     if(IsMacro()) {
-        PPToken tok = TagsManagerST::Get()->GetDatabase()->GetMacro( GetName() );
+        PPToken tok = TagsManagerST::Get()->GetDatabase()->GetMacro(GetName());
         if(tok.flags & PPToken::IsValid && !(tok.flags & PPToken::IsFunctionLike)) {
             std::vector<TagEntryPtr> tags;
             TagsManagerST::Get()->FindByNameAndScope(tok.replacement, GetScopeName(), tags);
@@ -790,7 +733,28 @@ int TagEntry::CompareDisplayString(const TagEntryPtr& rhs) const
 {
     wxString d1, d2;
 
-    d1 << GetReturnValue()     << wxT(": ") << GetFullDisplayName()     << wxT(":") << GetAccess();
+    d1 << GetReturnValue() << wxT(": ") << GetFullDisplayName() << wxT(":") << GetAccess();
     d2 << rhs->GetReturnValue() << wxT(": ") << rhs->GetFullDisplayName() << wxT(":") << rhs->GetAccess();
     return d1.Cmp(d2);
 }
+
+bool TagEntry::IsTemplateFunction() const 
+{
+    wxString pattern = GetPatternClean();
+    pattern.Trim().Trim(false);
+    return IsMethod() && pattern.StartsWith("template ");
+}
+
+wxString TagEntry::GetPatternClean() const
+{
+    wxString p = GetPattern();
+    p.Trim();
+    if(p.StartsWith(wxT("/^"))) {
+        p.Replace(wxT("/^"), wxT(""));
+    }
+
+    if(p.EndsWith(wxT("$/"))) {
+        p.Replace(wxT("$/"), wxT(""));
+    }
+    return p;
+}
