@@ -34,7 +34,7 @@
 #include "codelite_exports.h"
 
 class TagEntry;
-typedef SmartPtr<TagEntry>       TagEntryPtr;
+typedef SmartPtr<TagEntry> TagEntryPtr;
 typedef std::vector<TagEntryPtr> TagEntryPtrVector_t;
 
 /**
@@ -53,28 +53,28 @@ typedef std::vector<TagEntryPtr> TagEntryPtrVector_t;
  */
 class WXDLLIMPEXP_CL TagEntry
 {
-    wxString                     m_path;		///< Tag full path
-    wxString                     m_file;		///< File this tag is found
-    int                          m_lineNumber;	///< Line number
-    wxString                     m_pattern;		///< A pattern that can be used to locate the tag in the file
-    wxString                     m_kind;		///< Member, function, class, typedef etc.
-    wxString                     m_parent;		///< Direct parent
-    wxTreeItemId                 m_hti;		///< Handle to tree item, not persistent item
-    wxString                     m_name;		///< Tag name (short name, excluding any scope names)
+    wxString m_path;                          ///< Tag full path
+    wxString m_file;                          ///< File this tag is found
+    int m_lineNumber;                         ///< Line number
+    wxString m_pattern;                       ///< A pattern that can be used to locate the tag in the file
+    wxString m_kind;                          ///< Member, function, class, typedef etc.
+    wxString m_parent;                        ///< Direct parent
+    wxTreeItemId m_hti;                       ///< Handle to tree item, not persistent item
+    wxString m_name;                          ///< Tag name (short name, excluding any scope names)
     std::map<wxString, wxString> m_extFields; ///< Additional extension fields
-    long                         m_id;
-    wxString                     m_scope;
-    bool                         m_differOnByLineNumber;
-    bool                         m_isClangTag;
-    void*                        m_userData;   // This member is not saved into the database
-    size_t                       m_flags;      // This member is not saved into the database
-    wxString                     m_comment;    // This member is not saved into the database
+    long m_id;
+    wxString m_scope;
+    bool m_differOnByLineNumber;
+    bool m_isClangTag;
+    void* m_userData;   // This member is not saved into the database
+    size_t m_flags;     // This member is not saved into the database
+    wxString m_comment; // This member is not saved into the database
 public:
     enum {
-        Tag_No_Signature_Format  = 0x00000001, // Do not attempt to format the signature. Use the GetSignature() as is
-        Tag_No_Return_Value_Eval = 0x00000002  // Do not evaluate the return value. Use GetReturnValue() instead
+        Tag_No_Signature_Format = 0x00000001, // Do not attempt to format the signature. Use the GetSignature() as is
+        Tag_No_Return_Value_Eval = 0x00000002 // Do not evaluate the return value. Use GetReturnValue() instead
     };
-    
+
     static wxString KIND_CLASS;
     static wxString KIND_ENUM;
     static wxString KIND_ENUMERATOR;
@@ -88,18 +88,25 @@ public:
     static wxString KIND_MACRO;
     static wxString KIND_STRUCT;
     static wxString KIND_FILE;
-    
+
     // Used by std::for_each to copy elements which are constructors
-    class ForEachCopyIfCtor {
-        TagEntryPtrVector_t &m_matches;
+    class ForEachCopyIfCtor
+    {
+        TagEntryPtrVector_t& m_matches;
+
     public:
-        ForEachCopyIfCtor(TagEntryPtrVector_t &v) : m_matches(v) {}
-        void operator()(TagEntryPtr tag) {
-            if ( tag->IsConstructor() ) {
-                m_matches.push_back( tag );
+        ForEachCopyIfCtor(TagEntryPtrVector_t& v)
+            : m_matches(v)
+        {
+        }
+        void operator()(TagEntryPtr tag)
+        {
+            if(tag->IsConstructor()) {
+                m_matches.push_back(tag);
             }
         }
     };
+
 public:
     /**
      * Construct a TagEntry from tagEntry struct
@@ -107,24 +114,16 @@ public:
      */
     TagEntry(const tagEntry& entry);
 
-    void SetComment(const wxString& comment) {
-        this->m_comment = comment;
-    }
-    const wxString& GetComment() const {
-        return m_comment;
-    }
-    void SetFlags(size_t flags) {
-        this->m_flags = flags;
-    }
-    size_t GetFlags() const {
-        return m_flags;
-    }
+    void SetComment(const wxString& comment) { this->m_comment = comment; }
+    const wxString& GetComment() const { return m_comment; }
+    void SetFlags(size_t flags) { this->m_flags = flags; }
+    size_t GetFlags() const { return m_flags; }
     /**
      * Default constructor.
      */
     TagEntry();
 
-    void FromLine(const wxString &line);
+    void FromLine(const wxString& line);
 
     /**
      * Copy constructor.
@@ -148,7 +147,12 @@ public:
      *	Destructor
      */
     virtual ~TagEntry();
-
+    
+    /**
+     * @brief return if this tag entry is a function tempalte
+     */
+    bool IsTemplateFunction() const;
+    
     /**
      * Construct a TagEntry from tagEntry struct.
      * \param entry Tag entry
@@ -165,20 +169,18 @@ public:
      * \param extFields Map of extenstion fields (key:value)
      * \param project Project name
      */
-    void Create(const wxString &fileName,
-                const wxString &name,
+    void Create(const wxString& fileName,
+                const wxString& name,
                 int lineNumber,
-                const wxString &pattern,
-                const wxString &kind,
+                const wxString& pattern,
+                const wxString& kind,
                 std::map<wxString, wxString>& extFields);
 
     /**
      * Test if this entry has been initialised.
      * \return true if this tag entry has been initialised
      */
-    const bool IsOk() const {
-        return GetKind() != _T("<unknown>");
-    }
+    const bool IsOk() const { return GetKind() != _T("<unknown>"); }
 
     /**
      * Test of this tag is a container (class, union, struct or namespace
@@ -210,109 +212,60 @@ public:
     //------------------------------------------
     // Operations
     //------------------------------------------
-    bool GetDifferOnByLineNumber() const {
-        return m_differOnByLineNumber;
-    }
+    bool GetDifferOnByLineNumber() const { return m_differOnByLineNumber; }
 
-    int GetId() const {
-        return m_id;
-    }
-    void SetId(int id) {
-        m_id = id;
-    }
+    int GetId() const { return m_id; }
+    void SetId(int id) { m_id = id; }
 
-    const wxString& GetName() const {
-        return m_name;
-    }
-    void SetName(const wxString& name) {
-        m_name = name;
-    }
+    const wxString& GetName() const { return m_name; }
+    void SetName(const wxString& name) { m_name = name; }
 
-    const wxString& GetPath() const {
-        return m_path;
-    }
-    void SetPath(const wxString& path) {
-        m_path = path;
-    }
+    const wxString& GetPath() const { return m_path; }
+    void SetPath(const wxString& path) { m_path = path; }
 
-    const wxString& GetFile() const {
-        return m_file;
-    }
-    void SetFile(const wxString& file) {
-        m_file = file;
-    }
+    const wxString& GetFile() const { return m_file; }
+    void SetFile(const wxString& file) { m_file = file; }
 
-    int GetLine() const {
-        return m_lineNumber;
-    }
-    void SetLine(int line) {
-        m_lineNumber = line;
-    }
+    int GetLine() const { return m_lineNumber; }
+    void SetLine(int line) { m_lineNumber = line; }
 
     wxString GetPattern() const;
-    void SetPattern(const wxString& pattern) {
-        m_pattern = pattern;
-    }
+    /**
+     * @brief return the entry pattern without the regex prefix/suffix
+     */
+    wxString GetPatternClean() const;
+    
+    void SetPattern(const wxString& pattern) { m_pattern = pattern; }
 
     wxString GetKind() const;
-    void SetKind(const wxString& kind) {
-        m_kind = kind;
-    }
+    void SetKind(const wxString& kind) { m_kind = kind; }
 
-    const wxString& GetParent() const {
-        return m_parent;
-    }
-    void SetParent(const wxString& parent) {
-        m_parent = parent;
-    }
+    const wxString& GetParent() const { return m_parent; }
+    void SetParent(const wxString& parent) { m_parent = parent; }
 
-    wxTreeItemId& GetTreeItemId() {
-        return m_hti;
-    }
-    void SetTreeItemId(wxTreeItemId& hti) {
-        m_hti = hti;
-    }
+    wxTreeItemId& GetTreeItemId() { return m_hti; }
+    void SetTreeItemId(wxTreeItemId& hti) { m_hti = hti; }
 
-    wxString GetAccess() const {
-        return GetExtField(_T("access"));
-    }
-    void SetAccess(const wxString &access) {
-        m_extFields[wxT("access")] = access;
-    }
+    wxString GetAccess() const { return GetExtField(_T("access")); }
+    void SetAccess(const wxString& access) { m_extFields[wxT("access")] = access; }
 
-    wxString GetSignature() const {
-        return GetExtField(_T("signature"));
-    }
-    void SetSignature(const wxString &sig) {
-        m_extFields[wxT("signature")] = sig;
-    }
+    wxString GetSignature() const { return GetExtField(_T("signature")); }
+    void SetSignature(const wxString& sig) { m_extFields[wxT("signature")] = sig; }
 
-    void SetInherits ( const wxString &inherits ) {
-        m_extFields[_T("inherits")] = inherits;
-    }
-    void SetTyperef  ( const wxString &typeref  ) {
-        m_extFields[_T("typeref")]   = typeref;
-    }
+    void SetInherits(const wxString& inherits) { m_extFields[_T("inherits")] = inherits; }
+    void SetTyperef(const wxString& typeref) { m_extFields[_T("typeref")] = typeref; }
 
-    wxString GetInheritsAsString                  () const;
-    wxArrayString GetInheritsAsArrayNoTemplates   () const;
-    wxArrayString GetInheritsAsArrayWithTemplates () const;
+    wxString GetInheritsAsString() const;
+    wxArrayString GetInheritsAsArrayNoTemplates() const;
+    wxArrayString GetInheritsAsArrayWithTemplates() const;
 
-    wxString GetTyperef() const {
-        return GetExtField(_T("typeref"));
-    }
+    wxString GetTyperef() const { return GetExtField(_T("typeref")); }
 
-    void     SetReturnValue(const wxString &retVal  ) {
-        m_extFields[_T("returns")]   = retVal;
-    }
+    void SetReturnValue(const wxString& retVal) { m_extFields[_T("returns")] = retVal; }
     wxString GetReturnValue() const;
 
-    const wxString &GetScope() const {
-        return m_scope;
-    }
-    void SetScope(const wxString &scope) {
-        m_scope = scope;
-    }
+    const wxString& GetScope() const { return m_scope; }
+    void SetScope(const wxString& scope) { m_scope = scope; }
 
     /**
      * \return Scope name of the tag.
@@ -344,7 +297,7 @@ public:
      * Return the actual name as described in the 'typeref' field
      * \return real name or wxEmptyString
      */
-    wxString NameFromTyperef(wxString &templateInitList, bool nameIncludeTemplate = false);
+    wxString NameFromTyperef(wxString& templateInitList, bool nameIncludeTemplate = false);
 
     /**
      * Return the actual type as described in the 'typeref' field
@@ -354,40 +307,32 @@ public:
     //------------------------------------------
     // Extenstion fields
     //------------------------------------------
-    wxString GetExtField(const wxString& extField) const {
+    wxString GetExtField(const wxString& extField) const
+    {
         std::map<wxString, wxString>::const_iterator iter = m_extFields.find(extField);
-        if(iter == m_extFields.end())
-            return wxEmptyString;
+        if(iter == m_extFields.end()) return wxEmptyString;
         return iter->second;
     }
 
     /**
      * @brief mark this tag has clang generated tag
      */
-    void SetIsClangTag(bool isClangTag) {
-        this->m_isClangTag = isClangTag;
-    }
+    void SetIsClangTag(bool isClangTag) { this->m_isClangTag = isClangTag; }
 
     /**
      * @brief return true if this tag was generated by clang
      */
-    bool GetIsClangTag() const {
-        return m_isClangTag;
-    }
+    bool GetIsClangTag() const { return m_isClangTag; }
     /**
      * @brief set the user data. The user data must live as long as this object is in scope
      * The tag entry class DOES NOT take ownership over the data. it is up to the user to delete
      * it for preventing memory leak.
      */
-    void SetUserData(void* userData) {
-        this->m_userData = userData;
-    }
+    void SetUserData(void* userData) { this->m_userData = userData; }
     /**
      * @brief return the associated user data for this tag entry
      */
-    void* GetUserData() {
-        return m_userData;
-    }
+    void* GetUserData() { return m_userData; }
     //------------------------------------------
     // Misc
     //------------------------------------------
@@ -399,13 +344,18 @@ public:
      * @brief return 0 if the values are the same. < 0 if a < b and > 0 if a > b
      */
     int CompareDisplayString(const TagEntryPtr& rhs) const;
+
 private:
     /**
      * Update the path with full path (e.g. namespace::class)
      * \param path path to add
      */
-    void UpdatePath        (wxString & path);
-    bool TypedefFromPattern(const wxString &tagPattern, const wxString &typedefName, wxString &name, wxString &templateInit, bool nameIncludeTemplate = false);
+    void UpdatePath(wxString& path);
+    bool TypedefFromPattern(const wxString& tagPattern,
+                            const wxString& typedefName,
+                            wxString& name,
+                            wxString& templateInit,
+                            bool nameIncludeTemplate = false);
 };
 
 #endif // CODELITE_ENTRY_H
