@@ -30,6 +30,9 @@
 #include <wx/string.h>
 #include <map>
 #include "codelite_exports.h"
+#include <wx/regex.h>
+#include "smart_ptr.h"
+#include <vector>
 
 class WXDLLIMPEXP_CL FileExtManager
 {
@@ -70,30 +73,71 @@ public:
         TypeWorkspacePHPTags,
         TypeWorkspaceDatabase,
         TypeAsm,
+        TypeJava,
         TypeOther = wxNOT_FOUND
     };
 
+    struct Matcher {
+        SmartPtr<wxRegEx> m_regex;
+        wxString m_exactMatch;
+        FileType m_fileType;
+        
+        Matcher(const wxString& pattern, FileType fileType, bool regex = true)
+            : m_fileType(fileType)
+        {
+            if(regex) {
+                m_regex = new wxRegEx(pattern);
+            } else {
+                m_exactMatch = pattern;
+            }
+        }
+        
+        bool Matches(const wxString &in) const {
+            if(m_regex) {
+                return m_regex->Matches(in);
+            } else {
+                return in.Find(m_exactMatch) != wxNOT_FOUND;
+            }
+        }
+        typedef SmartPtr<Matcher> Ptr_t;
+    };
+
 private:
     static std::map<wxString, FileType> m_map;
+    static std::vector<FileExtManager::Matcher::Ptr_t> m_matchers;
 
 public:
-    static FileType GetType(const wxString &filename, FileExtManager::FileType defaultType = FileExtManager::TypeOther);
+    static FileType GetType(const wxString& filename, FileExtManager::FileType defaultType = FileExtManager::TypeOther);
     static void Init();
 
     /**
      * @brief return true if the file is a C/C++ file
      */
     static bool IsCxxFile(const wxString& filename);
-    static bool IsCxxFile(const wxFileName& filename) {
-        return IsCxxFile(filename.GetFullName());
-    }
+    static bool IsCxxFile(const wxFileName& filename) { return IsCxxFile(filename.GetFullName()); }
 
     /**
      * @brief return true if a file is a JavaScript file
      */
     static bool IsJavascriptFile(const wxString& filename);
-    static bool IsJavascriptFile(const wxFileName& filename) {
-        return IsJavascriptFile(filename.GetFullName());
-    }
+    static bool IsJavascriptFile(const wxFileName& filename) { return IsJavascriptFile(filename.GetFullName()); }
+
+    /**
+     * @param return true if a file is a PHP file
+     */
+    static bool IsPHPFile(const wxString& filename);
+    static bool IsPHPFile(const wxFileName& filename) { return IsPHPFile(filename.GetFullName()); }
+
+    /**
+     * @param return true if a file is a Java file
+     */
+    static bool IsJavaFile(const wxString& filename);
+    static bool IsJavaFile(const wxFileName& filename) { return IsJavaFile(filename.GetFullName()); }
+
+    /**
+     * @brief attempt to autodetect the file type by examining its content
+     */
+    static bool AutoDetectByContent(const wxString& filename, FileExtManager::FileType& fileType);
 };
+
 #endif // __fileextmanager__
