@@ -29,11 +29,12 @@
 #include "tags_options_data.h"
 #include <set>
 #include "cl_config.h"
+#include "ctags_manager.h"
 
 wxString TagsOptionsData::CLANG_CACHE_LAZY = "Lazy";
 wxString TagsOptionsData::CLANG_CACHE_ON_FILE_LOAD = "On File Load";
 
-size_t TagsOptionsData::CURRENT_VERSION = 104;
+size_t TagsOptionsData::CURRENT_VERSION = 105;
 
 static bool _IsValidCppIndetifier(const wxString& id)
 {
@@ -55,76 +56,9 @@ static bool _IsValidCppIndetifier(const wxString& id)
 static bool _IsCppKeyword(const wxString& word)
 {
     static std::set<wxString> words;
-
     if(words.empty()) {
-        words.insert(wxT("auto"));
-        words.insert(wxT("break"));
-        words.insert(wxT("case"));
-        words.insert(wxT("char"));
-        words.insert(wxT("const"));
-        words.insert(wxT("continue"));
-        words.insert(wxT("default"));
-        words.insert(wxT("define"));
-        words.insert(wxT("defined"));
-        words.insert(wxT("do"));
-        words.insert(wxT("double"));
-        words.insert(wxT("elif"));
-        words.insert(wxT("else"));
-        words.insert(wxT("endif"));
-        words.insert(wxT("enum"));
-        words.insert(wxT("error"));
-        words.insert(wxT("extern"));
-        words.insert(wxT("float"));
-        words.insert(wxT("for"));
-        words.insert(wxT("goto"));
-        words.insert(wxT("if"));
-        words.insert(wxT("ifdef"));
-        words.insert(wxT("ifndef"));
-        words.insert(wxT("include"));
-        words.insert(wxT("int"));
-        words.insert(wxT("line"));
-        words.insert(wxT("long"));
-        words.insert(wxT("bool"));
-        words.insert(wxT("pragma"));
-        words.insert(wxT("register"));
-        words.insert(wxT("return"));
-        words.insert(wxT("short"));
-        words.insert(wxT("signed"));
-        words.insert(wxT("sizeof"));
-        words.insert(wxT("static"));
-        words.insert(wxT("struct"));
-        words.insert(wxT("switch"));
-        words.insert(wxT("typedef"));
-        words.insert(wxT("undef"));
-        words.insert(wxT("union"));
-        words.insert(wxT("unsigned"));
-        words.insert(wxT("void"));
-        words.insert(wxT("volatile"));
-        words.insert(wxT("while"));
-        words.insert(wxT("class"));
-        words.insert(wxT("namespace"));
-        words.insert(wxT("delete"));
-        words.insert(wxT("friend"));
-        words.insert(wxT("inline"));
-        words.insert(wxT("new"));
-        words.insert(wxT("operator"));
-        words.insert(wxT("overload"));
-        words.insert(wxT("protected"));
-        words.insert(wxT("private"));
-        words.insert(wxT("public"));
-        words.insert(wxT("this"));
-        words.insert(wxT("virtual"));
-        words.insert(wxT("template"));
-        words.insert(wxT("typename"));
-        words.insert(wxT("dynamic_cast"));
-        words.insert(wxT("static_cast"));
-        words.insert(wxT("const_cast"));
-        words.insert(wxT("reinterpret_cast"));
-        words.insert(wxT("using"));
-        words.insert(wxT("throw"));
-        words.insert(wxT("catch"));
+        TagsManager::GetCXXKeywords(words);
     }
-
     return words.find(word) != words.end();
 }
 
@@ -133,7 +67,7 @@ static bool _IsCppKeyword(const wxString& word)
 TagsOptionsData::TagsOptionsData()
     : clConfigItem("code-completion")
     , m_ccFlags(CC_DISP_FUNC_CALLTIP | CC_CPP_KEYWORD_ASISST | CC_COLOUR_VARS | CC_ACCURATE_SCOPE_RESOLVING |
-                CC_COLOUR_WORKSPACE_TAGS)
+                CC_COLOUR_WORKSPACE_TAGS | CC_DEEP_SCAN_USING_NAMESPACE_RESOLVING | CC_WORD_ASSIST)
     , m_ccColourFlags(CC_COLOUR_DEFAULT)
     , m_fileSpec(wxT("*.cpp;*.cc;*.cxx;*.h;*.hpp;*.c;*.c++;*.tcc;*.hxx;*.h++"))
     , m_minWordLen(3)
@@ -302,16 +236,14 @@ wxString TagsOptionsData::ToString()
                 file_content << iter->first << wxT("=") << iter->second << wxT("\n");
             } else {
 
-                if(options.IsEmpty())
-                    options = wxT(" -I");
+                if(options.IsEmpty()) options = wxT(" -I");
 
                 options << iter->first;
                 options << wxT(",");
             }
         }
 
-        if(options.IsEmpty() == false)
-            options.RemoveLast();
+        if(options.IsEmpty() == false) options.RemoveLast();
 
         options += wxT(" ");
     }
@@ -492,8 +424,7 @@ wxString TagsOptionsData::DoJoinArray(const wxArrayString& arr) const
     for(size_t i = 0; i < arr.GetCount(); ++i)
         s << arr.Item(i) << "\n";
 
-    if(s.IsEmpty() == false)
-        s.RemoveLast();
+    if(s.IsEmpty() == false) s.RemoveLast();
 
     return s;
 }
@@ -505,4 +436,8 @@ void TagsOptionsData::Merge(const TagsOptionsData& tod)
     m_types = conf.MergeArrays(m_types, tod.m_types);
     DoUpdateTokensWxMapReversed();
     DoUpdateTokensWxMap();
+    if(m_version != TagsOptionsData::CURRENT_VERSION) {
+        m_ccFlags |= CC_WORD_ASSIST;
+    }
+    m_version = TagsOptionsData::CURRENT_VERSION;
 }
