@@ -45,7 +45,7 @@
 
 // On Windows lower than XP, the function DebugBreakProcess does not exist
 // so we need to bind it dynamically
-typedef WINBASEAPI BOOL WINAPI ( *DBG_BREAK_PROC_FUNC_PTR )( HANDLE );
+typedef BOOL WINAPI ( *DBG_BREAK_PROC_FUNC_PTR )( HANDLE );
 DBG_BREAK_PROC_FUNC_PTR DebugBreakProcessFunc = NULL;
 HINSTANCE Kernel32Dll = NULL;
 
@@ -1160,6 +1160,7 @@ DbgCmdCLIHandler* DbgGdb::GetCliHandler()
 bool DbgGdb::ListChildren( const wxString& name, int userReason )
 {
     wxString cmd;
+    // use -var-list-children 2 ("--simple-values")
     cmd << wxT( "-var-list-children \"" ) << name << wxT( "\"" );
     return WriteCommand( cmd, new DbgCmdListChildren( m_observer, name, userReason ) );
 }
