@@ -56,41 +56,45 @@ CompilerMainPage::CompilerMainPage(wxWindow* parent)
     // =============-----------------------------
     // Patterns page initialization
     // =============-----------------------------
-    m_listErrPatterns->InsertColumn(0,  _("Pattern"));
-    m_listErrPatterns->InsertColumn(1,  _("File name index"));
-    m_listErrPatterns->InsertColumn(2,  _("Line number index"));
-
-    m_listWarnPatterns->InsertColumn(0,  _("Pattern"));
-    m_listWarnPatterns->InsertColumn(1,  _("File name index"));
-    m_listWarnPatterns->InsertColumn(2,  _("Line number index"));
-
-    m_listWarnPatterns->SetColumnWidth(0, 200);
-    m_listWarnPatterns->SetColumnWidth(1, 50);
-    m_listWarnPatterns->SetColumnWidth(2, 50);
+    m_listErrPatterns->InsertColumn(0, _("Pattern"));
+    m_listErrPatterns->InsertColumn(1, _("File name index"));
+    m_listErrPatterns->InsertColumn(2, _("Line number index"));
+    m_listErrPatterns->InsertColumn(3, _("Column index"));
 
     m_listErrPatterns->SetColumnWidth(0, 200);
     m_listErrPatterns->SetColumnWidth(1, 50);
     m_listErrPatterns->SetColumnWidth(2, 50);
-    
+    m_listErrPatterns->SetColumnWidth(3, 50);
+
+    m_listWarnPatterns->InsertColumn(0, _("Pattern"));
+    m_listWarnPatterns->InsertColumn(1, _("File name index"));
+    m_listWarnPatterns->InsertColumn(2, _("Line number index"));
+    m_listWarnPatterns->InsertColumn(3, _("Column index"));
+
+    m_listWarnPatterns->SetColumnWidth(0, 200);
+    m_listWarnPatterns->SetColumnWidth(1, 50);
+    m_listWarnPatterns->SetColumnWidth(2, 50);
+    m_listWarnPatterns->SetColumnWidth(3, 50);
+
     // ==============------------------
     // Switches
     // ==============------------------
     m_listSwitches->InsertColumn(0, _("Name"));
     m_listSwitches->InsertColumn(1, _("Value"));
-    
+
     // =============----------------------
     // File Types
     // =============----------------------
     m_listCtrlFileTypes->InsertColumn(0, _("Extension"));
     m_listCtrlFileTypes->InsertColumn(1, _("Kind"));
     m_listCtrlFileTypes->InsertColumn(2, _("Compilation Line"));
-    
+
     // =====---------------------------------
     // Compiler options
     // =====---------------------------------
     m_listCompilerOptions->InsertColumn(0, _("Switch"));
     m_listCompilerOptions->InsertColumn(1, _("Help"));
-    
+
     // =====---------------------------------
     // Linker options
     // =====---------------------------------
@@ -98,39 +102,38 @@ CompilerMainPage::CompilerMainPage(wxWindow* parent)
     m_listLinkerOptions->InsertColumn(1, _("Help"));
 }
 
-CompilerMainPage::~CompilerMainPage()
-{
-}
+CompilerMainPage::~CompilerMainPage() {}
 
 void CompilerMainPage::OnBtnAddErrPattern(wxCommandEvent& event)
 {
     CompilerPatternDlg dlg(wxGetTopLevelParent(this), _("Add compiler error pattern"));
-    if (dlg.ShowModal() == wxID_OK) {
-        long item = AppendListCtrlRow( m_listErrPatterns );
+    if(dlg.ShowModal() == wxID_OK) {
+        long item = AppendListCtrlRow(m_listErrPatterns);
         SetColumnText(m_listErrPatterns, item, 0, dlg.GetPattern());
         SetColumnText(m_listErrPatterns, item, 1, dlg.GetFileIndex());
         SetColumnText(m_listErrPatterns, item, 2, dlg.GetLineIndex());
+        SetColumnText(m_listErrPatterns, item, 3, dlg.GetColumnIndex());
         m_isDirty = true;
     }
-
 }
 
 void CompilerMainPage::OnBtnAddWarnPattern(wxCommandEvent& event)
 {
     CompilerPatternDlg dlg(wxGetTopLevelParent(this), _("Add compiler warning pattern"));
-    if (dlg.ShowModal() == wxID_OK) {
+    if(dlg.ShowModal() == wxID_OK) {
         m_isDirty = true;
-        long item = AppendListCtrlRow( m_listWarnPatterns );
+        long item = AppendListCtrlRow(m_listWarnPatterns);
         SetColumnText(m_listWarnPatterns, item, 0, dlg.GetPattern());
         SetColumnText(m_listWarnPatterns, item, 1, dlg.GetFileIndex());
         SetColumnText(m_listWarnPatterns, item, 2, dlg.GetLineIndex());
+        SetColumnText(m_listWarnPatterns, item, 3, dlg.GetColumnIndex());
     }
 }
 
 void CompilerMainPage::OnBtnDelErrPattern(wxCommandEvent& event)
 {
-    int sel =  m_listErrPatterns->GetNextItem(-1, wxLIST_NEXT_ALL, wxLIST_STATE_SELECTED);
-    if (sel == wxNOT_FOUND) {
+    int sel = m_listErrPatterns->GetNextItem(-1, wxLIST_NEXT_ALL, wxLIST_STATE_SELECTED);
+    if(sel == wxNOT_FOUND) {
         return;
     }
     m_listErrPatterns->DeleteItem(sel);
@@ -140,7 +143,7 @@ void CompilerMainPage::OnBtnDelErrPattern(wxCommandEvent& event)
 void CompilerMainPage::OnBtnDelWarnPattern(wxCommandEvent& event)
 {
     int sel = m_listWarnPatterns->GetNextItem(-1, wxLIST_NEXT_ALL, wxLIST_STATE_SELECTED);
-    if (sel == wxNOT_FOUND) {
+    if(sel == wxNOT_FOUND) {
         return;
     }
     m_listWarnPatterns->DeleteItem(sel);
@@ -150,7 +153,7 @@ void CompilerMainPage::OnBtnDelWarnPattern(wxCommandEvent& event)
 void CompilerMainPage::OnBtnUpdateErrPattern(wxCommandEvent& event)
 {
     int sel = m_listErrPatterns->GetNextItem(-1, wxLIST_NEXT_ALL, wxLIST_STATE_SELECTED);
-    if (sel == wxNOT_FOUND) {
+    if(sel == wxNOT_FOUND) {
         return;
     }
     DoUpdateErrPattern(sel);
@@ -160,7 +163,7 @@ void CompilerMainPage::OnBtnUpdateErrPattern(wxCommandEvent& event)
 void CompilerMainPage::OnBtnUpdateWarnPattern(wxCommandEvent& event)
 {
     int sel = m_listWarnPatterns->GetNextItem(-1, wxLIST_NEXT_ALL, wxLIST_STATE_SELECTED);
-    if (sel == wxNOT_FOUND) {
+    if(sel == wxNOT_FOUND) {
         return;
     }
     DoUpdateWarnPattern(sel);
@@ -169,14 +172,14 @@ void CompilerMainPage::OnBtnUpdateWarnPattern(wxCommandEvent& event)
 
 void CompilerMainPage::OnCompilerOptionActivated(wxListEvent& event)
 {
-    if (m_selectedCmpOption == wxNOT_FOUND) {
+    if(m_selectedCmpOption == wxNOT_FOUND) {
         return;
     }
 
     wxString name = m_listCompilerOptions->GetItemText(m_selectedCmpOption);
     wxString help = GetColumnText(m_listCompilerOptions, m_selectedCmpOption, 1);
     CompilerCompilerOptionDialog dlg(wxGetTopLevelParent(this), name, help);
-    if (dlg.ShowModal() == wxID_OK) {
+    if(dlg.ShowModal() == wxID_OK) {
         SetColumnText(m_listCompilerOptions, m_selectedCmpOption, 0, dlg.GetName());
         SetColumnText(m_listCompilerOptions, m_selectedCmpOption, 1, dlg.GetHelp());
         m_listCompilerOptions->SetColumnWidth(1, wxLIST_AUTOSIZE);
@@ -202,22 +205,24 @@ void CompilerMainPage::OnCustomEditorButtonClicked(wxCommandEvent& event)
 {
     wxPGProperty* prop = m_pgMgrTools->GetSelectedProperty();
     CHECK_PTR_RET(prop);
-    
+
     wxString oldValue = prop->GetValueAsString();
     wxFileName fn(oldValue);
-    
+
     wxString newPath = ::wxFileSelector(_("Select a file"), fn.GetPath());
-    if ( !newPath.IsEmpty() ) {
-        ::WrapWithQuotes( newPath );
-        prop->SetValueFromString( newPath );
+    if(!newPath.IsEmpty()) {
+        ::WrapWithQuotes(newPath);
+        prop->SetValueFromString(newPath);
     }
     m_isDirty = true;
 }
 
 void CompilerMainPage::OnDeleteCompilerOption(wxCommandEvent& event)
 {
-    if (m_selectedCmpOption != wxNOT_FOUND) {
-        if (wxMessageBox(_("Are you sure you want to delete this compiler option?"), _("CodeLite"), wxYES_NO|wxCANCEL) == wxYES) {
+    if(m_selectedCmpOption != wxNOT_FOUND) {
+        if(wxMessageBox(_("Are you sure you want to delete this compiler option?"),
+                        _("CodeLite"),
+                        wxYES_NO | wxCANCEL) == wxYES) {
             m_listCompilerOptions->DeleteItem(m_selectedCmpOption);
             m_listCompilerOptions->SetColumnWidth(1, wxLIST_AUTOSIZE);
             m_selectedCmpOption = wxNOT_FOUND;
@@ -228,8 +233,9 @@ void CompilerMainPage::OnDeleteCompilerOption(wxCommandEvent& event)
 
 void CompilerMainPage::OnDeleteFileType(wxCommandEvent& event)
 {
-    if (m_selectedFileType != wxNOT_FOUND) {
-        if (wxMessageBox(_("Are you sure you want to delete this file type?"), _("CodeLite"), wxYES_NO|wxCANCEL) == wxYES) {
+    if(m_selectedFileType != wxNOT_FOUND) {
+        if(wxMessageBox(_("Are you sure you want to delete this file type?"), _("CodeLite"), wxYES_NO | wxCANCEL) ==
+           wxYES) {
             m_listCtrlFileTypes->DeleteItem(m_selectedFileType);
             m_selectedFileType = wxNOT_FOUND;
             m_isDirty = true;
@@ -239,8 +245,9 @@ void CompilerMainPage::OnDeleteFileType(wxCommandEvent& event)
 
 void CompilerMainPage::OnDeleteLinkerOption(wxCommandEvent& event)
 {
-    if (m_selectedLnkOption != wxNOT_FOUND) {
-        if (wxMessageBox(_("Are you sure you want to delete this linker option?"), _("CodeLite"), wxYES_NO|wxCANCEL) == wxYES) {
+    if(m_selectedLnkOption != wxNOT_FOUND) {
+        if(wxMessageBox(_("Are you sure you want to delete this linker option?"), _("CodeLite"), wxYES_NO | wxCANCEL) ==
+           wxYES) {
             m_isDirty = true;
             m_listLinkerOptions->DeleteItem(m_selectedLnkOption);
             m_listLinkerOptions->SetColumnWidth(1, wxLIST_AUTOSIZE);
@@ -252,26 +259,26 @@ void CompilerMainPage::OnDeleteLinkerOption(wxCommandEvent& event)
 void CompilerMainPage::OnEditIncludePaths(wxCommandEvent& event)
 {
     wxString curIncludePath = m_textCtrlGlobalIncludePath->GetValue();
-    curIncludePath = wxJoin( ::wxStringTokenize(curIncludePath, ";", wxTOKEN_STRTOK), '\n', '\0' );
+    curIncludePath = wxJoin(::wxStringTokenize(curIncludePath, ";", wxTOKEN_STRTOK), '\n', '\0');
     wxString newIncludePath = ::clGetTextFromUser(curIncludePath, EventNotifier::Get()->TopFrame());
     newIncludePath.Trim().Trim(false);
-    if ( !newIncludePath.IsEmpty() ) {
+    if(!newIncludePath.IsEmpty()) {
         m_isDirty = true;
-        newIncludePath = wxJoin( ::wxStringTokenize(newIncludePath, "\n\r", wxTOKEN_STRTOK), ';', '\0' );
-        m_textCtrlGlobalIncludePath->ChangeValue( newIncludePath );
+        newIncludePath = wxJoin(::wxStringTokenize(newIncludePath, "\n\r", wxTOKEN_STRTOK), ';', '\0');
+        m_textCtrlGlobalIncludePath->ChangeValue(newIncludePath);
     }
 }
 
 void CompilerMainPage::OnEditLibraryPaths(wxCommandEvent& event)
 {
     wxString curLibPath = m_textCtrlGlobalLibPath->GetValue();
-    curLibPath = wxJoin( ::wxStringTokenize(curLibPath, ";", wxTOKEN_STRTOK), '\n', '\0' );
+    curLibPath = wxJoin(::wxStringTokenize(curLibPath, ";", wxTOKEN_STRTOK), '\n', '\0');
     wxString newLibPath = ::clGetTextFromUser(curLibPath, EventNotifier::Get()->TopFrame());
     newLibPath.Trim().Trim(false);
-    if ( !newLibPath.IsEmpty() ) {
+    if(!newLibPath.IsEmpty()) {
         m_isDirty = true;
-        newLibPath = wxJoin( ::wxStringTokenize(newLibPath, "\n\r", wxTOKEN_STRTOK), ';', '\0' );
-        m_textCtrlGlobalLibPath->ChangeValue( newLibPath );
+        newLibPath = wxJoin(::wxStringTokenize(newLibPath, "\n\r", wxTOKEN_STRTOK), ';', '\0');
+        m_textCtrlGlobalLibPath->ChangeValue(newLibPath);
     }
 }
 
@@ -292,12 +299,14 @@ void CompilerMainPage::DoUpdateWarnPattern(long item)
     wxString pattern = GetColumnText(m_listWarnPatterns, item, 0);
     wxString fileIdx = GetColumnText(m_listWarnPatterns, item, 1);
     wxString lineIdx = GetColumnText(m_listWarnPatterns, item, 2);
+    wxString colIdx = GetColumnText(m_listWarnPatterns, item, 3);
     CompilerPatternDlg dlg(wxGetTopLevelParent(this), _("Update compiler warning pattern"));
-    dlg.SetPattern(pattern, lineIdx, fileIdx);
-    if (dlg.ShowModal() == wxID_OK) {
-        SetColumnText(m_listWarnPatterns, item, 0,  dlg.GetPattern());
+    dlg.SetPattern(pattern, lineIdx, fileIdx, colIdx);
+    if(dlg.ShowModal() == wxID_OK) {
+        SetColumnText(m_listWarnPatterns, item, 0, dlg.GetPattern());
         SetColumnText(m_listWarnPatterns, item, 1, dlg.GetFileIndex());
         SetColumnText(m_listWarnPatterns, item, 2, dlg.GetLineIndex());
+        SetColumnText(m_listWarnPatterns, item, 3, dlg.GetColumnIndex());
     }
 }
 
@@ -306,24 +315,26 @@ void CompilerMainPage::DoUpdateErrPattern(long item)
     wxString pattern = GetColumnText(m_listErrPatterns, item, 0);
     wxString fileIdx = GetColumnText(m_listErrPatterns, item, 1);
     wxString lineIdx = GetColumnText(m_listErrPatterns, item, 2);
+    wxString colIdx = GetColumnText(m_listErrPatterns, item, 3);
     CompilerPatternDlg dlg(wxGetTopLevelParent(this), _("Update compiler error pattern"));
-    dlg.SetPattern(pattern, lineIdx, fileIdx);
-    if (dlg.ShowModal() == wxID_OK) {
-        SetColumnText(m_listErrPatterns, item, 0,  dlg.GetPattern());
+    dlg.SetPattern(pattern, lineIdx, fileIdx, colIdx);
+    if(dlg.ShowModal() == wxID_OK) {
+        SetColumnText(m_listErrPatterns, item, 0, dlg.GetPattern());
         SetColumnText(m_listErrPatterns, item, 1, dlg.GetFileIndex());
         SetColumnText(m_listErrPatterns, item, 2, dlg.GetLineIndex());
+        SetColumnText(m_listErrPatterns, item, 3, dlg.GetColumnIndex());
     }
 }
 
 void CompilerMainPage::OnFileTypeActivated(wxListEvent& event)
 {
-    if (m_selectedFileType != wxNOT_FOUND) {
+    if(m_selectedFileType != wxNOT_FOUND) {
         EditCmpFileInfo dlg(wxGetTopLevelParent(this));
         dlg.SetCompilationLine(GetColumnText(m_listCtrlFileTypes, m_selectedFileType, 2));
         dlg.SetExtension(GetColumnText(m_listCtrlFileTypes, m_selectedFileType, 0));
         dlg.SetKind(GetColumnText(m_listCtrlFileTypes, m_selectedFileType, 1));
 
-        if (dlg.ShowModal() == wxID_OK) {
+        if(dlg.ShowModal() == wxID_OK) {
             SetColumnText(m_listCtrlFileTypes, m_selectedFileType, 2, dlg.GetCompilationLine());
             SetColumnText(m_listCtrlFileTypes, m_selectedFileType, 0, dlg.GetExtension().Lower());
             SetColumnText(m_listCtrlFileTypes, m_selectedFileType, 1, dlg.GetKind());
@@ -350,18 +361,18 @@ void CompilerMainPage::OnFileTypeSelected(wxListEvent& event)
 void CompilerMainPage::OnItemActivated(wxListEvent& event)
 {
     m_isDirty = true;
-    //get the var name & value
+    // get the var name & value
     wxListItem info;
     info.m_itemId = event.m_itemIndex;
-    info.m_col = 0;	//name
+    info.m_col = 0; // name
     info.m_mask = wxLIST_MASK_TEXT;
 
-    if ( m_listSwitches->GetItem(info) ) {
+    if(m_listSwitches->GetItem(info)) {
         m_selSwitchName = info.m_text;
     }
 
-    info.m_col = 1;//value
-    if ( m_listSwitches->GetItem(info)) {
+    info.m_col = 1; // value
+    if(m_listSwitches->GetItem(info)) {
         m_selSwitchValue = info.m_text;
     }
     EditSwitch();
@@ -370,32 +381,32 @@ void CompilerMainPage::OnItemActivated(wxListEvent& event)
 void CompilerMainPage::OnItemSelected(wxListEvent& event)
 {
     m_isDirty = true;
-    //get the var name & value
+    // get the var name & value
     wxListItem info;
     info.m_itemId = event.m_itemIndex;
-    info.m_col = 0;	//name
+    info.m_col = 0; // name
     info.m_mask = wxLIST_MASK_TEXT;
 
-    if ( m_listSwitches->GetItem(info) ) {
+    if(m_listSwitches->GetItem(info)) {
         m_selSwitchName = info.m_text;
     }
 
-    info.m_col = 1;//value
-    if ( m_listSwitches->GetItem(info)) {
+    info.m_col = 1; // value
+    if(m_listSwitches->GetItem(info)) {
         m_selSwitchValue = info.m_text;
     }
 }
 
 void CompilerMainPage::OnLinkerOptionActivated(wxListEvent& event)
 {
-    if (m_selectedLnkOption == wxNOT_FOUND) {
+    if(m_selectedLnkOption == wxNOT_FOUND) {
         return;
     }
 
     wxString name = m_listLinkerOptions->GetItemText(m_selectedLnkOption);
     wxString help = GetColumnText(m_listLinkerOptions, m_selectedLnkOption, 1);
     CompilerLinkerOptionDialog dlg(wxGetTopLevelParent(this), name, help);
-    if (dlg.ShowModal() == wxID_OK) {
+    if(dlg.ShowModal() == wxID_OK) {
         m_isDirty = true;
         SetColumnText(m_listLinkerOptions, m_selectedLnkOption, 0, dlg.GetName());
         SetColumnText(m_listLinkerOptions, m_selectedLnkOption, 1, dlg.GetHelp());
@@ -420,7 +431,7 @@ void CompilerMainPage::OnLinkerOptionSelected(wxListEvent& event)
 void CompilerMainPage::OnNewCompilerOption(wxCommandEvent& event)
 {
     CompilerCompilerOptionDialog dlg(wxGetTopLevelParent(this), wxEmptyString, wxEmptyString);
-    if (dlg.ShowModal() == wxID_OK) {
+    if(dlg.ShowModal() == wxID_OK) {
         long idx = m_listCompilerOptions->InsertItem(m_listCompilerOptions->GetItemCount(), dlg.GetName());
         m_listCompilerOptions->SetItem(idx, 1, dlg.GetHelp());
         m_listCompilerOptions->SetColumnWidth(1, wxLIST_AUTOSIZE);
@@ -430,8 +441,8 @@ void CompilerMainPage::OnNewCompilerOption(wxCommandEvent& event)
 
 void CompilerMainPage::OnNewFileType(wxCommandEvent& event)
 {
-    EditCmpFileInfo dlg( wxGetTopLevelParent(this) );
-    if (dlg.ShowModal() == wxID_OK) {
+    EditCmpFileInfo dlg(wxGetTopLevelParent(this));
+    if(dlg.ShowModal() == wxID_OK) {
         long newItem = AppendListCtrlRow(m_listCtrlFileTypes);
         SetColumnText(m_listCtrlFileTypes, newItem, 2, dlg.GetCompilationLine());
         SetColumnText(m_listCtrlFileTypes, newItem, 0, dlg.GetExtension().Lower());
@@ -443,13 +454,12 @@ void CompilerMainPage::OnNewFileType(wxCommandEvent& event)
 void CompilerMainPage::OnNewLinkerOption(wxCommandEvent& event)
 {
     CompilerLinkerOptionDialog dlg(wxGetTopLevelParent(this), wxEmptyString, wxEmptyString);
-    if (dlg.ShowModal() == wxID_OK) {
+    if(dlg.ShowModal() == wxID_OK) {
         m_isDirty = true;
         long idx = m_listLinkerOptions->InsertItem(m_listLinkerOptions->GetItemCount(), dlg.GetName());
         m_listLinkerOptions->SetItem(idx, 1, dlg.GetHelp());
         m_listLinkerOptions->SetColumnWidth(1, wxLIST_AUTOSIZE);
     }
-
 }
 
 void CompilerMainPage::OnWarnItemActivated(wxListEvent& event)
@@ -475,26 +485,28 @@ void CompilerMainPage::InitializePatterns()
 
     const Compiler::CmpListInfoPattern& errPatterns = m_compiler->GetErrPatterns();
     Compiler::CmpListInfoPattern::const_iterator itPattern;
-    for (itPattern = errPatterns.begin(); itPattern != errPatterns.end(); ++itPattern) {
+    for(itPattern = errPatterns.begin(); itPattern != errPatterns.end(); ++itPattern) {
         long item = AppendListCtrlRow(m_listErrPatterns);
-        SetColumnText(m_listErrPatterns, item, 0,  itPattern->pattern);
+        SetColumnText(m_listErrPatterns, item, 0, itPattern->pattern);
         SetColumnText(m_listErrPatterns, item, 1, itPattern->fileNameIndex);
         SetColumnText(m_listErrPatterns, item, 2, itPattern->lineNumberIndex);
+        SetColumnText(m_listErrPatterns, item, 3, itPattern->columnIndex);
     }
 
     const Compiler::CmpListInfoPattern& warnPatterns = m_compiler->GetWarnPatterns();
-    for (itPattern = warnPatterns.begin(); itPattern != warnPatterns.end(); ++itPattern) {
+    for(itPattern = warnPatterns.begin(); itPattern != warnPatterns.end(); ++itPattern) {
         long item = AppendListCtrlRow(m_listWarnPatterns);
-        SetColumnText(m_listWarnPatterns, item, 0,  itPattern->pattern);
+        SetColumnText(m_listWarnPatterns, item, 0, itPattern->pattern);
         SetColumnText(m_listWarnPatterns, item, 1, itPattern->fileNameIndex);
         SetColumnText(m_listWarnPatterns, item, 2, itPattern->lineNumberIndex);
+        SetColumnText(m_listWarnPatterns, item, 3, itPattern->columnIndex);
     }
 }
 
 void CompilerMainPage::LoadCompiler(const wxString& compilerName)
 {
     // Save before we switch
-    if ( m_isDirty ) {
+    if(m_isDirty) {
         Save();
     }
     m_compiler = BuildSettingsConfigST::Get()->GetCompiler(compilerName);
@@ -507,21 +519,23 @@ void CompilerMainPage::SavePatterns()
 {
     CHECK_PTR_RET(m_compiler);
     Compiler::CmpListInfoPattern errPatterns;
-    for (int i = 0; i < m_listErrPatterns->GetItemCount(); ++i) {
+    for(int i = 0; i < m_listErrPatterns->GetItemCount(); ++i) {
         Compiler::CmpInfoPattern infoPattern;
-        infoPattern.pattern         = GetColumnText(m_listErrPatterns, i, 0);
-        infoPattern.fileNameIndex   = GetColumnText(m_listErrPatterns, i, 1);
+        infoPattern.pattern = GetColumnText(m_listErrPatterns, i, 0);
+        infoPattern.fileNameIndex = GetColumnText(m_listErrPatterns, i, 1);
         infoPattern.lineNumberIndex = GetColumnText(m_listErrPatterns, i, 2);
+        infoPattern.columnIndex = GetColumnText(m_listErrPatterns, i, 3);
         errPatterns.push_back(infoPattern);
     }
     m_compiler->SetErrPatterns(errPatterns);
 
     Compiler::CmpListInfoPattern warnPatterns;
-    for (int i = 0; i < m_listWarnPatterns->GetItemCount(); ++i) {
+    for(int i = 0; i < m_listWarnPatterns->GetItemCount(); ++i) {
         Compiler::CmpInfoPattern infoPattern;
-        infoPattern.pattern         = GetColumnText(m_listWarnPatterns, i, 0);
-        infoPattern.fileNameIndex   = GetColumnText(m_listWarnPatterns, i, 1);
+        infoPattern.pattern = GetColumnText(m_listWarnPatterns, i, 0);
+        infoPattern.fileNameIndex = GetColumnText(m_listWarnPatterns, i, 1);
         infoPattern.lineNumberIndex = GetColumnText(m_listWarnPatterns, i, 2);
+        infoPattern.columnIndex = GetColumnText(m_listWarnPatterns, i, 3);
         warnPatterns.push_back(infoPattern);
     }
     m_compiler->SetWarnPatterns(warnPatterns);
@@ -531,38 +545,38 @@ void CompilerMainPage::InitializeTools()
 {
     // Clear the values
     wxPropertyGridConstIterator iter = m_pgMgrTools->GetGrid()->GetIterator();
-    for ( ; !iter.AtEnd(); ++iter ) {
-        wxPGProperty *prop = iter.GetProperty();
+    for(; !iter.AtEnd(); ++iter) {
+        wxPGProperty* prop = iter.GetProperty();
         prop->SetValue("");
     }
-    
+
     CHECK_PTR_RET(m_compiler);
-    
-    m_pgPropCXX->SetValue( m_compiler->GetTool(wxT("CXX")) );
-    m_pgPropCC->SetValue( m_compiler->GetTool(wxT("CC")) );
-    m_pgPropAR->SetValue( m_compiler->GetTool(wxT("AR")) );
-    m_pgPropLD->SetValue( m_compiler->GetTool("LinkerName") );
-    m_pgPropSharedObjectLD->SetValue( m_compiler->GetTool("SharedObjectLinkerName"));
+
+    m_pgPropCXX->SetValue(m_compiler->GetTool(wxT("CXX")));
+    m_pgPropCC->SetValue(m_compiler->GetTool(wxT("CC")));
+    m_pgPropAR->SetValue(m_compiler->GetTool(wxT("AR")));
+    m_pgPropLD->SetValue(m_compiler->GetTool("LinkerName"));
+    m_pgPropSharedObjectLD->SetValue(m_compiler->GetTool("SharedObjectLinkerName"));
     m_pgPropAS->SetValue(m_compiler->GetTool("AS"));
     m_pgPropMAKE->SetValue(m_compiler->GetTool("MAKE"));
     m_pgPropResourceCompiler->SetValue(m_compiler->GetTool("ResourceCompiler"));
-    m_pgPropMkdir->SetValue( m_compiler->GetTool("MakeDirCommand") );
-    m_pgPropDebugger->SetValue( m_compiler->GetTool("Debugger") );
+    m_pgPropMkdir->SetValue(m_compiler->GetTool("MakeDirCommand"));
+    m_pgPropDebugger->SetValue(m_compiler->GetTool("Debugger"));
 }
 
 void CompilerMainPage::SaveTools()
 {
     CHECK_PTR_RET(m_compiler);
-    m_compiler->SetTool(wxT("CXX"),                    m_pgPropCXX->GetValueAsString());
-    m_compiler->SetTool(wxT("CC"),                     m_pgPropCC->GetValueAsString());
-    m_compiler->SetTool(wxT("AR"),                     m_pgPropAR->GetValueAsString());
-    m_compiler->SetTool(wxT("LinkerName"),             m_pgPropLD->GetValueAsString());
+    m_compiler->SetTool(wxT("CXX"), m_pgPropCXX->GetValueAsString());
+    m_compiler->SetTool(wxT("CC"), m_pgPropCC->GetValueAsString());
+    m_compiler->SetTool(wxT("AR"), m_pgPropAR->GetValueAsString());
+    m_compiler->SetTool(wxT("LinkerName"), m_pgPropLD->GetValueAsString());
     m_compiler->SetTool(wxT("SharedObjectLinkerName"), m_pgPropSharedObjectLD->GetValueAsString());
-    m_compiler->SetTool(wxT("ResourceCompiler"),       m_pgPropResourceCompiler->GetValueAsString());
-    m_compiler->SetTool("MAKE",                        m_pgPropMAKE->GetValueAsString());
-    m_compiler->SetTool("AS",                          m_pgPropAS->GetValueAsString());
-    m_compiler->SetTool("MakeDirCommand",              m_pgPropMkdir->GetValueAsString());
-    m_compiler->SetTool("Debugger",                    m_pgPropDebugger->GetValueAsString());
+    m_compiler->SetTool(wxT("ResourceCompiler"), m_pgPropResourceCompiler->GetValueAsString());
+    m_compiler->SetTool("MAKE", m_pgPropMAKE->GetValueAsString());
+    m_compiler->SetTool("AS", m_pgPropAS->GetValueAsString());
+    m_compiler->SetTool("MakeDirCommand", m_pgPropMkdir->GetValueAsString());
+    m_compiler->SetTool("Debugger", m_pgPropDebugger->GetValueAsString());
 }
 
 void CompilerMainPage::Initialize()
@@ -587,7 +601,7 @@ void CompilerMainPage::Save()
     SaveLinkerOptions();
 
     // save the compiler to the file system
-    BuildSettingsConfigST::Get()->SetCompiler( m_compiler );
+    BuildSettingsConfigST::Get()->SetCompiler(m_compiler);
     m_isDirty = false;
 }
 
@@ -597,7 +611,7 @@ void CompilerMainPage::AddSwitch(const wxString& name, const wxString& value, bo
     SetColumnText(m_listSwitches, item, 0, name);
     SetColumnText(m_listSwitches, item, 1, value);
 
-    if (choose) {
+    if(choose) {
         m_selSwitchName = name;
         m_selSwitchValue = value;
     }
@@ -610,7 +624,7 @@ void CompilerMainPage::EditSwitch()
     wxString message;
     message << m_selSwitchName << _(" switch:");
     wxTextEntryDialog dlg(this, message, _("Edit"), m_selSwitchValue);
-    if (dlg.ShowModal() == wxID_OK) {
+    if(dlg.ShowModal() == wxID_OK) {
         wxString newVal = dlg.GetValue();
         m_compiler->SetSwitch(m_selSwitchName, dlg.GetValue());
         m_isDirty = true;
@@ -621,42 +635,41 @@ void CompilerMainPage::EditSwitch()
 void CompilerMainPage::InitializeSwitches()
 {
     // Clear content
-    wxWindowUpdateLocker locker( m_listSwitches );
+    wxWindowUpdateLocker locker(m_listSwitches);
     m_listSwitches->DeleteAllItems();
     m_selSwitchName.Clear();
     m_selSwitchValue.Clear();
-    
+
     // Validate compiler and add new content
     CHECK_PTR_RET(m_compiler);
-    
+
     Compiler::ConstIterator iter = m_compiler->SwitchesBegin();
-    for (; iter != m_compiler->SwitchesEnd(); iter++) {
+    for(; iter != m_compiler->SwitchesEnd(); iter++) {
         AddSwitch(iter->first, iter->second, iter == m_compiler->SwitchesBegin());
     }
     m_listSwitches->SetColumnWidth(0, wxLIST_AUTOSIZE);
 }
 
-void CompilerMainPage::SaveSwitches()
-{
-}
+void CompilerMainPage::SaveSwitches() {}
 
 void CompilerMainPage::InitializeFileTypes()
 {
-    //populate the list control
-    wxWindowUpdateLocker locker( m_listCtrlFileTypes );
-    
+    // populate the list control
+    wxWindowUpdateLocker locker(m_listCtrlFileTypes);
+
     m_listCtrlFileTypes->DeleteAllItems();
     CHECK_PTR_RET(m_compiler);
-    
+
     m_selectedFileType = -1;
     std::map<wxString, Compiler::CmpFileTypeInfo> fileTypes = m_compiler->GetFileTypes();
     std::map<wxString, Compiler::CmpFileTypeInfo>::iterator iter = fileTypes.begin();
-    for ( ; iter != fileTypes.end(); iter++ ) {
+    for(; iter != fileTypes.end(); iter++) {
         Compiler::CmpFileTypeInfo ft = iter->second;
 
         long item = AppendListCtrlRow(m_listCtrlFileTypes);
         SetColumnText(m_listCtrlFileTypes, item, 0, ft.extension);
-        SetColumnText(m_listCtrlFileTypes, item, 1, ft.kind == Compiler::CmpFileKindSource ? _("Source") : _("Resource"));
+        SetColumnText(
+            m_listCtrlFileTypes, item, 1, ft.kind == Compiler::CmpFileKindSource ? _("Source") : _("Resource"));
         SetColumnText(m_listCtrlFileTypes, item, 2, ft.compilation_line);
     }
 
@@ -668,13 +681,14 @@ void CompilerMainPage::InitializeFileTypes()
 void CompilerMainPage::SaveFileTypes()
 {
     CHECK_PTR_RET(m_compiler);
-    
+
     std::map<wxString, Compiler::CmpFileTypeInfo> fileTypes;
     int count = m_listCtrlFileTypes->GetItemCount();
-    for (int i=0; i<count; i++) {
+    for(int i = 0; i < count; i++) {
         Compiler::CmpFileTypeInfo ft;
         ft.extension = GetColumnText(m_listCtrlFileTypes, i, 0);
-        ft.kind = GetColumnText(m_listCtrlFileTypes, i, 1) == _("Resource") ? Compiler::CmpFileKindResource : Compiler::CmpFileKindSource;
+        ft.kind = GetColumnText(m_listCtrlFileTypes, i, 1) == _("Resource") ? Compiler::CmpFileKindResource :
+                                                                              Compiler::CmpFileKindSource;
         ft.compilation_line = GetColumnText(m_listCtrlFileTypes, i, 2);
 
         fileTypes[ft.extension] = ft;
@@ -693,7 +707,7 @@ void CompilerMainPage::InitializeAdvancePage()
     m_textCtrlGlobalLibPath->ChangeValue("");
     m_checkBoxReadObjectsFromFile->SetValue(false);
     m_checkBoxObjectNameSameAsFileName->SetValue(false);
-    
+
     CHECK_PTR_RET(m_compiler);
     m_textObjectExtension->ChangeValue(m_compiler->GetObjectSuffix());
     m_textDependExtension->ChangeValue(m_compiler->GetDependSuffix());
@@ -721,13 +735,13 @@ void CompilerMainPage::SaveAdvancedPage()
 void CompilerMainPage::InitializeCompilerOptions()
 {
     m_selectedCmpOption = -1;
-    wxWindowUpdateLocker locker( m_listCompilerOptions );
+    wxWindowUpdateLocker locker(m_listCompilerOptions);
     m_listCompilerOptions->DeleteAllItems();
-    
+
     CHECK_PTR_RET(m_compiler);
     const Compiler::CmpCmdLineOptions& cmpOptions = m_compiler->GetCompilerOptions();
     Compiler::CmpCmdLineOptions::const_iterator itCmpOption = cmpOptions.begin();
-    for ( ; itCmpOption != cmpOptions.end(); ++itCmpOption) {
+    for(; itCmpOption != cmpOptions.end(); ++itCmpOption) {
         const Compiler::CmpCmdLineOption& cmpOption = itCmpOption->second;
         long idx = m_listCompilerOptions->InsertItem(m_listCompilerOptions->GetItemCount(), cmpOption.name);
         m_listCompilerOptions->SetItem(idx, 1, cmpOption.help);
@@ -741,7 +755,7 @@ void CompilerMainPage::SaveComilerOptions()
 {
     CHECK_PTR_RET(m_compiler);
     Compiler::CmpCmdLineOptions cmpOptions;
-    for (int idx = 0; idx < m_listCompilerOptions->GetItemCount(); ++idx) {
+    for(int idx = 0; idx < m_listCompilerOptions->GetItemCount(); ++idx) {
         Compiler::CmpCmdLineOption cmpOption;
         cmpOption.name = m_listCompilerOptions->GetItemText(idx);
         cmpOption.help = GetColumnText(m_listCompilerOptions, idx, 1);
@@ -754,13 +768,13 @@ void CompilerMainPage::SaveComilerOptions()
 void CompilerMainPage::InitializeLinkerOptions()
 {
     m_selectedLnkOption = -1;
-    wxWindowUpdateLocker locker( m_listLinkerOptions );
+    wxWindowUpdateLocker locker(m_listLinkerOptions);
     m_listLinkerOptions->DeleteAllItems();
     CHECK_PTR_RET(m_compiler);
-    
+
     const Compiler::CmpCmdLineOptions& lnkOptions = m_compiler->GetLinkerOptions();
     Compiler::CmpCmdLineOptions::const_iterator itLnkOption = lnkOptions.begin();
-    for ( ; itLnkOption != lnkOptions.end(); ++itLnkOption) {
+    for(; itLnkOption != lnkOptions.end(); ++itLnkOption) {
         const Compiler::CmpCmdLineOption& lnkOption = itLnkOption->second;
         long idx = m_listLinkerOptions->InsertItem(m_listLinkerOptions->GetItemCount(), lnkOption.name);
         m_listLinkerOptions->SetItem(idx, 1, lnkOption.help);
@@ -773,7 +787,7 @@ void CompilerMainPage::SaveLinkerOptions()
 {
     CHECK_PTR_RET(m_compiler);
     Compiler::CmpCmdLineOptions lnkOptions;
-    for (int idx = 0; idx < m_listLinkerOptions->GetItemCount(); ++idx) {
+    for(int idx = 0; idx < m_listLinkerOptions->GetItemCount(); ++idx) {
         Compiler::CmpCmdLineOption lnkOption;
         lnkOption.name = m_listLinkerOptions->GetItemText(idx);
         lnkOption.help = GetColumnText(m_listLinkerOptions, idx, 1);
@@ -781,43 +795,39 @@ void CompilerMainPage::SaveLinkerOptions()
         lnkOptions[lnkOption.name] = lnkOption;
     }
     m_compiler->SetLinkerOptions(lnkOptions);
-
 }
 
 void CompilerMainPage::LoadCompilers()
 {
     // Populate the compilers list
     m_listBoxCompilers->Clear();
-    
+
     wxString cmpType;
-    if ( WorkspaceST::Get()->IsOpen() && WorkspaceST::Get()->GetActiveProject() ) {
+    if(WorkspaceST::Get()->IsOpen() && WorkspaceST::Get()->GetActiveProject()) {
         BuildConfigPtr bldConf = WorkspaceST::Get()->GetActiveProject()->GetBuildConfiguration();
         if(bldConf) {
             cmpType = bldConf->GetCompilerType();
         }
     }
-    
+
     BuildSettingsConfigCookie cookie;
     CompilerPtr cmp = BuildSettingsConfigST::Get()->GetFirstCompiler(cookie);
     int sel(0);
-    while (cmp) {
+    while(cmp) {
         int curidx = m_listBoxCompilers->Append(cmp->GetName());
-        if ( !cmpType.IsEmpty() && (cmp->GetName() == cmpType) ) {
+        if(!cmpType.IsEmpty() && (cmp->GetName() == cmpType)) {
             sel = curidx;
         }
         cmp = BuildSettingsConfigST::Get()->GetNextCompiler(cookie);
     }
-    
-    if ( !m_listBoxCompilers->IsEmpty() ) {
+
+    if(!m_listBoxCompilers->IsEmpty()) {
         m_listBoxCompilers->SetSelection(sel);
-        LoadCompiler( m_listBoxCompilers->GetStringSelection() );
+        LoadCompiler(m_listBoxCompilers->GetStringSelection());
     }
 }
 
-void CompilerMainPage::OnCompilerSelected(wxCommandEvent& event)
-{
-    LoadCompiler(event.GetString());
-}
+void CompilerMainPage::OnCompilerSelected(wxCommandEvent& event) { LoadCompiler(event.GetString()); }
 
 // ======----------------------------------------------------------------
 // Helper dialogs
@@ -829,22 +839,23 @@ CompilerPatternDlg::CompilerPatternDlg(wxWindow* parent, const wxString& title)
     WindowAttrManager::Load(this, wxT("CompilerPatternDlg"), NULL);
 }
 
-CompilerPatternDlg::~CompilerPatternDlg()
-{
-    WindowAttrManager::Save(this, wxT("CompilerPatternDlg"), NULL);
-}
+CompilerPatternDlg::~CompilerPatternDlg() { WindowAttrManager::Save(this, wxT("CompilerPatternDlg"), NULL); }
 
-void CompilerPatternDlg::SetPattern(const wxString& pattern, const wxString& lineIdx, const wxString& fileIdx)
+void CompilerPatternDlg::SetPattern(const wxString& pattern,
+                                    const wxString& lineIdx,
+                                    const wxString& fileIdx,
+                                    const wxString& columnIndex)
 {
     m_textPattern->ChangeValue(pattern);
     m_textLineNumber->ChangeValue(lineIdx);
     m_textFileIndex->ChangeValue(fileIdx);
+    m_textColumn->ChangeValue(columnIndex);
 }
 
-void CompilerPatternDlg::OnSubmit( wxCommandEvent& event )
+void CompilerPatternDlg::OnSubmit(wxCommandEvent& event)
 {
-    if ( GetPattern().Trim().IsEmpty() || GetFileIndex().Trim().IsEmpty() || GetLineIndex().Trim().IsEmpty()) {
-        wxMessageBox(_("Please fill all the fields"), _("CodeLite"), wxOK|wxICON_INFORMATION, this);
+    if(GetPattern().Trim().IsEmpty() || GetFileIndex().Trim().IsEmpty() || GetLineIndex().Trim().IsEmpty()) {
+        wxMessageBox(_("Please fill all the fields"), _("CodeLite"), wxOK | wxICON_INFORMATION, this);
         return;
     }
     EndModal(wxID_OK);
@@ -852,8 +863,8 @@ void CompilerPatternDlg::OnSubmit( wxCommandEvent& event )
 
 void CompilerMainPage::OnAddCompilers(wxCommandEvent& event)
 {
-    AdvancedDlg *dlg = dynamic_cast<AdvancedDlg*>(wxGetTopLevelParent(this));
-    dlg->OnAutoDetectCompilers( m_button222 );
+    AdvancedDlg* dlg = dynamic_cast<AdvancedDlg*>(wxGetTopLevelParent(this));
+    dlg->OnAutoDetectCompilers(m_button222);
 }
 
 void CompilerMainPage::OnContextMenu(wxContextMenuEvent& event)
@@ -861,29 +872,32 @@ void CompilerMainPage::OnContextMenu(wxContextMenuEvent& event)
     wxMenu menu;
     menu.Append(XRCID("rename_compiler"), _("Rename..."));
     menu.Append(wxID_DELETE);
-    
+
     int selection = m_listBoxCompilers->GetSelection();
-    menu.Enable(wxID_DELETE,              selection != wxNOT_FOUND);
+    menu.Enable(wxID_DELETE, selection != wxNOT_FOUND);
     menu.Enable(XRCID("rename_compiler"), selection != wxNOT_FOUND);
-    
-    m_listBoxCompilers->Bind(wxEVT_COMMAND_MENU_SELECTED, &CompilerMainPage::OnRenameCompiler, this, XRCID("rename_compiler"));
+
+    m_listBoxCompilers->Bind(
+        wxEVT_COMMAND_MENU_SELECTED, &CompilerMainPage::OnRenameCompiler, this, XRCID("rename_compiler"));
     m_listBoxCompilers->Bind(wxEVT_COMMAND_MENU_SELECTED, &CompilerMainPage::OnDeleteCompiler, this, wxID_DELETE);
-    
-    m_listBoxCompilers->PopupMenu( &menu );
+
+    m_listBoxCompilers->PopupMenu(&menu);
 }
 
 void CompilerMainPage::OnDeleteCompiler(wxCommandEvent& event)
 {
     int selection = m_listBoxCompilers->GetSelection();
-    if ( selection == wxNOT_FOUND )
-        return;
-    
-    if ( ::wxMessageBox(wxString() << _("Are you sure you want to delete compiler\n'") << m_listBoxCompilers->GetStringSelection() << "'?", _("Delete Compiler"), wxYES_NO|wxCENTER|wxICON_WARNING) != wxYES )
+    if(selection == wxNOT_FOUND) return;
+
+    if(::wxMessageBox(wxString() << _("Are you sure you want to delete compiler\n'")
+                                 << m_listBoxCompilers->GetStringSelection() << "'?",
+                      _("Delete Compiler"),
+                      wxYES_NO | wxCENTER | wxICON_WARNING) != wxYES)
         return;
 
     wxString compilerName = m_listBoxCompilers->GetStringSelection();
-    BuildSettingsConfigST::Get()->DeleteCompiler( compilerName );
-    
+    BuildSettingsConfigST::Get()->DeleteCompiler(compilerName);
+
     // Reload the content
     LoadCompilers();
 }
@@ -891,24 +905,22 @@ void CompilerMainPage::OnDeleteCompiler(wxCommandEvent& event)
 void CompilerMainPage::OnRenameCompiler(wxCommandEvent& event)
 {
     int selection = m_listBoxCompilers->GetSelection();
-    if ( selection == wxNOT_FOUND )
-        return;
-        
-    wxString newName = ::wxGetTextFromUser(_("New Compiler Name"), _("Rename Compiler"), m_listBoxCompilers->GetStringSelection());
-    if ( newName.IsEmpty() )
-        return;
-    
+    if(selection == wxNOT_FOUND) return;
+
+    wxString newName =
+        ::wxGetTextFromUser(_("New Compiler Name"), _("Rename Compiler"), m_listBoxCompilers->GetStringSelection());
+    if(newName.IsEmpty()) return;
+
     CompilerPtr compiler = BuildSettingsConfigST::Get()->GetCompiler(m_listBoxCompilers->GetStringSelection());
-    if ( !compiler )
-        return;
-    
+    if(!compiler) return;
+
     // Delete the old compiler
-    BuildSettingsConfigST::Get()->DeleteCompiler( compiler->GetName() );
-    
+    BuildSettingsConfigST::Get()->DeleteCompiler(compiler->GetName());
+
     // Create new one with differet name
-    compiler->SetName( newName );
-    BuildSettingsConfigST::Get()->SetCompiler( compiler );
-    
+    compiler->SetName(newName);
+    BuildSettingsConfigST::Get()->SetCompiler(compiler);
+
     // Reload the content
     LoadCompilers();
 }
@@ -917,3 +929,9 @@ void CompilerMainPage::OnValueChanged(wxPropertyGridEvent& event)
     event.Skip();
     m_isDirty = true;
 }
+
+void CompilerMainPage::OnCmdModify(wxCommandEvent& event)
+{
+    event.Skip();
+    m_isDirty = true;
+}
