@@ -51,6 +51,9 @@
 #include <wx/regex.h>
 #include "CompilerLocatorCygwin.h"
 #include "ColoursAndFontsManager.h"
+#include "clKeyboardManager.h"
+#include "clInitializeDialog.h"
+#include "event_notifier.h"
 
 #define __PERFORMANCE
 #include "performance.h"
@@ -58,10 +61,10 @@
 //////////////////////////////////////////////
 // Define the version string for this codelite
 //////////////////////////////////////////////
-extern wxChar *clGitRevision;
+extern wxChar* clGitRevision;
 wxString CODELITE_VERSION_STR = clGitRevision;
 
-#if defined(__WXMAC__)||defined(__WXGTK__)
+#if defined(__WXMAC__) || defined(__WXGTK__)
 #include <sys/wait.h>
 #include <signal.h> // sigprocmask
 #endif
@@ -99,12 +102,12 @@ wxString MacGetBasePath()
     uint32_t path_len = 256;
     _NSGetExecutablePath(path, &path_len);
 
-    //path now contains
-    //CodeLite.app/Contents/MacOS/
+    // path now contains
+    // CodeLite.app/Contents/MacOS/
     wxFileName fname(wxString(path, wxConvUTF8));
 
-    //remove he MacOS part of the exe path
-    wxString file_name = fname.GetPath(wxPATH_GET_VOLUME|wxPATH_GET_SEPARATOR);
+    // remove he MacOS part of the exe path
+    wxString file_name = fname.GetPath(wxPATH_GET_VOLUME | wxPATH_GET_SEPARATOR);
     wxString rest;
     file_name.EndsWith(wxT("MacOS/"), &rest);
     rest.Append(wxT("SharedSupport/"));
@@ -116,22 +119,52 @@ wxString MacGetBasePath()
 ///////////////////////////////////////////////////////////////////
 
 static const wxCmdLineEntryDesc cmdLineDesc[] = {
-    {wxCMD_LINE_SWITCH, "v",  "version",      "Print current version",                       wxCMD_LINE_VAL_STRING, wxCMD_LINE_PARAM_OPTIONAL },
-    {wxCMD_LINE_SWITCH, "h",  "help",         "Print usage",                                 wxCMD_LINE_VAL_STRING, wxCMD_LINE_PARAM_OPTIONAL },
-    {wxCMD_LINE_SWITCH, "n",  "no-plugins",   "Start codelite without any plugins",          wxCMD_LINE_VAL_STRING, wxCMD_LINE_PARAM_OPTIONAL },
-    {wxCMD_LINE_OPTION, "l",  "line",         "Open the file at a given line number",        wxCMD_LINE_VAL_NUMBER, wxCMD_LINE_PARAM_OPTIONAL },
-    {wxCMD_LINE_OPTION, "b",  "basedir",      "Use this path as the CodeLite installation path (Windows only)", wxCMD_LINE_VAL_STRING, wxCMD_LINE_PARAM_OPTIONAL },
-    {wxCMD_LINE_OPTION, "d",  "datadir",      "Use this path as the CodeLite data path",     wxCMD_LINE_VAL_STRING, wxCMD_LINE_PARAM_OPTIONAL },
-    {wxCMD_LINE_OPTION, "p",  "with-plugins", "Comma separated list of plugins to load",     wxCMD_LINE_VAL_STRING, wxCMD_LINE_PARAM_OPTIONAL },
-    {wxCMD_LINE_PARAM,  NULL, NULL,           "Input file",                                  wxCMD_LINE_VAL_STRING, wxCMD_LINE_PARAM_MULTIPLE|wxCMD_LINE_PARAM_OPTIONAL },
-    {wxCMD_LINE_NONE }
+    { wxCMD_LINE_SWITCH, "v", "version", "Print current version", wxCMD_LINE_VAL_STRING, wxCMD_LINE_PARAM_OPTIONAL },
+    { wxCMD_LINE_SWITCH, "h", "help", "Print usage", wxCMD_LINE_VAL_STRING, wxCMD_LINE_PARAM_OPTIONAL },
+    { wxCMD_LINE_SWITCH,
+      "n",
+      "no-plugins",
+      "Start codelite without any plugins",
+      wxCMD_LINE_VAL_STRING,
+      wxCMD_LINE_PARAM_OPTIONAL },
+    { wxCMD_LINE_OPTION,
+      "l",
+      "line",
+      "Open the file at a given line number",
+      wxCMD_LINE_VAL_NUMBER,
+      wxCMD_LINE_PARAM_OPTIONAL },
+    { wxCMD_LINE_OPTION,
+      "b",
+      "basedir",
+      "Use this path as the CodeLite installation path (Windows only)",
+      wxCMD_LINE_VAL_STRING,
+      wxCMD_LINE_PARAM_OPTIONAL },
+    { wxCMD_LINE_OPTION,
+      "d",
+      "datadir",
+      "Use this path as the CodeLite data path",
+      wxCMD_LINE_VAL_STRING,
+      wxCMD_LINE_PARAM_OPTIONAL },
+    { wxCMD_LINE_OPTION,
+      "p",
+      "with-plugins",
+      "Comma separated list of plugins to load",
+      wxCMD_LINE_VAL_STRING,
+      wxCMD_LINE_PARAM_OPTIONAL },
+    { wxCMD_LINE_PARAM,
+      NULL,
+      NULL,
+      "Input file",
+      wxCMD_LINE_VAL_STRING,
+      wxCMD_LINE_PARAM_MULTIPLE | wxCMD_LINE_PARAM_OPTIONAL },
+    { wxCMD_LINE_NONE }
 };
 
-static void massCopy(const wxString &sourceDir, const wxString &spec, const wxString &destDir)
+static void massCopy(const wxString& sourceDir, const wxString& spec, const wxString& destDir)
 {
     wxArrayString files;
     wxDir::GetAllFiles(sourceDir, &files, spec, wxDIR_FILES);
-    for ( size_t i=0; i<files.GetCount(); i++ ) {
+    for(size_t i = 0; i < files.GetCount(); i++) {
         wxFileName fn(files.Item(i));
         wxCopyFile(files.Item(i), destDir + wxT("/") + fn.GetFullName());
     }
@@ -140,7 +173,7 @@ static void massCopy(const wxString &sourceDir, const wxString &spec, const wxSt
 static void ChildTerminatedSingalHandler(int signo)
 {
     int status;
-    while( true ) {
+    while(true) {
         pid_t pid = ::waitpid(-1, &status, WNOHANG);
         if(pid > 0) {
             // waitpid succeeded
@@ -149,7 +182,6 @@ static void ChildTerminatedSingalHandler(int signo)
 
         } else {
             break;
-
         }
     }
 }
@@ -175,37 +207,40 @@ static void WaitForDebugger(int signo)
     wxString msg;
     wxString where;
 
-    msg << wxT("codelite crashed: you may attach to it using gdb\n")
-        << wxT("or let it crash silently..\n")
+    msg << wxT("codelite crashed: you may attach to it using gdb\n") << wxT("or let it crash silently..\n")
         << wxT("Attach debugger?\n");
 
-    int rc = wxMessageBox(msg, wxT("CodeLite Crash Handler"), wxYES_NO|wxCENTER|wxICON_ERROR);
+    int rc = wxMessageBox(msg, wxT("CodeLite Crash Handler"), wxYES_NO | wxCENTER | wxICON_ERROR);
     if(rc == wxYES) {
 
         // Launch a shell command with the following command:
         // gdb -p <PID>
 
         char command[256];
-        memset (command, 0, sizeof(command));
+        memset(command, 0, sizeof(command));
 
-        if (ExeLocator::Locate(wxT("gnome-terminal"), where)) {
+        if(ExeLocator::Locate(wxT("gnome-terminal"), where)) {
             sprintf(command, "gnome-terminal -t 'gdb' -e 'gdb -p %d'", getpid());
-        } else if (ExeLocator::Locate(wxT("konsole"), where)) {
+        } else if(ExeLocator::Locate(wxT("konsole"), where)) {
             sprintf(command, "konsole -T 'gdb' -e 'gdb -p %d'", getpid());
-        } else if (ExeLocator::Locate(wxT("terminal"), where)) {
+        } else if(ExeLocator::Locate(wxT("terminal"), where)) {
             sprintf(command, "terminal -T 'gdb' -e 'gdb -p %d'", getpid());
-        } else if (ExeLocator::Locate(wxT("lxterminal"), where)) {
+        } else if(ExeLocator::Locate(wxT("lxterminal"), where)) {
             sprintf(command, "lxterminal -T 'gdb' -e 'gdb -p %d'", getpid());
         } else {
             sprintf(command, "xterm -T 'gdb' -e 'gdb -p %d'", getpid());
         }
 
-        if(system (command) == 0) {
+        if(system(command) == 0) {
             signal(signo, SIG_DFL);
             raise(signo);
         } else {
             // Go down without launching the debugger, ask the user to do it manually
-            wxMessageBox(wxString::Format(wxT("Failed to launch the debugger\nYou may still attach to codelite manually by typing this command in a terminal:\ngdb -p %d"), getpid()), wxT("CodeLite Crash Handler"), wxOK|wxCENTER|wxICON_ERROR);
+            wxMessageBox(wxString::Format(wxT("Failed to launch the debugger\nYou may still attach to codelite "
+                                              "manually by typing this command in a terminal:\ngdb -p %d"),
+                                          getpid()),
+                         wxT("CodeLite Crash Handler"),
+                         wxOK | wxCENTER | wxICON_ERROR);
             pause();
         }
     }
@@ -217,9 +252,9 @@ static void WaitForDebugger(int signo)
 
 IMPLEMENT_APP(CodeLiteApp)
 
-//BEGIN_EVENT_TABLE(CodeLiteApp, wxApp)
+// BEGIN_EVENT_TABLE(CodeLiteApp, wxApp)
 //    EVT_ACTIVATE_APP(CodeLiteApp::OnAppAcitvated)
-//END_EVENT_TABLE()
+// END_EVENT_TABLE()
 
 extern void InitXmlResource();
 CodeLiteApp::CodeLiteApp(void)
@@ -236,15 +271,15 @@ CodeLiteApp::~CodeLiteApp(void)
 {
     wxImage::CleanUpHandlers();
 #ifdef __WXMSW__
-    if (m_handler) {
+    if(m_handler) {
         FreeLibrary(m_handler);
         m_handler = NULL;
     }
 #endif
-    if ( m_singleInstance ) {
+    if(m_singleInstance) {
         delete m_singleInstance;
     }
-//    wxAppBase::ExitMainLoop();
+    //    wxAppBase::ExitMainLoop();
 }
 
 bool CodeLiteApp::OnInit()
@@ -253,7 +288,7 @@ bool CodeLiteApp::OnInit()
 
     // block signal pipe
     sigset_t mask_set;
-    sigemptyset( &mask_set );
+    sigemptyset(&mask_set);
     sigaddset(&mask_set, SIGPIPE);
     sigprocmask(SIG_SETMASK, &mask_set, NULL);
 
@@ -279,49 +314,62 @@ bool CodeLiteApp::OnInit()
     // load the exception handler dll so we will get Dr MinGW at runtime
     m_handler = LoadLibrary(wxT("exchndl.dll"));
 
-    // Enable this process debugging priviliges
-    //EnableDebugPriv();
+// Enable this process debugging priviliges
+// EnableDebugPriv();
 #endif
 
+#ifdef USE_POSIX_LAYOUT
+    wxStandardPaths::Get().IgnoreAppSubDir("bin");
+#endif
 
     // Init resources and add the PNG handler
     wxSystemOptions::SetOption(_T("msw.remap"), 0);
-    wxSystemOptions::SetOption("msw.notebook.themed-background", 0);
+    wxSystemOptions::SetOption("msw.notebook.themed-background", 1);
     wxXmlResource::Get()->InitAllHandlers();
-    wxImage::AddHandler( new wxPNGHandler );
-    wxImage::AddHandler( new wxCURHandler );
-    wxImage::AddHandler( new wxICOHandler );
-    wxImage::AddHandler( new wxXPMHandler );
-    wxImage::AddHandler( new wxGIFHandler );
+    wxImage::AddHandler(new wxPNGHandler);
+    wxImage::AddHandler(new wxCURHandler);
+    wxImage::AddHandler(new wxICOHandler);
+    wxImage::AddHandler(new wxXPMHandler);
+    wxImage::AddHandler(new wxGIFHandler);
     InitXmlResource();
 
     wxLog::EnableLogging(false);
     wxString homeDir(wxEmptyString);
 
-    //parse command line
+    // parse command line
     wxCmdLineParser parser;
     parser.SetDesc(cmdLineDesc);
     parser.SetCmdLine(wxAppBase::argc, wxAppBase::argv);
-    if (parser.Parse() != 0) {
+    if(parser.Parse() != 0) {
         return false;
     }
 
-    if (parser.Found(wxT("h"))) {
+    if(parser.Found(wxT("h"))) {
         // print usage
         parser.Usage();
         return false;
     }
+    
+    if(parser.Found(wxT("v"))) {
+        // print version
+#ifdef __WXMSW__
+        ::wxMessageBox(wxString() << "CodeLite IDE v" << clGitRevision, "CodeLite");
+#else
+        wxPrintf("CodeLite IDE v%s\n", clGitRevision);
+#endif
+        return false;
+    }
 
-    if (parser.Found(wxT("n"))) {
+    if(parser.Found(wxT("n"))) {
         // Load codelite without plugins
         SetPluginLoadPolicy(PP_None);
     }
 
     wxString plugins;
-    if (parser.Found(wxT("p"), &plugins)) {
+    if(parser.Found(wxT("p"), &plugins)) {
         wxArrayString pluginsArr = ::wxStringTokenize(plugins, wxT(","));
         // Trim and make lower case
-        for(size_t i=0; i<pluginsArr.GetCount(); i++) {
+        for(size_t i = 0; i < pluginsArr.GetCount(); i++) {
             pluginsArr.Item(i).Trim().Trim(false).MakeLower();
         }
 
@@ -331,8 +379,8 @@ bool CodeLiteApp::OnInit()
     }
 
     wxString newBaseDir(wxEmptyString);
-    if (parser.Found(wxT("b"), &newBaseDir)) {
-#if defined (__WXMSW__)
+    if(parser.Found(wxT("b"), &newBaseDir)) {
+#if defined(__WXMSW__)
         homeDir = newBaseDir;
 #else
         wxLogDebug("Ignoring the Windows-only --basedir option as not running Windows");
@@ -340,10 +388,14 @@ bool CodeLiteApp::OnInit()
     }
 
     wxString newDataDir(wxEmptyString);
-    if (parser.Found(wxT("d"), &newDataDir)) {
+    if(parser.Found(wxT("d"), &newDataDir)) {
         clStandardPaths::Get().SetUserDataDir(newDataDir);
     }
 
+    // Set the log file verbosity. NB Doing this earlier seems to break wxGTK debug output when debugging CodeLite itself :/
+    FileLogger::OpenLog("codelite.log", clConfig::Get().Read(kConfigLogVerbosity, FileLogger::Error));
+    CL_DEBUG(wxT("Starting codelite..."));
+
     // Copy gdb pretty printers from the installation folder to a writeable location
     // this is  needed because python complies the files and in most cases the user
     // running codelite has no write permissions to /usr/share/codelite/...
@@ -357,17 +409,18 @@ bool CodeLiteApp::OnInit()
     // http://gcc.gnu.org/onlinedocs/gcc/Language-Independent-Options.html
     ::wxSetEnv("GCC_COLORS", "");
 
-#if defined (__WXGTK__)
-    if (homeDir.IsEmpty()) {
+#if defined(__WXGTK__)
+    if(homeDir.IsEmpty()) {
         SetAppName(wxT("codelite"));
-        homeDir = clStandardPaths::Get().GetUserDataDir(); // By default, ~/Library/Application Support/codelite or ~/.codelite
-        if (!wxFileName::Exists(homeDir)) {
+        homeDir = clStandardPaths::Get()
+                      .GetUserDataDir(); // By default, ~/Library/Application Support/codelite or ~/.codelite
+        if(!wxFileName::Exists(homeDir)) {
             wxLogNull noLog;
-            wxFileName::Mkdir(homeDir, wxS_DIR_DEFAULT,  wxPATH_MKDIR_FULL);
+            wxFileName::Mkdir(homeDir, wxS_DIR_DEFAULT, wxPATH_MKDIR_FULL);
             wxCHECK_MSG(wxFileName::DirExists(homeDir), false, "Failed to create the requested data dir");
         }
 
-        //Create the directory structure
+        // Create the directory structure
         wxLogNull noLog;
         wxMkdir(homeDir);
         wxMkdir(homeDir + wxT("/lexers/"));
@@ -377,30 +430,30 @@ bool CodeLiteApp::OnInit()
         wxMkdir(homeDir + wxT("/config/"));
         wxMkdir(homeDir + wxT("/tabgroups/"));
 
-        //copy the settings from the global location if needed
-        wxString installPath( INSTALL_DIR, wxConvUTF8 );
-        if ( ! CopySettings(homeDir, installPath ) ) return false;
-        ManagerST::Get()->SetInstallDir( installPath );
+        // copy the settings from the global location if needed
+        wxString installPath(INSTALL_DIR, wxConvUTF8);
+        if(!CopySettings(homeDir, installPath)) return false;
+        ManagerST::Get()->SetInstallDir(installPath);
 
     } else {
         wxFileName fn(homeDir);
         fn.MakeAbsolute();
-        ManagerST::Get()->SetInstallDir( fn.GetFullPath() );
+        ManagerST::Get()->SetInstallDir(fn.GetFullPath());
     }
 
-#elif defined (__WXMAC__)
+#elif defined(__WXMAC__)
     SetAppName(wxT("codelite"));
     homeDir = clStandardPaths::Get().GetUserDataDir();
-    if (!wxFileName::Exists(homeDir)) {
+    if(!wxFileName::Exists(homeDir)) {
         wxLogNull noLog;
-        wxFileName::Mkdir(homeDir, wxS_DIR_DEFAULT,  wxPATH_MKDIR_FULL);
+        wxFileName::Mkdir(homeDir, wxS_DIR_DEFAULT, wxPATH_MKDIR_FULL);
         wxCHECK_MSG(wxFileName::DirExists(homeDir), false, "Failed to create the requested data dir");
     }
 
     {
         wxLogNull noLog;
 
-        //Create the directory structure
+        // Create the directory structure
         wxMkdir(homeDir);
         wxMkdir(homeDir + wxT("/lexers/"));
         wxMkdir(homeDir + wxT("/rc/"));
@@ -410,62 +463,68 @@ bool CodeLiteApp::OnInit()
         wxMkdir(homeDir + wxT("/tabgroups/"));
     }
 
-
-    wxString installPath( MacGetBasePath() );
-    ManagerST::Get()->SetInstallDir( installPath );
-    //copy the settings from the global location if needed
+    wxString installPath(MacGetBasePath());
+    ManagerST::Get()->SetInstallDir(installPath);
+    // copy the settings from the global location if needed
     CopySettings(homeDir, installPath);
 
 #else //__WXMSW__
-    if (homeDir.IsEmpty()) { //did we got a basedir from user?
+    if(homeDir.IsEmpty()) { // did we got a basedir from user?
+#  ifdef USE_POSIX_LAYOUT
+        homeDir = wxStandardPaths::Get().GetDataDir() + wxT(INSTALL_DIR);
+#  else
         homeDir = ::wxGetCwd();
+#  endif
     }
     wxFileName fnHomdDir(homeDir + wxT("/"));
 
     // try to locate the menu/rc.xrc file
     wxFileName fn(homeDir + wxT("/rc"), wxT("menu.xrc"));
-    if (!fn.FileExists()) {
+    if(!fn.FileExists()) {
         // we got wrong home directory
-        wxFileName appFn( wxAppBase::argv[0] );
+        wxFileName appFn(wxAppBase::argv[0]);
         homeDir = appFn.GetPath();
     }
 
-    if (fnHomdDir.IsRelative()) {
+    if(fnHomdDir.IsRelative()) {
         fnHomdDir.MakeAbsolute();
         homeDir = fnHomdDir.GetPath();
     }
 
-    ManagerST::Get()->SetInstallDir( homeDir );
+    ManagerST::Get()->SetInstallDir(homeDir);
 #endif
 
     // Update codelite revision and Version
-    EditorConfigST::Get()->Init(clGitRevision, wxT("2.0.2") );
-
+    EditorConfigST::Get()->Init(clGitRevision, wxT("2.0.2"));
+    
+    // Make sure we have an instance if the keyboard manager allocated before we create the main frame class
+    // (the keyboard manager needs to connect to the main frame events)
+    clKeyboardManager::Get();
+    
     ManagerST::Get()->SetOriginalCwd(wxGetCwd());
     ::wxSetWorkingDirectory(homeDir);
     // Load all of the XRC files that will be used. You can put everything
     // into one giant XRC file if you wanted, but then they become more
     // diffcult to manage, and harder to reuse in later projects.
     // The menubar
-    if (!wxXmlResource::Get()->Load( DoFindMenuFile(ManagerST::Get()->GetInstallDir(), wxT("2.0")) ) )
-        return false;
+    if(!wxXmlResource::Get()->Load(DoFindMenuFile(ManagerST::Get()->GetInstallDir(), wxT("2.0")))) return false;
 
     // keep the startup directory
-    ManagerST::Get()->SetStarupDirectory(::wxGetCwd());
+    ManagerST::Get()->SetStartupDirectory(::wxGetCwd());
 
     // set the performance output file name
     PERF_OUTPUT(wxString::Format(wxT("%s/codelite.perf"), wxGetCwd().c_str()).mb_str(wxConvUTF8));
 
     // Initialize the configuration file locater
-    ConfFileLocator::Instance()->Initialize(ManagerST::Get()->GetInstallDir(), ManagerST::Get()->GetStarupDirectory());
+    ConfFileLocator::Instance()->Initialize(ManagerST::Get()->GetInstallDir(), ManagerST::Get()->GetStartupDirectory());
 
-    Manager *mgr = ManagerST::Get();
+    Manager* mgr = ManagerST::Get();
 
     // set the CTAGS_REPLACEMENT environment variable
-    wxSetEnv(wxT("CTAGS_REPLACEMENTS"), ManagerST::Get()->GetStarupDirectory() + wxT("/ctags.replacements"));
+    wxSetEnv(wxT("CTAGS_REPLACEMENTS"), ManagerST::Get()->GetStartupDirectory() + wxT("/ctags.replacements"));
 
     long style = wxSIMPLE_BORDER;
-#if defined (__WXMSW__) || defined (__WXGTK__)
+#if defined(__WXMSW__) || defined(__WXGTK__)
     style |= wxFRAME_NO_TASKBAR;
 
 #else // Mac
@@ -473,27 +532,25 @@ bool CodeLiteApp::OnInit()
 
 #endif
 
-    //read the last frame size from the configuration file
-    // Initialise editor configuration files
+// read the last frame size from the configuration file
+// Initialise editor configuration files
 #ifdef __WXMSW__
     {
         wxLogNull noLog;
-        wxFileName::Mkdir(clStandardPaths::Get().GetUserDataDir(), wxS_DIR_DEFAULT,  wxPATH_MKDIR_FULL);
+        wxFileName::Mkdir(clStandardPaths::Get().GetUserDataDir(), wxS_DIR_DEFAULT, wxPATH_MKDIR_FULL);
     }
 #endif
 
-    EditorConfigST::Get()->SetInstallDir( mgr->GetInstallDir() );
-    EditorConfig *cfg = EditorConfigST::Get();
-    if ( !cfg->Load() ) {
+    EditorConfigST::Get()->SetInstallDir(mgr->GetInstallDir());
+    EditorConfig* cfg = EditorConfigST::Get();
+    if(!cfg->Load()) {
         CL_ERROR(wxT("Failed to load configuration file: %s/config/codelite.xml"), wxGetCwd().c_str());
         return false;
     }
 
-    ColoursAndFontsManager::Get().Load();
-
 #ifdef __WXGTK__
-    bool redirect = clConfig::Get().Read("RedirectLogOutput", true);
-    if (redirect) {
+    bool redirect = clConfig::Get().Read(kConfigRedirectLogOutput, true);
+    if(redirect) {
         // Redirect stdout/error to a file
         wxFileName stdout_err(clStandardPaths::Get().GetUserDataDir(), "codelite-stdout-stderr.log");
         FILE* new_stdout = ::freopen(stdout_err.GetFullPath().mb_str(wxConvISO8859_1).data(), "a+b", stdout);
@@ -502,13 +559,8 @@ bool CodeLiteApp::OnInit()
         wxUnusedVar(new_stdout);
     }
 #endif
-
-    // Set the log file verbosity
-    FileLogger::OpenLog("codelite.log", clConfig::Get().Read("LogVerbosity", FileLogger::Error));
-    CL_DEBUG(wxT("Starting codelite..."));
-
     // check for single instance
-    if ( !IsSingleInstance(parser, ManagerST::Get()->GetOriginalCwd()) ) {
+    if(!IsSingleInstance(parser, ManagerST::Get()->GetOriginalCwd())) {
         return false;
     }
 
@@ -523,7 +575,7 @@ bool CodeLiteApp::OnInit()
     vars.InsertVariable(wxT("Default"), wxT("CodeLiteDir"), ManagerST::Get()->GetInstallDir());
     EnvironmentConfig::Instance()->WriteObject(wxT("Variables"), &vars);
 
-    //---------------------------------------------------------
+//---------------------------------------------------------
 
 #ifdef __WXMSW__
 
@@ -536,46 +588,51 @@ bool CodeLiteApp::OnInit()
     cfg->ReadObject(wxT("GeneralInfo"), &inf);
 
     // Set up the locale if appropriate
-    if (EditorConfigST::Get()->GetOptions()->GetUseLocale()) {
+    if(EditorConfigST::Get()->GetOptions()->GetUseLocale()) {
         int preferredLocale = wxLANGUAGE_ENGLISH;
-        // The locale had to be saved as the canonical locale name, as the wxLanguage enum wasn't consistent between wx versions
+        // The locale had to be saved as the canonical locale name, as the wxLanguage enum wasn't consistent between wx
+        // versions
         wxString preferredLocalename = EditorConfigST::Get()->GetOptions()->GetPreferredLocale();
-        if (!preferredLocalename.IsEmpty()) {
+        if(!preferredLocalename.IsEmpty()) {
             const wxLanguageInfo* info = wxLocale::FindLanguageInfo(preferredLocalename);
-            if (info) {
+            if(info) {
                 preferredLocale = info->Language;
-                if (preferredLocale == wxLANGUAGE_UNKNOWN) {
+                if(preferredLocale == wxLANGUAGE_UNKNOWN) {
                     preferredLocale = wxLANGUAGE_ENGLISH;
                 }
             }
         }
 
-#if defined (__WXGTK__)
+#if defined(__WXGTK__)
         // Cater for a --prefix= build. This gets added automatically to the search path for catalogues.
         // So hack in the standard ones too, otherwise wxstd.mo will be missed
         wxLocale::AddCatalogLookupPathPrefix(wxT("/usr/share/locale"));
         wxLocale::AddCatalogLookupPathPrefix(wxT("/usr/local/share/locale"));
 
 #elif defined(__WXMSW__)
+#   ifdef USE_POSIX_LAYOUT
+        wxLocale::AddCatalogLookupPathPrefix(wxStandardPaths::Get().GetDataDir() + wxT("/share/locale"));
+#   else
         wxLocale::AddCatalogLookupPathPrefix(ManagerST::Get()->GetInstallDir() + wxT("\\locale"));
+#   endif
 #endif
 
         // This has to be done before the catalogues are added, as otherwise the wrong one (or none) will be found
         m_locale.Init(preferredLocale);
 
         bool codelitemo_found = m_locale.AddCatalog(wxT("codelite"));
-        if (!codelitemo_found) {
+        if(!codelitemo_found) {
             m_locale.AddCatalog(wxT("CodeLite")); // Hedge bets re our spelling
         }
 
-        if (!codelitemo_found) {
+        if(!codelitemo_found) {
             // I wanted to 'un-init' the locale if no translations were found
             // as otherwise, in a RTL locale, menus, dialogs etc will be displayed RTL, in English...
             // However I couldn't find a way to do this
         }
     }
 
-    // Append the binary's dir to $PATH. This makes codelite-cc available even for a --prefix= installation
+// Append the binary's dir to $PATH. This makes codelite-cc available even for a --prefix= installation
 #if defined(__WXMSW__)
     wxChar pathsep(wxT(';'));
 #else
@@ -591,28 +648,51 @@ bool CodeLiteApp::OnInit()
     // If running under Cygwin terminal, adjust the environment variables
     AdjustPathForCygwinIfNeeded();
 
+    // If running under Cygwin terminal, adjust the environment variables
+    AdjustPathForMSYSIfNeeded();
+    
+    // determine if the 'upgrade' frame needs to be started instead of the 
+    // standard main frame
+    bool needsLexerLoadedEvent(false);
+    if(ColoursAndFontsManager::Get().IsUpgradeNeeded()) {
+        clInitializeDialog initDialog(NULL);
+        SetTopWindow(&initDialog);
+        initDialog.ShowModal();
+        needsLexerLoadedEvent = true;
+    } else {
+        // Make sure that the colours and fonts manager is instantiated
+        ColoursAndFontsManager::Get().Load();
+    }
+    
     // Create the main application window
-    clMainFrame::Initialize( parser.GetParamCount() == 0 );
+    clMainFrame::Initialize(parser.GetParamCount() == 0);
     m_pMainFrame = clMainFrame::Get();
     m_pMainFrame->Show(TRUE);
     SetTopWindow(m_pMainFrame);
-
+    
+    if (needsLexerLoadedEvent) {
+        // Though a wxEVT_COLOURS_AND_FONTS_LOADED will already have been sent, it won't have done anything because
+        // the frame wasn't instantiated/Connect()ed at that time. So a session won't be loaded unless...
+        clColourEvent event(wxEVT_COLOURS_AND_FONTS_LOADED);
+        EventNotifier::Get()->AddPendingEvent(event);
+    }
+    
     long lineNumber(0);
     parser.Found(wxT("l"), &lineNumber);
-    if (lineNumber > 0) {
+    if(lineNumber > 0) {
         lineNumber--;
     } else {
         lineNumber = 0;
     }
 
-    for (size_t i=0; i< parser.GetParamCount(); i++) {
+    for(size_t i = 0; i < parser.GetParamCount(); i++) {
         wxString argument = parser.GetParam(i);
 
-        //convert to full path and open it
+        // convert to full path and open it
         wxFileName fn(argument);
         fn.MakeAbsolute(ManagerST::Get()->GetOriginalCwd());
 
-        if (fn.GetExt() == wxT("workspace")) {
+        if(fn.GetExt() == wxT("workspace")) {
             ManagerST::Get()->OpenWorkspace(fn.GetFullPath());
         } else {
             clMainFrame::Get()->GetMainBook()->OpenFile(fn.GetFullPath(), wxEmptyString, lineNumber);
@@ -620,11 +700,11 @@ bool CodeLiteApp::OnInit()
     }
 
     wxLogMessage(wxString::Format(wxT("Install path: %s"), ManagerST::Get()->GetInstallDir().c_str()));
-    wxLogMessage(wxString::Format(wxT("Startup Path: %s"), ManagerST::Get()->GetStarupDirectory().c_str()));
+    wxLogMessage(wxString::Format(wxT("Startup Path: %s"), ManagerST::Get()->GetStartupDirectory().c_str()));
 
 #ifdef __WXGTK__
     // Needed on GTK
-    if (clMainFrame::Get()->GetMainBook()->GetActiveEditor() == NULL) {
+    if(clMainFrame::Get()->GetMainBook()->GetActiveEditor() == NULL) {
         clMainFrame::Get()->GetOutputPane()->GetBuildTab()->SetFocus();
     }
 #endif
@@ -644,7 +724,7 @@ int CodeLiteApp::OnExit()
     return 0;
 }
 
-bool CodeLiteApp::CopySettings(const wxString &destDir, wxString& installPath)
+bool CodeLiteApp::CopySettings(const wxString& destDir, wxString& installPath)
 {
     wxLogNull noLog;
 
@@ -653,8 +733,8 @@ bool CodeLiteApp::CopySettings(const wxString &destDir, wxString& installPath)
     // /usr/local/share/codelite/ (Linux) or at codelite.app/Contents/SharedSupport
     ///////////////////////////////////////////////////////////////////////////////////////////
     CopyDir(installPath + wxT("/templates/"), destDir + wxT("/templates/"));
-    massCopy  (installPath + wxT("/images/"), wxT("*.png"), destDir + wxT("/images/"));
-    //wxCopyFile(installPath + wxT("/rc/menu.xrc"), destDir + wxT("/rc/menu.xrc"));
+    massCopy(installPath + wxT("/images/"), wxT("*.png"), destDir + wxT("/images/"));
+    // wxCopyFile(installPath + wxT("/rc/menu.xrc"), destDir + wxT("/rc/menu.xrc"));
     wxCopyFile(installPath + wxT("/index.html"), destDir + wxT("/index.html"));
     wxCopyFile(installPath + wxT("/svnreport.html"), destDir + wxT("/svnreport.html"));
     wxCopyFile(installPath + wxT("/astyle.sample"), destDir + wxT("/astyle.sample"));
@@ -676,34 +756,32 @@ void CodeLiteApp::OnFatalException()
 #endif
 }
 
-bool CodeLiteApp::IsSingleInstance(const wxCmdLineParser &parser, const wxString &curdir)
+bool CodeLiteApp::IsSingleInstance(const wxCmdLineParser& parser, const wxString& curdir)
 {
     // check for single instance
-    if ( clConfig::Get().Read("SingleInstance", false) ) {
+    if(clConfig::Get().Read(kConfigSingleInstance, false)) {
         const wxString name = wxString::Format(wxT("CodeLite-%s"), wxGetUserId().c_str());
 
         m_singleInstance = new wxSingleInstanceChecker(name);
-        if (m_singleInstance->IsAnotherRunning()) {
+        if(m_singleInstance->IsAnotherRunning()) {
             // prepare commands file for the running instance
             wxString files;
-            for (size_t i=0; i< parser.GetParamCount(); i++) {
+            for(size_t i = 0; i < parser.GetParamCount(); i++) {
                 wxString argument = parser.GetParam(i);
 
-                //convert to full path and open it
+                // convert to full path and open it
                 wxFileName fn(argument);
                 fn.MakeAbsolute(curdir);
                 files << fn.GetFullPath() << wxT("\n");
             }
 
-            if (files.IsEmpty() == false) {
-                Mkdir(ManagerST::Get()->GetStarupDirectory() + wxT("/ipc"));
+            if(files.IsEmpty() == false) {
+                Mkdir(ManagerST::Get()->GetStartupDirectory() + wxT("/ipc"));
 
                 wxString file_name, tmp_file;
-                tmp_file 	<< ManagerST::Get()->GetStarupDirectory()
-                            << wxT("/ipc/command.msg.tmp");
+                tmp_file << ManagerST::Get()->GetStartupDirectory() << wxT("/ipc/command.msg.tmp");
 
-                file_name 	<< ManagerST::Get()->GetStarupDirectory()
-                            << wxT("/ipc/command.msg");
+                file_name << ManagerST::Get()->GetStartupDirectory() << wxT("/ipc/command.msg");
 
                 // write the content to a temporary file, once completed,
                 // rename the file to the actual file name
@@ -718,7 +796,7 @@ bool CodeLiteApp::IsSingleInstance(const wxCmdLineParser &parser, const wxString
 
 void CodeLiteApp::MacOpenFile(const wxString& fileName)
 {
-    switch (FileExtManager::GetType(fileName)) {
+    switch(FileExtManager::GetType(fileName)) {
     case FileExtManager::TypeWorkspace:
         ManagerST::Get()->OpenWorkspace(fileName);
         break;
@@ -754,39 +832,38 @@ void CodeLiteApp::MSWReadRegistry()
     wxString iniFile;
     iniFile << ManagerST::Get()->GetInstallDir() << wxFileName::GetPathSeparator() << wxT("registry.ini");
 
-    if ( wxFileName::FileExists(iniFile) ) {
+    if(wxFileName::FileExists(iniFile)) {
         clRegistry::SetFilename(iniFile);
         clRegistry registry;
 
         m_parserPaths.Clear();
         wxString strWx, strMingw, strUnitTestPP;
-        //registry.Read(wxT("wx"),         strWx);
-        registry.Read(wxT("mingw"),      strMingw);
+        // registry.Read(wxT("wx"),         strWx);
+        registry.Read(wxT("mingw"), strMingw);
         registry.Read(wxT("unittestpp"), strUnitTestPP);
 
         // Supprot for wxWidgets
-        if (strWx.IsEmpty() == false) {
+        if(strWx.IsEmpty() == false) {
             // we have WX installed on this machine, set the path of WXWIN & WXCFG to point to it
             EnvMap envs = vars.GetVariables(wxT("Default"), false, wxT(""));
 
-            if ( !envs.Contains(wxT("WXWIN")) ) {
+            if(!envs.Contains(wxT("WXWIN"))) {
                 vars.AddVariable(wxT("Default"), wxT("WXWIN"), strWx);
-                vars.AddVariable(wxT("Default"), wxT("PATH"),  wxT("$(WXWIN)\\lib\\gcc_dll;$(PATH)"));
+                vars.AddVariable(wxT("Default"), wxT("PATH"), wxT("$(WXWIN)\\lib\\gcc_dll;$(PATH)"));
             }
 
-            if ( !envs.Contains(wxT("WXCFG")) )
-                vars.AddVariable(wxT("Default"), wxT("WXCFG"), wxT("gcc_dll\\mswu"));
+            if(!envs.Contains(wxT("WXCFG"))) vars.AddVariable(wxT("Default"), wxT("WXCFG"), wxT("gcc_dll\\mswu"));
 
             EnvironmentConfig::Instance()->WriteObject(wxT("Variables"), &vars);
             wxSetEnv(wxT("WX_INCL_HOME"), strWx + wxT("\\include"));
         }
 
         // Support for UnitTest++
-        if (strUnitTestPP.IsEmpty() == false) {
+        if(strUnitTestPP.IsEmpty() == false) {
             // we have UnitTest++ installed on this machine
             EnvMap envs = vars.GetVariables(wxT("Default"), false, wxT(""));
 
-            if (!envs.Contains(wxT("UNIT_TEST_PP_SRC_DIR")) ) {
+            if(!envs.Contains(wxT("UNIT_TEST_PP_SRC_DIR"))) {
                 vars.AddVariable(wxT("Default"), wxT("UNIT_TEST_PP_SRC_DIR"), strUnitTestPP);
             }
 
@@ -794,10 +871,10 @@ void CodeLiteApp::MSWReadRegistry()
         }
 
         // Support for MinGW
-        if (strMingw.IsEmpty() == false) {
+        if(strMingw.IsEmpty() == false) {
             // Make sure that codelite's MinGW comes first before any other
             // MinGW installation that might exist on the machine
-            strMingw << wxFileName::GetPathSeparator() <<  wxT("bin;");
+            strMingw << wxFileName::GetPathSeparator() << wxT("bin;");
             pathEnv.Prepend(strMingw);
         }
         wxSetEnv(wxT("PATH"), pathEnv);
@@ -805,10 +882,12 @@ void CodeLiteApp::MSWReadRegistry()
 #endif
 }
 
-wxString CodeLiteApp::DoFindMenuFile(const wxString& installDirectory, const wxString &requiredVersion)
+wxString CodeLiteApp::DoFindMenuFile(const wxString& installDirectory, const wxString& requiredVersion)
 {
-    wxString defaultMenuFile = installDirectory + wxFileName::GetPathSeparator() + wxT("rc") + wxFileName::GetPathSeparator() + wxT("menu.xrc");
-    wxFileName menuFile(clStandardPaths::Get().GetUserDataDir() + wxFileName::GetPathSeparator() + wxT("rc") + wxFileName::GetPathSeparator() + wxT("menu.xrc"));
+    wxString defaultMenuFile = installDirectory + wxFileName::GetPathSeparator() + wxT("rc") +
+                               wxFileName::GetPathSeparator() + wxT("menu.xrc");
+    wxFileName menuFile(clStandardPaths::Get().GetUserDataDir() + wxFileName::GetPathSeparator() + wxT("rc") +
+                        wxFileName::GetPathSeparator() + wxT("menu.xrc"));
     if(menuFile.FileExists()) {
         // if we find the user's file menu, check that it has the required version
         {
@@ -832,7 +911,12 @@ void CodeLiteApp::DoCopyGdbPrinters()
 #ifdef __WXGTK__
     printersInstallDir = wxFileName(wxString(INSTALL_DIR, wxConvUTF8), "gdb_printers");
 #else
+#   ifdef USE_POSIX_LAYOUT
+    wxString commdir(wxStandardPaths::Get().GetDataDir() + wxT( INSTALL_DIR ));
+    printersInstallDir = wxFileName(commdir, "gdb_printers");
+#   else
     printersInstallDir = wxFileName(wxStandardPaths::Get().GetDataDir(), "gdb_printers");
+#   endif
 #endif
 
     // copy the files to ~/.codelite/gdb_printers
@@ -846,14 +930,16 @@ void CodeLiteApp::AdjustPathForCygwinIfNeeded()
 {
 #ifdef __WXMSW__
     CL_DEBUG("AdjustPathForCygwinIfNeeded called");
-    if ( !::clIsCygwinEnvironment() ) {
+    if(!::clIsCygwinEnvironment()) {
         CL_DEBUG("Not running under Cygwin - nothing be done");
         return;
     }
-
+    
+    CL_SYSTEM("Cygwin environment detected");
+    
     wxString cygwinRootDir;
     CompilerLocatorCygwin cygwin;
-    if ( cygwin.Locate() ) {
+    if(cygwin.Locate()) {
         // this will return the base folder for cygwin (e.g. D:\cygwin)
         cygwinRootDir = (*cygwin.GetCompilers().begin())->GetInstallationPath();
     }
@@ -865,8 +951,9 @@ void CodeLiteApp::AdjustPathForCygwinIfNeeded()
 
     // Always add the default paths
     wxArrayString paths;
-    if ( !cygwinRootDir.IsEmpty() ) {
-        wxFileName cygwinBinFolder(cygwinRootDir, "" );
+    if(!cygwinRootDir.IsEmpty()) {
+        CL_SYSTEM("Cygwin root folder is: %s", cygwinRootDir);
+        wxFileName cygwinBinFolder(cygwinRootDir, "");
         cygwinBinFolder.AppendDir("bin");
         paths.Add(cygwinBinFolder.GetPath());
     }
@@ -882,14 +969,14 @@ void CodeLiteApp::AdjustPathForCygwinIfNeeded()
     paths.insert(paths.end(), userPaths.begin(), userPaths.end());
 
     wxString fixedPath;
-    for(size_t i=0; i<paths.GetCount(); ++i) {
-        wxString &curpath = paths.Item(i);
+    for(size_t i = 0; i < paths.GetCount(); ++i) {
+        wxString& curpath = paths.Item(i);
         static wxRegEx reCygdrive("/cygdrive/([A-Za-z])");
-        if ( reCygdrive.Matches(curpath) ) {
+        if(reCygdrive.Matches(curpath)) {
             // Get the drive letter
             wxString volume = reCygdrive.GetMatch(curpath, 1);
             volume << ":";
-            reCygdrive.Replace( &curpath, volume );
+            reCygdrive.Replace(&curpath, volume);
         }
 
         fixedPath << curpath << ";";
@@ -899,3 +986,48 @@ void CodeLiteApp::AdjustPathForCygwinIfNeeded()
     ::wxSetEnv("PATH", fixedPath);
 #endif
 }
+
+void CodeLiteApp::AdjustPathForMSYSIfNeeded()
+{
+#ifdef __WXMSW__
+    CL_DEBUG("AdjustPathForMSYSIfNeeded called");
+    if(!::clIsMSYSEnvironment()) {
+        CL_DEBUG("Not running under MSYS - nothing be done");
+        return;
+    }
+    
+    CL_SYSTEM("MSYS environment detected");
+    
+    // Running under Cygwin
+    // Adjust the PATH environment variable
+    wxString pathEnv;
+    ::wxGetEnv("PATH", &pathEnv);
+
+    // Always add the default paths
+    wxArrayString paths;
+
+    wxString rootDir = "/"; // Default
+    // determine the baseroot of the MSYS installation
+    wxString msysRoot = ProcUtils::SafeExecuteCommand("sh -c 'cd / && pwd -W'");
+    if(!msysRoot.IsEmpty()) {
+        CL_SYSTEM("MSYS Root folder is set to: %s", msysRoot);
+        msysRoot.Trim().Trim(false);
+        rootDir.Clear();
+        rootDir << msysRoot << "/";
+    }
+
+    paths.Add(rootDir + "usr/local/bin");
+    paths.Add(rootDir + "usr/bin");
+    paths.Add(rootDir + "usr/sbin");
+    paths.Add(rootDir + "bin");
+    paths.Add(rootDir + "sbin");
+
+    // Append the paths from the environment variables
+    wxArrayString userPaths = ::wxStringTokenize(pathEnv, ";", wxTOKEN_STRTOK);
+    paths.insert(paths.end(), userPaths.begin(), userPaths.end());
+
+    wxString fixedPath = ::wxJoin(paths, ';');
+    CL_DEBUG("Setting PATH environment variable to:\n%s", fixedPath);
+    ::wxSetEnv("PATH", fixedPath);
+#endif
+}
