@@ -54,15 +54,25 @@
 #include "plugin.h"
 #include "event_notifier.h"
 #include "workspacetab.h"
+#include "globals.h"
 
 BEGIN_EVENT_TABLE(ProjectSettingsDlg, ProjectSettingsBaseDlg)
 END_EVENT_TABLE()
 
-ProjectSettingsDlg::ProjectSettingsDlg( wxWindow* parent, WorkspaceTab* workspaceTab, const wxString &configName, const wxString &projectName, const wxString &title )
+ProjectSettingsDlg::ProjectSettingsDlg(wxWindow* parent,
+                                       WorkspaceTab* workspaceTab,
+                                       const wxString& configName,
+                                       const wxString& projectName,
+                                       const wxString& title)
 #ifdef __WXMAC__
-    : ProjectSettingsBaseDlg( parent, wxID_ANY, title, wxDefaultPosition, wxDefaultSize, wxDEFAULT_DIALOG_STYLE|wxRESIZE_BORDER )
+    : ProjectSettingsBaseDlg(parent,
+                             wxID_ANY,
+                             title,
+                             wxDefaultPosition,
+                             wxDefaultSize,
+                             wxDEFAULT_DIALOG_STYLE | wxRESIZE_BORDER)
 #else
-    : ProjectSettingsBaseDlg( parent, wxID_ANY, title )
+    : ProjectSettingsBaseDlg(parent, wxID_ANY, title)
 #endif
     , m_projectName(projectName)
     , m_configName(configName)
@@ -72,7 +82,7 @@ ProjectSettingsDlg::ProjectSettingsDlg( wxWindow* parent, WorkspaceTab* workspac
     , m_workspaceTab(workspaceTab)
 {
     DoGetAllBuildConfigs();
-    MSWSetNativeTheme( m_treebook->GetTreeCtrl() );
+    MSWSetNativeTheme(m_treebook->GetTreeCtrl());
     BuildTree();
     LoadValues(m_configName);
 
@@ -89,14 +99,16 @@ ProjectSettingsDlg::ProjectSettingsDlg( wxWindow* parent, WorkspaceTab* workspac
         GetSizer()->Fit(this);
     }
 
-    EventNotifier::Get()->Connect(wxEVT_PROJECT_TREEITEM_CLICKED, wxCommandEventHandler(ProjectSettingsDlg::OnProjectSelected), NULL, this);
-    EventNotifier::Get()->Connect(wxEVT_WORKSPACE_CLOSED, wxCommandEventHandler(ProjectSettingsDlg::OnWorkspaceClosed), NULL, this);
-    
+    EventNotifier::Get()->Connect(
+        wxEVT_PROJECT_TREEITEM_CLICKED, wxCommandEventHandler(ProjectSettingsDlg::OnProjectSelected), NULL, this);
+    EventNotifier::Get()->Connect(
+        wxEVT_WORKSPACE_CLOSED, wxCommandEventHandler(ProjectSettingsDlg::OnWorkspaceClosed), NULL, this);
+
     // No effects plz
     m_infobar->SetShowHideEffects(wxSHOW_EFFECT_NONE, wxSHOW_EFFECT_NONE);
-    
+
     ShowHideDisabledMessage();
-    //ShowCustomProjectMessage( IsCustomBuildEnabled() );
+    // ShowCustomProjectMessage( IsCustomBuildEnabled() );
 }
 
 void ProjectSettingsDlg::DoClearDialog()
@@ -107,45 +119,56 @@ void ProjectSettingsDlg::DoClearDialog()
 
 void ProjectSettingsDlg::BuildTree()
 {
-    wxString selectedPage = EditorConfigST::Get()->GetStringValue(wxT("PSSelectedPage"));
+    wxString selectedPage = EditorConfigST::Get()->GetString(wxT("PSSelectedPage"));
     if(selectedPage.IsEmpty()) {
         selectedPage = _("General");
     }
 
-    PSGeneralPage *gp = new PSGeneralPage(m_treebook, m_projectName, m_choiceConfig->GetStringSelection(), this);
+    PSGeneralPage* gp = new PSGeneralPage(m_treebook, m_projectName, m_choiceConfig->GetStringSelection(), this);
     m_treebook->AddPage(0, _("Common Settings"));
-    m_treebook->AddSubPage(gp,                                                       _("General"),               selectedPage == _("General"));
-    m_treebook->AddSubPage(new PSCompilerPage(m_treebook, m_projectName, this, gp),  _("Compiler"),              selectedPage == _("Compiler"));
-    m_treebook->AddSubPage(new PSLinkerPage(m_treebook, this, gp),                   _("Linker"),                selectedPage == _("Linker"));
-    m_treebook->AddSubPage(new PSEnvironmentPage(m_treebook, this),                  _("Environment"),           selectedPage == _("Environment"));
-    m_treebook->AddSubPage(new PSDebuggerPage(m_treebook, this),                     _("Debugger"),              selectedPage == _("Debugger"));
-    m_treebook->AddSubPage(new PSResourcesPage(m_treebook, this),                    _("Resources"),             selectedPage == _("Resources"));
+    m_treebook->AddSubPage(gp, _("General"), selectedPage == _("General"));
+    m_treebook->AddSubPage(
+        new PSCompilerPage(m_treebook, m_projectName, this, gp), _("Compiler"), selectedPage == _("Compiler"));
+    m_treebook->AddSubPage(new PSLinkerPage(m_treebook, this, gp), _("Linker"), selectedPage == _("Linker"));
+    m_treebook->AddSubPage(new PSEnvironmentPage(m_treebook, this), _("Environment"), selectedPage == _("Environment"));
+    m_treebook->AddSubPage(new PSDebuggerPage(m_treebook, this), _("Debugger"), selectedPage == _("Debugger"));
+    m_treebook->AddSubPage(new PSResourcesPage(m_treebook, this), _("Resources"), selectedPage == _("Resources"));
 
     m_treebook->AddPage(0, _("Pre / Post Build Commands"));
-    m_treebook->AddSubPage(new PSBuildEventsPage(m_treebook, true, this),            _("Pre Build"),             selectedPage == _("Pre Build"));
-    m_treebook->AddSubPage(new PSBuildEventsPage(m_treebook, false, this),           _("Post Build"),            selectedPage == _("Post Build"));
+    m_treebook->AddSubPage(
+        new PSBuildEventsPage(m_treebook, true, this), _("Pre Build"), selectedPage == _("Pre Build"));
+    m_treebook->AddSubPage(
+        new PSBuildEventsPage(m_treebook, false, this), _("Post Build"), selectedPage == _("Post Build"));
 
     m_treebook->AddPage(0, _("Customize"));
-    m_treebook->AddSubPage(new PSCustomBuildPage(m_treebook, m_projectName, this),   _("Custom Build"),          selectedPage == _("Custom Build"));
-    m_treebook->AddSubPage(new PSCustomMakefileRulesPage(m_treebook, this),          _("Custom Makefile Rules"), selectedPage == _("Custom Makefile Rules"));
+    m_treebook->AddSubPage(
+        new PSCustomBuildPage(m_treebook, m_projectName, this), _("Custom Build"), selectedPage == _("Custom Build"));
+    m_treebook->AddSubPage(new PSCustomMakefileRulesPage(m_treebook, this),
+                           _("Custom Makefile Rules"),
+                           selectedPage == _("Custom Makefile Rules"));
 
-    m_treebook->AddPage(new PSCompletionPage(m_treebook, this), _("Code Completion"), selectedPage == _("Code Completion"));
-    m_treebook->AddPage(new GlobalSettingsPanel(m_treebook, m_projectName, this, gp), _("Global Settings"),      selectedPage == _("Global Settings"));
+    m_treebook->AddPage(
+        new PSCompletionPage(m_treebook, this), _("Code Completion"), selectedPage == _("Code Completion"));
+    m_treebook->AddPage(new GlobalSettingsPanel(m_treebook, m_projectName, this, gp),
+                        _("Global Settings"),
+                        selectedPage == _("Global Settings"));
 }
 
 ProjectSettingsDlg::~ProjectSettingsDlg()
 {
     m_workspaceTab->ProjectSettingsDlgClosed();
 
-    EventNotifier::Get()->Disconnect(wxEVT_PROJECT_TREEITEM_CLICKED, wxCommandEventHandler(ProjectSettingsDlg::OnProjectSelected), NULL, this);
-    EventNotifier::Get()->Disconnect(wxEVT_WORKSPACE_CLOSED, wxCommandEventHandler(ProjectSettingsDlg::OnWorkspaceClosed), NULL, this);
+    EventNotifier::Get()->Disconnect(
+        wxEVT_PROJECT_TREEITEM_CLICKED, wxCommandEventHandler(ProjectSettingsDlg::OnProjectSelected), NULL, this);
+    EventNotifier::Get()->Disconnect(
+        wxEVT_WORKSPACE_CLOSED, wxCommandEventHandler(ProjectSettingsDlg::OnWorkspaceClosed), NULL, this);
 
     PluginManager::Get()->UnHookProjectSettingsTab(m_treebook, m_projectName, wxEmptyString /* all tabs */);
-    EditorConfigST::Get()->SaveStringValue(wxT("PSSelectedPage"), m_treebook->GetPageText(m_treebook->GetSelection()));
+    EditorConfigST::Get()->SetString(wxT("PSSelectedPage"), m_treebook->GetPageText(m_treebook->GetSelection()));
     WindowAttrManager::Save(this, wxT("ProjectSettingsDlg"), NULL);
 }
 
-void ProjectSettingsDlg::OnButtonOK(wxCommandEvent &event)
+void ProjectSettingsDlg::OnButtonOK(wxCommandEvent& event)
 {
     event.Skip();
     OnButtonApply(event);
@@ -155,7 +178,7 @@ void ProjectSettingsDlg::OnButtonOK(wxCommandEvent &event)
 #endif
 }
 
-void ProjectSettingsDlg::OnButtonApply(wxCommandEvent &event)
+void ProjectSettingsDlg::OnButtonApply(wxCommandEvent& event)
 {
     wxUnusedVar(event);
     SaveValues();
@@ -168,25 +191,28 @@ void ProjectSettingsDlg::SaveValues()
 
     ProjectSettingsPtr projSettingsPtr = ManagerST::Get()->GetProjectSettings(m_projectName);
     BuildConfigPtr buildConf = projSettingsPtr->GetBuildConfiguration(m_configName);
-    if (!buildConf) {
+    if(!buildConf) {
         return;
     }
 
     size_t pageCount = m_treebook->GetPageCount();
-    for(size_t i=0; i<pageCount; i++) {
-        wxWindow *page = m_treebook->GetPage(i);
+    for(size_t i = 0; i < pageCount; i++) {
+        wxWindow* page = m_treebook->GetPage(i);
         if(!page) continue;
-        IProjectSettingsPage *p = dynamic_cast<IProjectSettingsPage*>(page);
+        IProjectSettingsPage* p = dynamic_cast<IProjectSettingsPage*>(page);
         if(p) {
             p->Save(buildConf, projSettingsPtr);
         }
     }
 
-    //save settings
+    // save settings
     ManagerST::Get()->SetProjectSettings(m_projectName, projSettingsPtr);
 
     // Notify the plugins to save their data
-    SendCmdEvent(wxEVT_CMD_PROJ_SETTINGS_SAVED, (void*)&m_projectName, m_configName);
+    clProjectSettingsEvent eventProjSettingsSaved(wxEVT_CMD_PROJ_SETTINGS_SAVED);
+    eventProjSettingsSaved.SetProjectName(m_projectName);
+    eventProjSettingsSaved.SetConfigName(m_configName);
+    EventNotifier::Get()->AddPendingEvent(eventProjSettingsSaved);
 }
 
 void ProjectSettingsDlg::LoadValues(const wxString& configName)
@@ -197,26 +223,31 @@ void ProjectSettingsDlg::LoadValues(const wxString& configName)
     BuildConfigPtr buildConf;
     ProjectSettingsPtr projSettingsPtr = ManagerST::Get()->GetProjectSettings(m_projectName);
     buildConf = projSettingsPtr->GetBuildConfiguration(configName);
-    if (!buildConf) {
+    if(!buildConf) {
         return;
     }
-    
-    if ( buildConf->GetProjectType().IsEmpty() ) {
-        // no project type is defined by the 
-        buildConf->SetProjectType( projSettingsPtr->GetProjectType(wxEmptyString) );
+
+    if(buildConf->GetProjectType().IsEmpty()) {
+        // no project type is defined by the
+        buildConf->SetProjectType(projSettingsPtr->GetProjectType(wxEmptyString));
     }
     size_t pageCount = m_treebook->GetPageCount();
-    for(size_t i=0; i<pageCount; i++) {
-        wxWindow *page = m_treebook->GetPage(i);
-        if (!page)                                       continue; // NULL page ...
-        IProjectSettingsPage *p = dynamic_cast<IProjectSettingsPage*>(page);
+    for(size_t i = 0; i < pageCount; i++) {
+        wxWindow* page = m_treebook->GetPage(i);
+        if(!page) continue; // NULL page ...
+        IProjectSettingsPage* p = dynamic_cast<IProjectSettingsPage*>(page);
         if(p) {
+            GlobalSettingsPanel* globalPage = dynamic_cast<GlobalSettingsPanel*>(page);
+            if(globalPage) {
+                // update the project name
+                //globalPage->SetProjectName(m_projectName);
+            }
             p->Load(buildConf);
         }
     }
 
-    if( sel != wxNOT_FOUND ) {
-        m_treebook->SetSelection( sel );
+    if(sel != wxNOT_FOUND) {
+        m_treebook->SetSelection(sel);
     }
     m_isDirty = false;
 }
@@ -224,11 +255,11 @@ void ProjectSettingsDlg::LoadValues(const wxString& configName)
 void ProjectSettingsDlg::ClearValues()
 {
     size_t pageCount = m_treebook->GetPageCount();
-    for(size_t i=0; i<pageCount; i++) {
-        wxWindow *page = m_treebook->GetPage(i);
+    for(size_t i = 0; i < pageCount; i++) {
+        wxWindow* page = m_treebook->GetPage(i);
         if(!page) continue;
 
-        IProjectSettingsPage *p = dynamic_cast<IProjectSettingsPage*>(page);
+        IProjectSettingsPage* p = dynamic_cast<IProjectSettingsPage*>(page);
         if(p) {
             p->Clear();
         }
@@ -251,14 +282,16 @@ void ProjectSettingsDlg::OnButtonHelp(wxCommandEvent& e)
 
 void ProjectSettingsDlg::OnButtonApplyUI(wxUpdateUIEvent& event)
 {
-    event.Enable( GetIsDirty() );
+    event.Enable(GetIsDirty());
 }
 
 void ProjectSettingsDlg::OnConfigurationChanged(wxCommandEvent& event)
 {
     event.Skip();
     if(m_isDirty) {
-        if(wxMessageBox(_("Save changes before loading new configuration?"), _("Save Changes"), wxICON_QUESTION|wxYES_NO|wxCENTER) == wxYES) {
+        if(wxMessageBox(_("Save changes before loading new configuration?"),
+                        _("Save Changes"),
+                        wxICON_QUESTION | wxYES_NO | wxCENTER) == wxYES) {
             SaveValues();
         } else {
             ClearValues();
@@ -283,8 +316,10 @@ void ProjectSettingsDlg::OnProjectSelected(wxCommandEvent& e)
     CHECK_PTR_RET(bldConf);
 
     if(m_isDirty) {
-        int answer = ::wxMessageBox(_("Save changes before loading new configuration?"), _("Save Changes"), wxICON_QUESTION|wxYES_NO|wxCANCEL|wxCENTER);
-        switch ( answer ) {
+        int answer = ::wxMessageBox(_("Save changes before loading new configuration?"),
+                                    _("Save Changes"),
+                                    wxICON_QUESTION | wxYES_NO | wxCANCEL | wxCENTER);
+        switch(answer) {
         case wxYES:
             SaveValues();
             break;
@@ -300,10 +335,10 @@ void ProjectSettingsDlg::OnProjectSelected(wxCommandEvent& e)
 
     // another project was selected in the tree view
     m_projectName = e.GetString();
-    m_configName  = bldConf->GetName();
+    m_configName = bldConf->GetName();
 
     // determine the correct configuration to load
-    SetTitle( wxString() << m_projectName << " Project Settings" );
+    SetTitle(wxString() << m_projectName << " Project Settings");
 
     DoGetAllBuildConfigs();
     LoadValues(m_configName);
@@ -316,7 +351,7 @@ void ProjectSettingsDlg::DoGetAllBuildConfigs()
     ProjectSettingsPtr projSettingsPtr = ManagerST::Get()->GetProjectSettings(m_projectName);
     ProjectSettingsCookie cookie;
     BuildConfigPtr conf = projSettingsPtr->GetFirstBuildConfiguration(cookie);
-    while (conf) {
+    while(conf) {
         configs.Add(conf->GetName());
         conf = projSettingsPtr->GetNextBuildConfiguration(cookie);
     }
@@ -327,7 +362,7 @@ void ProjectSettingsDlg::DoGetAllBuildConfigs()
 
         m_choiceConfig->SetSelection(where);
 
-    } else if ( !m_choiceConfig->IsEmpty() ) {
+    } else if(!m_choiceConfig->IsEmpty()) {
 
         m_configName = m_choiceConfig->GetString(0);
         m_choiceConfig->SetSelection(0);
@@ -343,7 +378,6 @@ void ProjectSettingsDlg::OnWorkspaceClosed(wxCommandEvent& e)
 #ifndef __WXMAC__
     Destroy();
 #endif
-
 }
 
 void ProjectSettingsDlg::OnButtonCancel(wxCommandEvent& event)
@@ -352,12 +386,11 @@ void ProjectSettingsDlg::OnButtonCancel(wxCommandEvent& event)
 #ifndef __WXMAC__
     Destroy();
 #endif
-
 }
 
 void ProjectSettingsDlg::ShowHideDisabledMessage()
 {
-    if ( !m_isProjectEnabled ) {
+    if(!m_isProjectEnabled) {
         m_infobar->ShowMessage(_("This project is disabled"), wxICON_WARNING);
     } else {
         m_infobar->Dismiss();
@@ -366,8 +399,10 @@ void ProjectSettingsDlg::ShowHideDisabledMessage()
 
 void ProjectSettingsDlg::ShowCustomProjectMessage(bool show)
 {
-    if ( show ) {
-        m_infobar->ShowMessage(_("Settings on this page are disabled because this project is setup as \"Custom Build\" project"), wxICON_INFORMATION);
+    if(show) {
+        m_infobar->ShowMessage(
+            _("Settings on this page are disabled because this project is setup as \"Custom Build\" project"),
+            wxICON_INFORMATION);
     } else {
         m_infobar->Dismiss();
     }
@@ -375,25 +410,19 @@ void ProjectSettingsDlg::ShowCustomProjectMessage(bool show)
 void ProjectSettingsDlg::OnPageChanged(wxTreebookEvent& event)
 {
     event.Skip();
-    
+
     // Do nothing if the project is disabled
-    if ( !IsProjectEnabled() )
-        return; 
+    if(!IsProjectEnabled()) return;
 
     int sel = m_treebook->GetSelection();
-    if ( sel != wxNOT_FOUND && IsCustomBuildEnabled() ) {
-        wxWindow *page = m_treebook->GetPage(sel);
-        
-        if ( !page                                  || 
-             dynamic_cast<PSCustomBuildPage*>(page) ||
-             dynamic_cast<PSGeneralPage*>(page)     ||
-             dynamic_cast<PSBuildEventsPage*>(page) ||
-             dynamic_cast<PSEnvironmentPage*>(page) ||
-             dynamic_cast<PSDebuggerPage*>(page)    ||
-             dynamic_cast<PSCompletionPage*>(page)
-             ) {
+    if(sel != wxNOT_FOUND && IsCustomBuildEnabled()) {
+        wxWindow* page = m_treebook->GetPage(sel);
+
+        if(!page || dynamic_cast<PSCustomBuildPage*>(page) || dynamic_cast<PSGeneralPage*>(page) ||
+           dynamic_cast<PSBuildEventsPage*>(page) || dynamic_cast<PSEnvironmentPage*>(page) ||
+           dynamic_cast<PSDebuggerPage*>(page) || dynamic_cast<PSCompletionPage*>(page)) {
             ShowCustomProjectMessage(false);
-            
+
         } else {
             ShowCustomProjectMessage(true);
         }
@@ -405,7 +434,10 @@ void ProjectSettingsDlg::OnPageChanged(wxTreebookEvent& event)
 ///////////////////////////////////////////////////////////////////////////
 ///////////////////////////////////////////////////////////////////////////
 
-GlobalSettingsPanel::GlobalSettingsPanel(wxWindow* parent, const wxString &projectName, ProjectSettingsDlg *dlg, PSGeneralPage* gp)
+GlobalSettingsPanel::GlobalSettingsPanel(wxWindow* parent,
+                                         const wxString& projectName,
+                                         ProjectSettingsDlg* dlg,
+                                         PSGeneralPage* gp)
     : GlobalSettingsBasePanel(parent)
     , m_projectName(projectName)
     , m_dlg(dlg)
@@ -413,14 +445,14 @@ GlobalSettingsPanel::GlobalSettingsPanel(wxWindow* parent, const wxString &proje
 {
     GetSizer()->Fit(this);
     Centre();
-    m_pgMgr->GetGrid()->SetPropertyAttributeAll(wxPG_BOOL_USE_CHECKBOX, true);
+    ::wxPGPropertyBooleanUseCheckbox(m_pgMgr->GetGrid());
 }
 
 void GlobalSettingsPanel::Clear()
 {
     wxPropertyGridIterator iter = m_pgMgr->GetGrid()->GetIterator();
-    for( ; !iter.AtEnd(); ++iter ) {
-        if ( iter.GetProperty() && !iter.GetProperty()->IsCategory() ) {
+    for(; !iter.AtEnd(); ++iter) {
+        if(iter.GetProperty() && !iter.GetProperty()->IsCategory()) {
             iter.GetProperty()->SetValueToUnspecified();
         }
     }
@@ -430,20 +462,20 @@ void GlobalSettingsPanel::Load(BuildConfigPtr buildConf)
 {
     ProjectSettingsPtr projSettingsPtr = ManagerST::Get()->GetProjectSettings(m_projectName);
     BuildConfigCommonPtr globalSettings = projSettingsPtr->GetGlobalSettings();
-    if (!globalSettings) {
+    if(!globalSettings) {
         Clear();
         return;
     }
 
-    m_pgPropCCmpOpts->SetValue( globalSettings->GetCCompileOptions() );
-    m_pgPropCppCmpOpts->SetValue( globalSettings->GetCompileOptions() );
-    m_pgPropPreProcessors->SetValue( globalSettings->GetPreprocessor() );
-    m_pgPropIncludePaths->SetValue( globalSettings->GetIncludePath() );
-    m_pgPropOptions->SetValue( globalSettings->GetLinkOptions() );
-    m_pgPropLIbs->SetValue( globalSettings->GetLibraries() );
-    m_pgPropLibPath->SetValue( globalSettings->GetLibPath() );
+    m_pgPropCCmpOpts->SetValue(globalSettings->GetCCompileOptions());
+    m_pgPropCppCmpOpts->SetValue(globalSettings->GetCompileOptions());
+    m_pgPropPreProcessors->SetValue(globalSettings->GetPreprocessor());
+    m_pgPropIncludePaths->SetValue(globalSettings->GetIncludePath());
+    m_pgPropOptions->SetValue(globalSettings->GetLinkOptions());
+    m_pgPropLIbs->SetValue(globalSettings->GetLibraries());
+    m_pgPropLibPath->SetValue(globalSettings->GetLibPath());
     m_pgPropResCmpOptions->SetValue(globalSettings->GetResCompileOptions());
-    m_pgPropResCmpSearchPath->SetValue( globalSettings->GetResCmpIncludePath() );
+    m_pgPropResCmpSearchPath->SetValue(globalSettings->GetResCmpIncludePath());
 }
 
 void GlobalSettingsPanel::Save(BuildConfigPtr buildConf, ProjectSettingsPtr projSettingsPtr)
@@ -452,7 +484,7 @@ void GlobalSettingsPanel::Save(BuildConfigPtr buildConf, ProjectSettingsPtr proj
     wxUnusedVar(projSettingsPtr);
 
     BuildConfigCommonPtr globalSettings = projSettingsPtr->GetGlobalSettings();
-    if (!globalSettings) {
+    if(!globalSettings) {
         return;
     }
 
@@ -468,7 +500,7 @@ void GlobalSettingsPanel::Save(BuildConfigPtr buildConf, ProjectSettingsPtr proj
     globalSettings->SetResCmpIncludePath(m_pgPropResCmpSearchPath->GetValueAsString());
     globalSettings->SetResCmpOptions(m_pgPropResCmpOptions->GetValueAsString());
 
-    //save settings
+    // save settings
     ManagerST::Get()->SetProjectGlobalSettings(m_projectName, globalSettings);
 }
 
@@ -481,26 +513,21 @@ void GlobalSettingsPanel::OnCustomEditorClicked(wxCommandEvent& event)
     wxString cmpName = m_gp->GetCompiler();
     CompilerPtr cmp = BuildSettingsConfigST::Get()->GetCompiler(cmpName);
 
-    if ( prop == m_pgPropCCmpOpts || prop == m_pgPropCppCmpOpts ) {
+    if(prop == m_pgPropCCmpOpts || prop == m_pgPropCppCmpOpts) {
         wxString v = prop->GetValueAsString();
-        if ( PopupAddOptionCheckDlg(v, _("Compiler Options"), cmp->GetCompilerOptions()) ) {
-            prop->SetValueFromString( v );
+        if(PopupAddOptionCheckDlg(v, _("Compiler Options"), cmp->GetCompilerOptions())) {
+            prop->SetValueFromString(v);
         }
-    } else if ( prop == m_pgPropIncludePaths        ||
-                prop == m_pgPropPreProcessors       ||
-                prop == m_pgPropLibPath             ||
-                prop == m_pgPropLIbs                ||
-                prop == m_pgPropResCmpOptions       ||
-                prop == m_pgPropResCmpSearchPath
-              ) {
+    } else if(prop == m_pgPropIncludePaths || prop == m_pgPropPreProcessors || prop == m_pgPropLibPath ||
+              prop == m_pgPropLIbs || prop == m_pgPropResCmpOptions || prop == m_pgPropResCmpSearchPath) {
         wxString v = prop->GetValueAsString();
-        if ( PopupAddOptionDlg( v ) ) {
-            prop->SetValueFromString( v );
+        if(PopupAddOptionDlg(v)) {
+            prop->SetValueFromString(v);
         }
-    } else if ( prop == m_pgPropOptions ) {
+    } else if(prop == m_pgPropOptions) {
         wxString v = prop->GetValueAsString();
-        if ( PopupAddOptionCheckDlg(v, _("Linker Options"), cmp->GetLinkerOptions()) ) {
-            prop->SetValueFromString( v );
+        if(PopupAddOptionCheckDlg(v, _("Linker Options"), cmp->GetLinkerOptions())) {
+            prop->SetValueFromString(v);
         }
     }
 }
@@ -518,7 +545,7 @@ void GlobalSettingsPanel::OnValueChanged(wxPropertyGridEvent& event)
 bool IProjectSettingsPage::PopupAddOptionDlg(wxTextCtrl* ctrl)
 {
     AddOptionDlg dlg(NULL, ctrl->GetValue());
-    if (dlg.ShowModal() == wxID_OK) {
+    if(dlg.ShowModal() == wxID_OK) {
         ctrl->SetValue(dlg.GetValue());
         return true;
     }
@@ -528,7 +555,7 @@ bool IProjectSettingsPage::PopupAddOptionDlg(wxTextCtrl* ctrl)
 bool IProjectSettingsPage::PopupAddOptionDlg(wxString& value)
 {
     AddOptionDlg dlg(NULL, value);
-    if (dlg.ShowModal() == wxID_OK) {
+    if(dlg.ShowModal() == wxID_OK) {
         value.Clear();
         value << dlg.GetValue();
         return true;
@@ -538,13 +565,13 @@ bool IProjectSettingsPage::PopupAddOptionDlg(wxString& value)
 
 bool IProjectSettingsPage::SelectChoiceWithGlobalSettings(wxChoice* c, const wxString& text)
 {
-    if (text == BuildConfig::APPEND_TO_GLOBAL_SETTINGS) {
+    if(text == BuildConfig::APPEND_TO_GLOBAL_SETTINGS) {
         c->Select(c->FindString(BuildConfig::APPEND_TO_GLOBAL_SETTINGS));
 
-    } else if (text == BuildConfig::OVERWRITE_GLOBAL_SETTINGS) {
+    } else if(text == BuildConfig::OVERWRITE_GLOBAL_SETTINGS) {
         c->Select(c->FindString(BuildConfig::OVERWRITE_GLOBAL_SETTINGS));
 
-    } else if (text == BuildConfig::PREPEND_GLOBAL_SETTINGS) {
+    } else if(text == BuildConfig::PREPEND_GLOBAL_SETTINGS) {
         c->Select(c->FindString(BuildConfig::PREPEND_GLOBAL_SETTINGS));
 
     } else {
@@ -554,20 +581,24 @@ bool IProjectSettingsPage::SelectChoiceWithGlobalSettings(wxChoice* c, const wxS
     return true;
 }
 
-bool IProjectSettingsPage::PopupAddOptionCheckDlg(wxTextCtrl *ctrl, const wxString& title, const Compiler::CmpCmdLineOptions& options)
+bool IProjectSettingsPage::PopupAddOptionCheckDlg(wxTextCtrl* ctrl,
+                                                  const wxString& title,
+                                                  const Compiler::CmpCmdLineOptions& options)
 {
     AddOptionCheckDlg dlg(NULL, title, options, ctrl->GetValue());
-    if (dlg.ShowModal() == wxID_OK) {
+    if(dlg.ShowModal() == wxID_OK) {
         ctrl->SetValue(dlg.GetValue());
         return true;
     }
     return false;
 }
 
-bool IProjectSettingsPage::PopupAddOptionCheckDlg(wxString& v, const wxString& title, const Compiler::CmpCmdLineOptions& options)
+bool IProjectSettingsPage::PopupAddOptionCheckDlg(wxString& v,
+                                                  const wxString& title,
+                                                  const Compiler::CmpCmdLineOptions& options)
 {
     AddOptionCheckDlg dlg(NULL, title, options, v);
-    if (dlg.ShowModal() == wxID_OK) {
+    if(dlg.ShowModal() == wxID_OK) {
         v = dlg.GetValue();
         return true;
     }
