@@ -44,13 +44,12 @@
 
 //---------------------------------------------------------
 
-TagsOptionsDlg::TagsOptionsDlg( wxWindow* parent, const TagsOptionsData& data)
-    : TagsOptionsBaseDlg( parent )
+TagsOptionsDlg::TagsOptionsDlg(wxWindow* parent, const TagsOptionsData& data)
+    : TagsOptionsBaseDlg(parent)
     , m_data(data)
 {
-    m_colour_flags = m_data.GetCcColourFlags();
     MSWSetNativeTheme(m_treebook2->GetTreeCtrl());
-
+    ::wxPGPropertyBooleanUseCheckbox(m_pgMgrColouring->GetGrid());
     Centre();
     GetSizer()->Fit(this);
     WindowAttrManager::Load(this, wxT("TagsOptionsDlgAttr"), NULL);
@@ -60,80 +59,48 @@ TagsOptionsDlg::TagsOptionsDlg( wxWindow* parent, const TagsOptionsData& data)
     //------------------------------------------------------------------
     // Display and behavior
     //------------------------------------------------------------------
-    m_checkDisplayFunctionTip->SetValue              (m_data.GetFlags() & CC_DISP_FUNC_CALLTIP ? true : false);
-    m_checkDisplayTypeInfo->SetValue                 (m_data.GetFlags() & CC_DISP_TYPE_INFO ? true : false);
-    m_checkCppKeywordAssist->SetValue                (m_data.GetFlags() & CC_CPP_KEYWORD_ASISST ? true : false);
-    m_checkDisableParseOnSave->SetValue              (m_data.GetFlags() & CC_DISABLE_AUTO_PARSING ? true : false);
-    m_checkBoxretagWorkspaceOnStartup->SetValue      (m_data.GetFlags() & CC_RETAG_WORKSPACE_ON_STARTUP ? true : false);
-    m_checkBoxDeepUsingNamespaceResolving->SetValue  (m_data.GetFlags() & CC_DEEP_SCAN_USING_NAMESPACE_RESOLVING ? true : false);
+    m_checkDisplayFunctionTip->SetValue(m_data.GetFlags() & CC_DISP_FUNC_CALLTIP ? true : false);
+    m_checkDisplayTypeInfo->SetValue(m_data.GetFlags() & CC_DISP_TYPE_INFO ? true : false);
+    m_checkCppKeywordAssist->SetValue(m_data.GetFlags() & CC_CPP_KEYWORD_ASISST ? true : false);
+    m_checkDisableParseOnSave->SetValue(m_data.GetFlags() & CC_DISABLE_AUTO_PARSING ? true : false);
+    m_checkBoxretagWorkspaceOnStartup->SetValue(m_data.GetFlags() & CC_RETAG_WORKSPACE_ON_STARTUP ? true : false);
+    m_checkBoxDeepUsingNamespaceResolving->SetValue(m_data.GetFlags() & CC_DEEP_SCAN_USING_NAMESPACE_RESOLVING ? true :
+                                                                                                                 false);
     m_checkBoxEnableCaseSensitiveCompletion->SetValue(m_data.GetFlags() & CC_IS_CASE_SENSITIVE ? true : false);
     m_checkBoxKeepFunctionSignature->SetValue(m_data.GetFlags() & CC_KEEP_FUNCTION_SIGNATURE_UNFORMATTED);
-    m_spinCtrlNumberOfCCItems->SetValue( ::wxIntToString( m_data.GetCcNumberOfDisplayItems()) );
+    m_spinCtrlNumberOfCCItems->SetValue(::wxIntToString(m_data.GetCcNumberOfDisplayItems()));
 
     //------------------------------------------------------------------
     // Colouring
     //------------------------------------------------------------------
-    m_checkColourLocalVars->SetValue     (m_data.GetFlags() & CC_COLOUR_VARS ? true : false);
-    m_checkColourProjTags->SetValue      (m_data.GetFlags() & CC_COLOUR_WORKSPACE_TAGS ? true : false);
-    m_checkBoxClass->SetValue            (m_data.GetCcColourFlags() & CC_COLOUR_CLASS);
-    m_checkBoxEnum->SetValue             (m_data.GetCcColourFlags() & CC_COLOUR_ENUM);
-    m_checkBoxFunction->SetValue         (m_data.GetCcColourFlags() & CC_COLOUR_FUNCTION);
-    m_checkBoxMacro->SetValue            (m_data.GetCcColourFlags() & CC_COLOUR_MACRO);
-    m_checkBoxNamespace->SetValue        (m_data.GetCcColourFlags() & CC_COLOUR_NAMESPACE);
-    m_checkBoxPrototype->SetValue        (m_data.GetCcColourFlags() & CC_COLOUR_PROTOTYPE);
-    m_checkBoxStruct->SetValue           (m_data.GetCcColourFlags() & CC_COLOUR_STRUCT);
-    m_checkBoxTypedef->SetValue          (m_data.GetCcColourFlags() & CC_COLOUR_TYPEDEF);
-    m_checkBoxUnion->SetValue            (m_data.GetCcColourFlags() & CC_COLOUR_UNION);
-    m_checkBoxEnumerator->SetValue       (m_data.GetCcColourFlags() & CC_COLOUR_ENUMERATOR);
-    m_checkBoxMember->SetValue           (m_data.GetCcColourFlags() & CC_COLOUR_MEMBER);
-    m_checkBoxVariable->SetValue         (m_data.GetCcColourFlags() & CC_COLOUR_VARIABLE);
-
-#if HAS_LIBCLANG
-    m_checkBoxColourMacroBlocks->SetValue(m_data.GetCcColourFlags() & CC_COLOUR_MACRO_BLOCKS);
-#else
-    m_checkBoxColourMacroBlocks->SetValue(false);
-    m_checkBoxColourMacroBlocks->Enable(false);
-#endif
-    m_spinCtrlMaxItemToColour->SetValue( wxString() << m_data.GetMaxItemToColour() );
-
-    // wxFB marks the checkboxes' labels to be localised. We really don't want e.g. "class" or "enum" translated
-    m_checkBoxClass->SetLabel(wxT("class"));
-    m_checkBoxEnum->SetLabel(wxT("enum"));
-    m_checkBoxFunction->SetLabel(wxT("function"));
-    m_checkBoxMacro->SetLabel(wxT("macro"));
-    m_checkBoxNamespace->SetLabel(wxT("namespace"));
-    m_checkBoxPrototype->SetLabel(wxT("prototype"));
-    m_checkBoxStruct->SetLabel(wxT("struct"));
-    m_checkBoxTypedef->SetLabel(wxT("typedef"));
-    m_checkBoxUnion->SetLabel(wxT("union"));
-    m_checkBoxEnumerator->SetLabel(wxT("enumerator"));
-    m_checkBoxMember->SetLabel(wxT("member"));
-    m_checkBoxVariable->SetLabel(wxT("variable"));
+    m_pgPropColourWorkspaceSymbols->SetValueFromInt(m_data.GetCcColourFlags());
+    m_pgPropColourLocalVariables->SetValue(m_data.GetFlags() & CC_COLOUR_VARS ? true : false);
+    m_pgPropTrackPreProcessors->SetValue(m_data.GetCcColourFlags() & CC_COLOUR_MACRO_BLOCKS ? true : false);
 
     //----------------------------------------------------
     // Triggering
     //----------------------------------------------------
-    m_checkWordAssist->SetValue            (m_data.GetFlags() & CC_WORD_ASSIST ? true : false);
+    m_checkWordAssist->SetValue(m_data.GetFlags() & CC_WORD_ASSIST ? true : false);
     m_checkAutoInsertSingleChoice->SetValue(m_data.GetFlags() & CC_AUTO_INSERT_SINGLE_CHOICE ? true : false);
-    m_sliderMinWordLen->SetValue           (m_data.GetMinWordLen() );
+    m_sliderMinWordLen->SetValue(m_data.GetMinWordLen());
 
     //----------------------------------------------------
     // CTags search paths
     //----------------------------------------------------
-    m_textCtrlCtagsSearchPaths->SetValue(wxImplode(m_data.GetParserSearchPaths(),   wxT("\n")));
+    m_textCtrlCtagsSearchPaths->SetValue(wxImplode(m_data.GetParserSearchPaths(), wxT("\n")));
     m_textCtrlCtagsExcludePaths->SetValue(wxImplode(m_data.GetParserExcludePaths(), wxT("\n")));
-    
+
     //----------------------------------------------------
     // CTags advanced page
     //----------------------------------------------------
-    m_textPrep->SetValue         (m_data.GetTokens());
-    m_textTypes->SetValue        (m_data.GetTypes());
+    m_textPrep->SetValue(m_data.GetTokens());
+    m_textTypes->SetValue(m_data.GetTypes());
     m_textCtrlFilesList->SetValue(m_data.GetMacrosFiles());
-    m_textFileSpec->SetValue     (m_data.GetFileSpec());
-    
-    //----------------------------------------------------
-    // Clang page
-    //----------------------------------------------------
+    m_textFileSpec->SetValue(m_data.GetFileSpec());
+
+//----------------------------------------------------
+// Clang page
+//----------------------------------------------------
 #if HAS_LIBCLANG
     m_checkBoxEnableClangCC->SetValue(m_data.GetClangOptions() & CC_CLANG_ENABLED);
 #else
@@ -161,7 +128,7 @@ TagsOptionsDlg::~TagsOptionsDlg()
     WindowAttrManager::Save(this, wxT("TagsOptionsDlgAttr"), NULL);
 }
 
-void TagsOptionsDlg::OnButtonOK(wxCommandEvent &event)
+void TagsOptionsDlg::OnButtonOK(wxCommandEvent& event)
 {
     wxUnusedVar(event);
     CopyData();
@@ -173,48 +140,35 @@ void TagsOptionsDlg::CopyData()
     //----------------------------------------------------
     // Display and behavior
     //----------------------------------------------------
-    SetFlag(CC_DISP_FUNC_CALLTIP,                   m_checkDisplayFunctionTip->IsChecked());
-    SetFlag(CC_DISP_TYPE_INFO,                      m_checkDisplayTypeInfo->IsChecked());
-    SetFlag(CC_CPP_KEYWORD_ASISST,                  m_checkCppKeywordAssist->IsChecked());
-    SetFlag(CC_RETAG_WORKSPACE_ON_STARTUP,          m_checkBoxretagWorkspaceOnStartup->IsChecked());
+    SetFlag(CC_DISP_FUNC_CALLTIP, m_checkDisplayFunctionTip->IsChecked());
+    SetFlag(CC_DISP_TYPE_INFO, m_checkDisplayTypeInfo->IsChecked());
+    SetFlag(CC_CPP_KEYWORD_ASISST, m_checkCppKeywordAssist->IsChecked());
+    SetFlag(CC_RETAG_WORKSPACE_ON_STARTUP, m_checkBoxretagWorkspaceOnStartup->IsChecked());
     SetFlag(CC_DEEP_SCAN_USING_NAMESPACE_RESOLVING, m_checkBoxDeepUsingNamespaceResolving->IsChecked());
-    SetFlag(CC_DISABLE_AUTO_PARSING,                m_checkDisableParseOnSave->IsChecked());
-    SetFlag(CC_IS_CASE_SENSITIVE,                   m_checkBoxEnableCaseSensitiveCompletion->IsChecked());
+    SetFlag(CC_DISABLE_AUTO_PARSING, m_checkDisableParseOnSave->IsChecked());
+    SetFlag(CC_IS_CASE_SENSITIVE, m_checkBoxEnableCaseSensitiveCompletion->IsChecked());
     SetFlag(CC_KEEP_FUNCTION_SIGNATURE_UNFORMATTED, m_checkBoxKeepFunctionSignature->IsChecked());
-    m_data.SetCcNumberOfDisplayItems( ::wxStringToInt(m_spinCtrlNumberOfCCItems->GetValue(), 100, 50));
+    m_data.SetCcNumberOfDisplayItems(::wxStringToInt(m_spinCtrlNumberOfCCItems->GetValue(), 100, 50));
 
     //----------------------------------------------------
     // Colouring
     //----------------------------------------------------
-    SetColouringFlag(CC_COLOUR_CLASS,        m_checkBoxClass->IsChecked());
-    SetColouringFlag(CC_COLOUR_ENUM,         m_checkBoxEnum->IsChecked());
-    SetColouringFlag(CC_COLOUR_FUNCTION,     m_checkBoxFunction->IsChecked());
-    SetColouringFlag(CC_COLOUR_MACRO,        m_checkBoxMacro->IsChecked());
-    SetColouringFlag(CC_COLOUR_NAMESPACE,    m_checkBoxNamespace->IsChecked());
-    SetColouringFlag(CC_COLOUR_PROTOTYPE,    m_checkBoxPrototype->IsChecked());
-    SetColouringFlag(CC_COLOUR_STRUCT,       m_checkBoxStruct->IsChecked());
-    SetColouringFlag(CC_COLOUR_TYPEDEF,      m_checkBoxTypedef->IsChecked());
-    SetColouringFlag(CC_COLOUR_UNION,        m_checkBoxUnion->IsChecked());
-    SetColouringFlag(CC_COLOUR_ENUMERATOR,   m_checkBoxEnumerator->IsChecked());
-    SetColouringFlag(CC_COLOUR_VARIABLE,     m_checkBoxVariable->IsChecked());
-    SetColouringFlag(CC_COLOUR_MEMBER,       m_checkBoxMember->IsChecked());
-    SetColouringFlag(CC_COLOUR_MACRO_BLOCKS, m_checkBoxColourMacroBlocks->IsChecked());
-    SetFlag(CC_COLOUR_VARS,                  m_checkColourLocalVars->IsChecked());
-    SetFlag(CC_COLOUR_WORKSPACE_TAGS,        m_checkColourProjTags->IsChecked());
-    m_data.SetMaxItemToColour( ::wxStringToInt(m_spinCtrlMaxItemToColour->GetValue(), 1000, 1000, 10000) );
+    // colouring is updated on the fly. See OnColouringPropertyValueChanged() function below
 
     //----------------------------------------------------
     // Triggering
     //----------------------------------------------------
     SetFlag(CC_AUTO_INSERT_SINGLE_CHOICE, m_checkAutoInsertSingleChoice->IsChecked());
-    SetFlag(CC_WORD_ASSIST,               m_checkWordAssist->IsChecked());
-    m_data.SetMinWordLen( m_sliderMinWordLen->GetValue() );
+    SetFlag(CC_WORD_ASSIST, m_checkWordAssist->IsChecked());
+    m_data.SetMinWordLen(m_sliderMinWordLen->GetValue());
 
     //----------------------------------------------------
     // CTags search paths
     //----------------------------------------------------
-    m_data.SetParserSearchPaths( ::wxStringTokenize(m_textCtrlCtagsSearchPaths->GetValue(), wxT("\r\n"), wxTOKEN_STRTOK) );
-    m_data.SetParserExcludePaths( ::wxStringTokenize(m_textCtrlCtagsExcludePaths->GetValue(), wxT("\r\n"), wxTOKEN_STRTOK) );
+    m_data.SetParserSearchPaths(
+        ::wxStringTokenize(m_textCtrlCtagsSearchPaths->GetValue(), wxT("\r\n"), wxTOKEN_STRTOK));
+    m_data.SetParserExcludePaths(
+        ::wxStringTokenize(m_textCtrlCtagsExcludePaths->GetValue(), wxT("\r\n"), wxTOKEN_STRTOK));
 
     //----------------------------------------------------
     // CTags advanced paths
@@ -222,17 +176,15 @@ void TagsOptionsDlg::CopyData()
     m_data.SetFileSpec(m_textFileSpec->GetValue());
     m_data.SetTokens(m_textPrep->GetValue());
     m_data.SetTypes(m_textTypes->GetValue());
-    m_data.SetMacrosFiles( m_textCtrlFilesList->GetValue() );
+    m_data.SetMacrosFiles(m_textCtrlFilesList->GetValue());
 
     //----------------------------------------------------
     // Clang
     //----------------------------------------------------
     size_t options(0);
-    if(m_checkBoxEnableClangCC->IsChecked())
-        options |= CC_CLANG_ENABLED;
+    if(m_checkBoxEnableClangCC->IsChecked()) options |= CC_CLANG_ENABLED;
 
-    if(m_checkBoxClangFirst->IsChecked())
-        options |= CC_CLANG_FIRST;
+    if(m_checkBoxClangFirst->IsChecked()) options |= CC_CLANG_FIRST;
 
     m_data.SetClangOptions(options);
     m_data.SetClangSearchPaths(m_textCtrlClangSearchPaths->GetValue());
@@ -241,7 +193,7 @@ void TagsOptionsDlg::CopyData()
 
 void TagsOptionsDlg::SetFlag(CodeCompletionOpts flag, bool set)
 {
-    if (set) {
+    if(set) {
         m_data.SetFlags(m_data.GetFlags() | flag);
     } else {
         m_data.SetFlags(m_data.GetFlags() & ~(flag));
@@ -250,7 +202,7 @@ void TagsOptionsDlg::SetFlag(CodeCompletionOpts flag, bool set)
 
 void TagsOptionsDlg::SetColouringFlag(CodeCompletionColourOpts flag, bool set)
 {
-    if (set) {
+    if(set) {
         m_data.SetCcColourFlags(m_data.GetCcColourFlags() | flag);
     } else {
         m_data.SetCcColourFlags(m_data.GetCcColourFlags() & ~(flag));
@@ -260,16 +212,15 @@ void TagsOptionsDlg::SetColouringFlag(CodeCompletionColourOpts flag, bool set)
 void TagsOptionsDlg::Parse()
 {
     // Prepate list of files to work on
-    wxArrayString files       = wxStringTokenize(m_textCtrlFilesList->GetValue(), wxT(" \t"), wxTOKEN_STRTOK);
+    wxArrayString files = wxStringTokenize(m_textCtrlFilesList->GetValue(), wxT(" \t"), wxTOKEN_STRTOK);
     wxArrayString searchPaths = GetCTagsSearchPaths();
     wxArrayString fullpathsArr;
 
-    for(size_t i=0; i<files.size(); i++) {
+    for(size_t i = 0; i < files.size(); i++) {
         wxString file = files[i].Trim().Trim(false);
-        if(file.IsEmpty())
-            continue;
+        if(file.IsEmpty()) continue;
 
-        for(size_t xx=0; xx<searchPaths.size(); xx++) {
+        for(size_t xx = 0; xx < searchPaths.size(); xx++) {
             wxString fullpath;
             fullpath << searchPaths.Item(xx) << wxFileName::GetPathSeparator() << file;
             wxFileName fn(fullpath);
@@ -282,13 +233,13 @@ void TagsOptionsDlg::Parse()
 
     // Clear the PreProcessor table
     PPTable::Instance()->Clear();
-    for(size_t i=0; i<fullpathsArr.size(); i++)
-        PPScan( fullpathsArr.Item(i), true );
+    for(size_t i = 0; i < fullpathsArr.size(); i++)
+        PPScan(fullpathsArr.Item(i), true);
 
     // Open an editor and print out the results
-    IEditor * editor = PluginManager::Get()->NewEditor();
+    IEditor* editor = PluginManager::Get()->NewEditor();
     if(editor) {
-        editor->AppendText( PPTable::Instance()->Export() );
+        editor->AppendText(PPTable::Instance()->Export());
         CopyData();
         EndModal(wxID_OK);
     }
@@ -297,7 +248,8 @@ void TagsOptionsDlg::Parse()
 void TagsOptionsDlg::OnAddExcludePath(wxCommandEvent& event)
 {
     wxUnusedVar(event);
-    wxString new_path = wxDirSelector(_("Add ctags Parser Exclude Path:"), wxT(""), wxDD_DEFAULT_STYLE, wxDefaultPosition, this);
+    wxString new_path =
+        wxDirSelector(_("Add ctags Parser Exclude Path:"), wxT(""), wxDD_DEFAULT_STYLE, wxDefaultPosition, this);
     if(new_path.IsEmpty() == false) {
         wxString currPathsStr = m_textCtrlCtagsExcludePaths->GetValue();
         wxArrayString currPaths = wxStringTokenize(currPathsStr, wxT("\n\r"), wxTOKEN_STRTOK);
@@ -315,19 +267,20 @@ void TagsOptionsDlg::OnAddExcludePath(wxCommandEvent& event)
 void TagsOptionsDlg::OnAddSearchPath(wxCommandEvent& event)
 {
     wxUnusedVar(event);
-    wxString new_path = wxDirSelector(_("Add ctags Parser Search Path:"), wxT(""), wxDD_DEFAULT_STYLE, wxDefaultPosition, this);
+    wxString new_path =
+        wxDirSelector(_("Add ctags Parser Search Path:"), wxT(""), wxDD_DEFAULT_STYLE, wxDefaultPosition, this);
     if(new_path.IsEmpty() == false) {
         wxString currPathsStr = m_textCtrlCtagsSearchPaths->GetValue();
         wxArrayString currPaths = wxStringTokenize(currPathsStr, wxT("\n\r"), wxTOKEN_STRTOK);
         if(currPaths.Index(new_path) == wxNOT_FOUND) {
-            
+
             currPathsStr.Trim().Trim(false);
             if(currPathsStr.IsEmpty() == false) {
                 currPathsStr << wxT("\n");
             }
             currPathsStr << new_path;
-            
-            m_textCtrlCtagsSearchPaths->ChangeValue( currPathsStr );
+
+            m_textCtrlCtagsSearchPaths->ChangeValue(currPathsStr);
         }
     }
 }
@@ -359,14 +312,9 @@ void TagsOptionsDlg::OnClearClangCacheUI(wxUpdateUIEvent& event)
 #endif
 }
 
-void TagsOptionsDlg::OnColourWorkspaceUI(wxUpdateUIEvent& event)
-{
-    event.Enable(m_checkColourProjTags->IsChecked());
-}
-
 void TagsOptionsDlg::OnFileSelectedUI(wxUpdateUIEvent& event)
 {
-    event.Enable( m_textCtrlFilesList->GetValue().IsEmpty() == false);
+    event.Enable(m_textCtrlFilesList->GetValue().IsEmpty() == false);
 }
 
 void TagsOptionsDlg::OnParse(wxCommandEvent& event)
@@ -402,23 +350,37 @@ void TagsOptionsDlg::DoSuggest(wxTextCtrl* textCtrl)
     CompilerPtr comp = BuildSettingsConfigST::Get()->GetDefaultCompiler(COMPILER_FAMILY_GCC);
 #endif
     wxArrayString paths;
-    if ( comp ) {
+    if(comp) {
         paths = comp->GetDefaultIncludePaths();
     }
-    
+
     wxString suggestedPaths;
-    for(size_t i=0; i<paths.GetCount(); i++) {
+    for(size_t i = 0; i < paths.GetCount(); i++) {
         suggestedPaths << paths.Item(i) << wxT("\n");
     }
-    
+
     suggestedPaths.Trim().Trim(false);
-    if ( !suggestedPaths.IsEmpty() ) {
-        if ( ::wxMessageBox(_("Accepting this suggestion will replace your old search paths with these paths\nContinue?"), 
-                            "CodeLite", 
-                            wxYES_NO|wxYES_DEFAULT|wxCANCEL|wxICON_QUESTION) != wxYES ) {
+    if(!suggestedPaths.IsEmpty()) {
+        if(::wxMessageBox(_("Accepting this suggestion will replace your old search paths with these paths\nContinue?"),
+                          "CodeLite",
+                          wxYES_NO | wxYES_DEFAULT | wxCANCEL | wxICON_QUESTION) != wxYES) {
             return;
         }
         textCtrl->Clear();
-        textCtrl->ChangeValue( suggestedPaths );
+        textCtrl->ChangeValue(suggestedPaths);
     }
 }
+void TagsOptionsDlg::OnColouringPropertyValueChanged(wxPropertyGridEvent& event)
+{
+    // Enable the local variables colouring feature
+    SetFlag(CC_COLOUR_VARS, m_pgPropColourLocalVariables->GetValue().GetBool());
+    
+    // if any of the types is selected, enable this feature
+    size_t ccColourFlags (0);
+    ccColourFlags = m_pgPropColourWorkspaceSymbols->GetValue().GetInteger();
+    m_data.SetCcColourFlags(ccColourFlags);
+    SetFlag(CC_COLOUR_WORKSPACE_TAGS, (ccColourFlags > 0));
+    
+    // Enable pre processor tracking (must come after we set the flags above)
+    SetColouringFlag(CC_COLOUR_MACRO_BLOCKS, m_pgPropTrackPreProcessors->GetValue().GetBool());
+}
