@@ -904,7 +904,11 @@ void BuilderGnuMake::CreateCleanTargets(ProjectPtr proj, const wxString& confToB
     text << wxT("clean:\n");
 
     wxString cwd = proj->GetFileName().GetPath();
-    if(OS_WINDOWS) {
+    if(!imd.IsEmpty()) {
+        // Remove the entire build folder
+        text << wxT("\t") << wxT("$(RM) -r ") << imd << "\n";
+        
+    } else if(OS_WINDOWS) {
         text << wxT("\t") << wxT("$(RM) ") << imd << "*$(ObjectSuffix)" << wxT("\n");
         text << wxT("\t") << wxT("$(RM) ") << imd << "*$(DependSuffix)" << wxT("\n");
         // delete the output file as well
@@ -944,7 +948,6 @@ void BuilderGnuMake::CreateCleanTargets(ProjectPtr proj, const wxString& confToB
             text << wxT("\t") << wxT("$(RM) ") << pchFile << wxT(".gch") << wxT("\n");
         }
     }
-
     text << wxT("\n\n");
 }
 
@@ -1178,13 +1181,11 @@ void BuilderGnuMake::CreateConfigsVariables(ProjectPtr proj, BuildConfigPtr bldC
     wxString outputFile = bldConf->GetOutputFileName();
     if(OS_WINDOWS && (bldConf->GetProjectType() == Project::EXECUTABLE || bldConf->GetProjectType().IsEmpty())) {
         outputFile.Trim().Trim(false);
-        // if(outputFile.EndsWith(wxT(".exe")) == false) {
-        //	outputFile.Append(wxT(".exe"));
-        //}
     }
 
     // Expand the build macros into the generated makefile
-    text << wxT("ProjectName            :=") << proj->GetName() << wxT("\n");
+    wxString projectName = proj->GetName();
+    text << wxT("ProjectName            :=") << projectName << wxT("\n");
     text << wxT("ConfigurationName      :=") << name << wxT("\n");
     text << wxT("WorkspacePath          := \"") << WorkspaceST::Get()->GetWorkspaceFileName().GetPath() << wxT("\"\n");
     text << wxT("ProjectPath            := \"") << proj->GetFileName().GetPath() << wxT("\"\n");
@@ -1548,7 +1549,7 @@ wxString BuilderGnuMake::GetPreprocessFileCmd(const wxString& project,
     CompilerPtr cmp = BuildSettingsConfigST::Get()->GetCompiler(cmpType);
 
     wxString objNamePrefix = DoGetTargetPrefix(fn, proj->GetFileName().GetPath(), cmp);
-    target << bldConf->GetIntermediateDirectory() << wxT("/") << objNamePrefix << fn.GetName()
+    target << bldConf->GetIntermediateDirectory() << wxT("/") << objNamePrefix << fn.GetFullName()
            << cmp->GetPreprocessSuffix();
 
     target = ExpandAllVariables(target, WorkspaceST::Get(), proj->GetName(), confToBuild, wxEmptyString);
