@@ -32,6 +32,10 @@
 #include <wx/dcclient.h>
 #include <wx/dcmemory.h>
 
+#ifdef __WXMSW__
+#   include <wx/msw/registry.h>
+#endif
+
 #ifdef __WXGTK20__
 // We need this ugly hack to workaround a gtk2-wxGTK name-clash^M
 // See http://trac.wxwidgets.org/ticket/10883^M
@@ -607,8 +611,8 @@ wxBrush DrawingUtils::GetStippleBrush()
     wxMemoryDC memDC;
     wxColour bgColour = GetAUIPaneBGColour();
     wxBitmap bmpStipple(3, 3);
-    wxColour lightPen = DrawingUtils::DarkColour(bgColour, 1.0);
-    wxColour darkPen  = DrawingUtils::LightColour(bgColour, 1.0);
+    wxColour lightPen = DrawingUtils::DarkColour(bgColour, 5.0);
+    wxColour darkPen  = DrawingUtils::LightColour(bgColour, 3.0);
     memDC.SelectObject(bmpStipple);
     memDC.SetBrush( bgColour );
     memDC.SetPen( bgColour );
@@ -637,3 +641,32 @@ wxColour DrawingUtils::GetThemeLinkColour()
         return "YELLOW";
     }
 }
+
+bool DrawingUtils::DrawStippleBackground(const wxRect& rect, wxDC& dc)
+{
+    // dark theme
+    dc.SetPen(*wxTRANSPARENT_PEN);
+    dc.SetBrush( GetStippleBrush() );
+    dc.DrawRectangle(rect);
+    return true;
+}
+
+wxColour DrawingUtils::GetCaptionColour()
+{
+#ifdef __WXMSW__
+    wxRegKey re(wxRegKey::HKCU, "Software\\Microsoft\\Windows\\DWM");
+    
+    unsigned long colVal = -1;
+    if(re.Exists() && re.QueryValue("ColorizationColor", (long*)&colVal)) {
+        // Colour format is: 0xAARRGGBB
+        int r = (colVal >> 16) & 0xff;
+        int g = (colVal >> 8) & 0xff;
+        int b = colVal & 0xff;
+        return wxColour(r, g, b);
+    } else {
+        return wxSystemSettings::GetColour(wxSYS_COLOUR_ACTIVECAPTION);
+    }
+#else
+    return wxSystemSettings::GetColour(wxSYS_COLOUR_ACTIVECAPTION);
+#endif
+}
