@@ -62,12 +62,7 @@ class WXDLLIMPEXP_SDK ProjectItem
 {
 public:
     // The visible items
-    enum {
-        TypeVirtualDirectory,
-        TypeProject,
-        TypeFile,
-        TypeWorkspace
-    };
+    enum { TypeVirtualDirectory, TypeProject, TypeFile, TypeWorkspace };
 
 public:
     wxString m_key;
@@ -79,23 +74,29 @@ public:
     //---------------------------------------------------------------
     // Constructors, destructor and assignment operator
     //---------------------------------------------------------------
-    ProjectItem(const wxString &key, const wxString &displayName, const wxString &file, int kind)
+    ProjectItem(const wxString& key, const wxString& displayName, const wxString& file, int kind)
         : m_key(key)
         , m_displayName(displayName)
         , m_file(file)
-        , m_kind(kind) {
+        , m_kind(kind)
+    {
     }
 
-    ProjectItem() : m_key(wxEmptyString), m_displayName(wxEmptyString), m_file(wxEmptyString), m_kind(TypeProject) {}
+    ProjectItem()
+        : m_key(wxEmptyString)
+        , m_displayName(wxEmptyString)
+        , m_file(wxEmptyString)
+        , m_kind(TypeProject)
+    {
+    }
 
     virtual ~ProjectItem() {}
 
-    ProjectItem(const ProjectItem& item) {
-        *this = item;
-    }
+    ProjectItem(const ProjectItem& item) { *this = item; }
 
-    ProjectItem &operator=(const ProjectItem &item) {
-        if (this == &item) {
+    ProjectItem& operator=(const ProjectItem& item)
+    {
+        if(this == &item) {
             return *this;
         }
 
@@ -109,31 +110,17 @@ public:
     //-----------------------------------------
     // Setters / Getters
     //-----------------------------------------
-    const wxString &GetDisplayName() const {
-        return m_displayName;
-    }
-    const wxString &GetFile() const {
-        return m_file;
-    }
-    int GetKind() const {
-        return m_kind;
-    }
+    const wxString& GetDisplayName() const { return m_displayName; }
+    const wxString& GetFile() const { return m_file; }
+    int GetKind() const { return m_kind; }
 
-    void SetDisplayName(const wxString &displayName) {
-        m_displayName = displayName;
-    }
-    void SetFile(const wxString &file) {
-        m_file = file;
-    }
-    void SetKind(int kind) {
-        m_kind = kind;
-    }
+    void SetDisplayName(const wxString& displayName) { m_displayName = displayName; }
+    void SetFile(const wxString& file) { m_file = file; }
+    void SetKind(int kind) { m_kind = kind; }
 
     //------------------------------------------
     // operations
-    const wxString& Key() const {
-        return m_key;
-    }
+    const wxString& Key() const { return m_key; }
 };
 
 // useful typedefs
@@ -144,8 +131,8 @@ typedef TreeNode<wxString, ProjectItem> ProjectTreeNode;
 class Project;
 class Workspace;
 
-typedef SmartPtr<Project>       ProjectPtr;
-typedef std::set<wxFileName>    FileNameSet_t;
+typedef SmartPtr<Project> ProjectPtr;
+typedef std::set<wxFileName> FileNameSet_t;
 typedef std::vector<wxFileName> FileNameVector_t;
 
 /**
@@ -180,77 +167,61 @@ public:
     friend class Workspace;
 
 private:
-    wxXmlDocument      m_doc;
-    wxFileName         m_fileName;
-    wxString           m_projectPath;
-    bool               m_tranActive;
-    bool               m_isModified;
-    NodeMap_t          m_vdCache;
-    time_t             m_modifyTime;
-    Workspace*         m_workspace;
+    wxXmlDocument m_doc;
+    wxFileName m_fileName;
+    wxString m_projectPath;
+    bool m_tranActive;
+    bool m_isModified;
+    NodeMap_t m_vdCache;
+    time_t m_modifyTime;
+    Workspace* m_workspace;
     ProjectSettingsPtr m_settings;
-    
+    wxString m_iconPath; /// Not serializable
+
 private:
     void DoUpdateProjectSettings();
-    wxArrayString DoGetCompilerOptions(bool cxxOptions, bool clearCache = false, bool noDefines = true, bool noIncludePaths = true);
-    
+    wxArrayString
+    DoGetCompilerOptions(bool cxxOptions, bool clearCache = false, bool noDefines = true, bool noIncludePaths = true);
+
 public:
     // -----------------------------------------
     // File meta data
     // -----------------------------------------
     class FileInfo
     {
-        wxString      m_filename;
-        wxString      m_virtualFolder;
-        wxString      m_filenameRelpath;
-        size_t        m_flags;
+        wxString m_filename;
+        wxString m_virtualFolder;
+        wxString m_filenameRelpath;
+        size_t m_flags;
         wxStringSet_t m_excludeConfigs;
 
     public:
-        FileInfo() : m_flags(0) {}
+        FileInfo()
+            : m_flags(0)
+        {
+        }
         ~FileInfo() {}
 
-        void SetExcludeConfigs(const wxStringSet_t& excludeConfigs) {
-            this->m_excludeConfigs = excludeConfigs;
-        }
-        void SetExcludeConfigs(const wxArrayString& excludeConfigs) {
+        void SetExcludeConfigs(const wxStringSet_t& excludeConfigs) { this->m_excludeConfigs = excludeConfigs; }
+        void SetExcludeConfigs(const wxArrayString& excludeConfigs)
+        {
             this->m_excludeConfigs.clear();
             this->m_excludeConfigs.insert(excludeConfigs.begin(), excludeConfigs.end());
         }
 
-        const wxStringSet_t& GetExcludeConfigs() const {
-            return m_excludeConfigs;
-        }
-        void SetFilenameRelpath(const wxString& filenameRelpath) {
-            this->m_filenameRelpath = filenameRelpath;
-        }
-        const wxString& GetFilenameRelpath() const {
-            return m_filenameRelpath;
-        }
-        void SetFilename(const wxString& filename) {
-            this->m_filename = filename;
-        }
-        void SetVirtualFolder(const wxString& virtualFolder) {
-            this->m_virtualFolder = virtualFolder;
-        }
-        const wxString& GetFilename() const {
-            return m_filename;
-        }
-        const wxString& GetVirtualFolder() const {
-            return m_virtualFolder;
-        }
-        void SetFlags(size_t flags) {
-            this->m_flags = flags;
-        }
-        size_t GetFlags() const {
-            return m_flags;
-        }
+        const wxStringSet_t& GetExcludeConfigs() const { return m_excludeConfigs; }
+        void SetFilenameRelpath(const wxString& filenameRelpath) { this->m_filenameRelpath = filenameRelpath; }
+        const wxString& GetFilenameRelpath() const { return m_filenameRelpath; }
+        void SetFilename(const wxString& filename) { this->m_filename = filename; }
+        void SetVirtualFolder(const wxString& virtualFolder) { this->m_virtualFolder = virtualFolder; }
+        const wxString& GetFilename() const { return m_filename; }
+        const wxString& GetVirtualFolder() const { return m_virtualFolder; }
+        void SetFlags(size_t flags) { this->m_flags = flags; }
+        size_t GetFlags() const { return m_flags; }
         /**
          * @brief return true if this file should be execluded from the build of a specific configuration
          */
-        bool IsExcludeFromConfiguration(const wxString &config) const {
-            return m_excludeConfigs.count(config);
-        }
+        bool IsExcludeFromConfiguration(const wxString& config) const { return m_excludeConfigs.count(config); }
     };
     typedef std::vector<Project::FileInfo> FileInfoVector_t;
 
@@ -261,35 +232,37 @@ public:
      */
     Workspace* GetWorkspace();
 
+    /**
+     * @brief a project was renamed - update our dependeices if needed
+     */
+    void ProjectRenamed(const wxString& oldname, const wxString& newname);
+    void SetIconPath(const wxString& iconPath) { this->m_iconPath = iconPath; }
+    const wxString& GetIconPath() const { return m_iconPath; }
     /**
      * @brief return set of compilers used by this project for the active build configuraion
      */
-    void GetCompilers(wxStringSet_t &compilers);
+    void GetCompilers(wxStringSet_t& compilers);
 
     /**
      * @brief replace compilers by name. compilers contains a map of the "olbd" compiler
      * name and the new compiler name
      */
-    void ReplaceCompilers(wxStringMap_t &compilers);
+    void ReplaceCompilers(wxStringMap_t& compilers);
 
     /**
      * @brief the const version of the above
      */
     const Workspace* GetWorkspace() const;
-    const wxFileName &GetFileName() const {
-        return m_fileName;
-    }
+    const wxFileName& GetFileName() const { return m_fileName; }
 
-    const wxString& GetProjectPath() const {
-        return m_projectPath;
-    }
+    const wxString& GetProjectPath() const { return m_projectPath; }
     /**
      * \brief copy this project and all the files under to new_path
      * \param file_name the new path of the project
      * \param new_name the new project name
      * \param description the new project description
      */
-    void CopyTo(const wxString &new_path, const wxString &new_name, const wxString &description);
+    void CopyTo(const wxString& new_path, const wxString& new_name, const wxString& description);
 
     /**
      * \brief copy files (and virtual directories) from src project to this project
@@ -311,7 +284,6 @@ public:
      */
     wxString GetName() const;
 
-
     /**
      * \brief return the project description as appears in the XML file
      * \return project description
@@ -326,7 +298,7 @@ public:
      * \param path
      * \return
      */
-    bool Load(const wxString &path);
+    bool Load(const wxString& path);
     /**
      * \brief Create new project
      * \param name project name
@@ -335,7 +307,7 @@ public:
      * \param projType project type: Project::STATIC_LIBRARY, Project::DYNAMIC_LIBRARY, Project::EXECUTABLE
      * \return true on success, false otherwise
      */
-    bool Create(const wxString &name, const wxString &description, const wxString &path, const wxString &projType);
+    bool Create(const wxString& name, const wxString& description, const wxString& path, const wxString& projType);
 
     /**
      * Add file to the project
@@ -344,7 +316,7 @@ public:
      *        and the file will be placed under it
      * \return
      */
-    bool AddFile(const wxString &fileName, const wxString &virtualDir = wxEmptyString);
+    bool AddFile(const wxString& fileName, const wxString& virtualDir = wxEmptyString);
 
     /**
      * Add file to the project - dont check for file duplication, this
@@ -353,7 +325,7 @@ public:
      *        and the file will be placed under it
      * \return true on success, false otherwise
      */
-    bool FastAddFile(const wxString &fileName, const wxString &virtualDir = wxEmptyString);
+    bool FastAddFile(const wxString& fileName, const wxString& virtualDir = wxEmptyString);
 
     /**
      * Remove file from the project
@@ -361,7 +333,7 @@ public:
      * \param virtualDir owner virtual directory
      * \return
      */
-    bool RemoveFile(const wxString &fileName, const wxString &virtualDir = wxEmptyString);
+    bool RemoveFile(const wxString& fileName, const wxString& virtualDir = wxEmptyString);
 
     /**
      * Rename file from the project
@@ -369,7 +341,7 @@ public:
      * \param virtualDir owner virtual directory
      * \return true on success, false otherwise
      */
-    bool RenameFile(const wxString &oldName, const wxString &virtualDir, const wxString &newName);
+    bool RenameFile(const wxString& oldName, const wxString& virtualDir, const wxString& newName);
 
     /**
      * \brief change the name of a virtual folder
@@ -377,40 +349,39 @@ public:
      * \param newName the new name *only* of the virtual folder (without the path)
      * \return true on success, false otherwise
      */
-    bool RenameVirtualDirectory(const wxString &oldVdPath, const wxString &newName);
+    bool RenameVirtualDirectory(const wxString& oldVdPath, const wxString& newName);
 
     /**
      * Create new virtual directory
      * \param vdFullPath VD path to add
      * \return
      */
-    bool CreateVirtualDir(const wxString &vdFullPath, bool mkpath = false);
+    bool CreateVirtualDir(const wxString& vdFullPath, bool mkpath = false);
 
     /**
      * remove a virtual directory
      * \param vdFullPath VD path to remove
      * \return
      */
-    bool DeleteVirtualDir(const wxString &vdFullPath);
+    bool DeleteVirtualDir(const wxString& vdFullPath);
 
     /**
      * Return list of files by a virtual directory
      * \param vdFullPath virtual directory
      * \param files [output] list of files under this vdFullPath. The files format are in absolute path!
      */
-    void GetFilesByVirtualDir(const wxString &vdFullPath, wxArrayString &files);
+    void GetFilesByVirtualDir(const wxString& vdFullPath, wxArrayString& files);
 
     /**
      * Save project settings
      */
     void Save();
 
-
     /**
      * Return list of files in this project
      * \param files
      */
-    void GetFiles(std::vector<wxFileName> &files, bool absPath = false);
+    void GetFiles(std::vector<wxFileName>& files, bool absPath = false);
 
     /**
      * Return list of files in this project as a wxString in blank separated format.
@@ -418,19 +389,18 @@ public:
      */
     wxString GetFiles(bool absPath = false);
 
-
     /**
      * @brief return the file meta data. The file names on the list
      * are in fullpath
      */
-    void GetFilesMetadata(Project::FileInfoVector_t &files) const;
+    void GetFilesMetadata(Project::FileInfoVector_t& files) const;
 
     /**
      * Return list of files in this project - in both absolute and relative path
      * \param files relative paths
      * \param absFiles absolute paths
      */
-    void GetFiles(std::vector<wxFileName> &files, std::vector<wxFileName> &absFiles);
+    void GetFiles(std::vector<wxFileName>& files, std::vector<wxFileName>& absFiles);
 
     /**
      * @brief return a filename set of all the project files (in absolute paths)
@@ -442,7 +412,7 @@ public:
      * \param files the set in which to return the paths
      * \param relativePath the path to which to make-relative
      */
-    //void GetFiles(wxStringSet_t& files, const wxString& relativePath);
+    // void GetFiles(wxStringSet_t& files, const wxString& relativePath);
 
     /**
      * Return a node pointing to any project-wide editor preferences
@@ -470,14 +440,24 @@ public:
     void SetGlobalSettings(BuildConfigCommonPtr settings);
 
     /**
-     * Get the project's file toplevel directory, extensions, ignorefiles, exclude paths and regexes for use when reconciling with filesystem reality
+     * Get the project's file toplevel directory, extensions, ignorefiles, exclude paths and regexes for use when
+     * reconciling with filesystem reality
      */
-    void GetReconciliationData(wxString& toplevelDir, wxString& extensions, wxArrayString& ignoreFiles, wxArrayString& excludePaths, wxArrayString& regexes);
+    void GetReconciliationData(wxString& toplevelDir,
+                               wxString& extensions,
+                               wxArrayString& ignoreFiles,
+                               wxArrayString& excludePaths,
+                               wxArrayString& regexes);
 
     /**
-     * Set the project's file toplevel directory, extensions, ignorefiles, exclude paths and regexes for use when reconciling with filesystem reality
+     * Set the project's file toplevel directory, extensions, ignorefiles, exclude paths and regexes for use when
+     * reconciling with filesystem reality
      */
-    void SetReconciliationData(const wxString& toplevelDir, const wxString& extensions, const wxArrayString& ignoreFiles, const wxArrayString& excludePaths, wxArrayString& regexes);
+    void SetReconciliationData(const wxString& toplevelDir,
+                               const wxString& extensions,
+                               const wxArrayString& ignoreFiles,
+                               const wxArrayString& excludePaths,
+                               wxArrayString& regexes);
     //-----------------------------------
     // visual operations
     //-----------------------------------
@@ -487,19 +467,19 @@ public:
      * \brief return the build order for a given configuration
      * \param configuration
      */
-    wxArrayString GetDependencies(const wxString &configuration) const;
+    wxArrayString GetDependencies(const wxString& configuration) const;
 
     /**
      * \brief set the dependencies for this project for a given configuration
      * \param deps
      * \param configuration
      */
-    void SetDependencies(wxArrayString &deps, const wxString &configuration);
+    void SetDependencies(wxArrayString& deps, const wxString& configuration);
 
     /**
      * Return true if a file already exist under the project
      */
-    bool IsFileExist(const wxString &fileName);
+    bool IsFileExist(const wxString& fileName);
 
     /**
      * \brief return true of the project was modified (in terms of files removed/added)
@@ -512,17 +492,11 @@ public:
     void SetModified(bool mod);
 
     // Transaction support to reduce overhead of disk writing
-    void BeginTranscation() {
-        m_tranActive = true;
-    }
-    void CommitTranscation() {
-        Save();
-    }
-    bool InTransaction() const {
-        return m_tranActive;
-    }
+    void BeginTranscation() { m_tranActive = true; }
+    void CommitTranscation() { Save(); }
+    bool InTransaction() const { return m_tranActive; }
 
-    wxString GetVDByFileName(const wxString &file);
+    wxString GetVDByFileName(const wxString& file);
 
     /**
      * \brief return Tree representation of all virtual folders of this project
@@ -536,7 +510,7 @@ public:
      * @param obj [output] container for the output
      * @return true on success.
      */
-    bool GetUserData(const wxString &name, SerializedObject *obj);
+    bool GetUserData(const wxString& name, SerializedObject* obj);
 
     /**
      * @brief save user data in the project settings
@@ -544,14 +518,14 @@ public:
      * @param obj the data
      * @return true on success.
      */
-    bool SetUserData(const wxString &name, SerializedObject *obj);
+    bool SetUserData(const wxString& name, SerializedObject* obj);
 
     /**
      * @brief set the project internal type (usually used to indicate internal types for the project
      * like 'GUI' or 'UnitTest++' etc.
      * @param internalType
      */
-    void SetProjectInternalType(const wxString &internalType);
+    void SetProjectInternalType(const wxString& internalType);
     /**
      * @brief return the project internal type
      * @return
@@ -567,29 +541,29 @@ public:
      * @param plugin plugin name
      * @return plugins data or wxEmptyString
      */
-    wxString GetPluginData(const wxString &pluginName);
+    wxString GetPluginData(const wxString& pluginName);
 
     /**
      * @brief set the plugin data. This data is copied when using 'save project as template' functionality
      * @param plugin the plugins' name
      * @param data the data
      */
-    void SetPluginData(const wxString &pluginName, const wxString &data, bool saveToXml = true);
+    void SetPluginData(const wxString& pluginName, const wxString& data, bool saveToXml = true);
 
     /**
      * @brief get all plugins data as map of plugin=value pair
      * @param pluginsDataMap [output]
      */
-    void GetAllPluginsData(std::map<wxString, wxString> &pluginsDataMap);
+    void GetAllPluginsData(std::map<wxString, wxString>& pluginsDataMap);
 
     /**
      * @brief set all plugins data as map of plugin=value pair
      * @param pluginsDataMap
      */
-    void SetAllPluginsData(const std::map<wxString, wxString> &pluginsDataMap, bool saveToFile = true);
+    void SetAllPluginsData(const std::map<wxString, wxString>& pluginsDataMap, bool saveToFile = true);
 
     //----------------------------------
-    //File modifications
+    // File modifications
     //----------------------------------
 
     /**
@@ -600,12 +574,8 @@ public:
     /**
      * return/set the last modification time that was made by the editor
      */
-    time_t GetProjectLastModifiedTime() const {
-        return m_modifyTime;
-    }
-    void SetProjectLastModifiedTime(time_t modificationTime) {
-        m_modifyTime = modificationTime;
-    }
+    time_t GetProjectLastModifiedTime() const { return m_modifyTime; }
+    void SetProjectLastModifiedTime(time_t modificationTime) { m_modifyTime = modificationTime; }
 
     wxString GetBestPathForVD(const wxString& vdPath);
 
@@ -615,30 +585,31 @@ public:
      * project settings
      */
     wxArrayString GetIncludePaths(bool clearCache = false);
-    
+
     /**
      * @brief return the pre-processors for this project.
      * The PreProcessors returned are from the build configuration
      * that matches the current workspace configuration
      */
     wxArrayString GetPreProcessors(bool clearCache = false);
-    
+
     /**
      * @brief return the compiler. Optionally ommit the defines/include paths
      */
     wxArrayString GetCXXCompilerOptions(bool clearCache = false, bool noDefines = true, bool noIncludePaths = true);
-    
+
     /**
      * @brief return the C compiler. Optionally ommit the defines/include paths
      */
     wxArrayString GetCCompilerOptions(bool clearCache = false, bool noDefines = true, bool noIncludePaths = true);
-    
+
     /**
      * @brief return the compilation line for a C++ file in the project. This function returns the same
-     * compilation line for all CXX or C files. So instead of hardcoding the file name it uses a placeholder for the file
+     * compilation line for all CXX or C files. So instead of hardcoding the file name it uses a placeholder for the
+     * file
      * name which can later be replaced by the caller with the actual file name
      */
-    wxString GetCompileLineForCXXFile(const wxString &filenamePlaceholder = "$FileName", bool cxxFile = true) const;
+    wxString GetCompileLineForCXXFile(const wxString& filenamePlaceholder = "$FileName", bool cxxFile = true) const;
 
     void ClearAllVirtDirs();
 
@@ -648,7 +619,7 @@ public:
      * @param virtualDirPath virtual folder path (a:b:c)
      * @param flags the flags to set
      */
-    void SetFileFlags(const wxString &fileName, const wxString &virtualDirPath, size_t flags);
+    void SetFileFlags(const wxString& fileName, const wxString& virtualDirPath, size_t flags);
 
     /**
      * @brief return the flags for a specific file in the project
@@ -656,61 +627,62 @@ public:
      * @param virtualDirPath virtual folder path (a:b:c)
      * @return the virtual flags of a file or if the file does not exists, return 0
      */
-    size_t GetFileFlags(const wxString &fileName, const wxString &virtualDirPath);
+    size_t GetFileFlags(const wxString& fileName, const wxString& virtualDirPath);
 
     /**
      * @brief return list of configurations for whom the current file is excluded from the build
      * @param fileName the fullpath of the file
      * @param virtualDirPath virtual folder path (a:b:c)
      */
-    wxArrayString GetExcludeConfigForFile(const wxString &filename, const wxString& virtualDirPath);
+    wxArrayString GetExcludeConfigForFile(const wxString& filename, const wxString& virtualDirPath);
 
     /**
      * @brief set the exclude config list for a file
      * @param fileName the fullpath of the file
      * @param virtualDirPath virtual folder path (a:b:c)
      */
-    void SetExcludeConfigForFile(const wxString &filename, const wxString& virtualDirPath, const wxArrayString& configs);
+    void
+    SetExcludeConfigForFile(const wxString& filename, const wxString& virtualDirPath, const wxArrayString& configs);
 
     /**
      * @brief add this project files into the 'compile_commands' json object
      */
-    void CreateCompileCommandsJSON( JSONElement &compile_commands );
+    void CreateCompileCommandsJSON(JSONElement& compile_commands);
 
     /**
      * @brief return the build configuration
      * @param configName configuration name. If non provided, returns the build configuration
      * that matches the current workspace configuration
      */
-    BuildConfigPtr GetBuildConfiguration(const wxString &configName = "");
+    BuildConfigPtr GetBuildConfiguration(const wxString& configName = "");
 
 private:
     /**
      * @brief associate this project with a workspace
      */
-    void AssociateToWorkspace( Workspace *workspace );
+    void AssociateToWorkspace(Workspace* workspace);
 
     wxString DoFormatVirtualFolderName(const wxXmlNode* node) const;
 
-    void DoDeleteVDFromCache(const wxString &vd);
-    wxArrayString DoBacktickToIncludePath(const wxString &backtick);
-    wxArrayString DoBacktickToPreProcessors(const wxString &backtick);
-    wxString DoExpandBacktick(const wxString &backtick) const;
+    void DoDeleteVDFromCache(const wxString& vd);
+    wxArrayString DoBacktickToIncludePath(const wxString& backtick);
+    wxArrayString DoBacktickToPreProcessors(const wxString& backtick);
+    wxString DoExpandBacktick(const wxString& backtick) const;
     void DoGetVirtualDirectories(wxXmlNode* parent, TreeNode<wxString, VisualWorkspaceNode>* tree);
-    wxXmlNode *FindFile(wxXmlNode* parent, const wxString &file);
+    wxXmlNode* FindFile(wxXmlNode* parent, const wxString& file);
 
     // Recursive helper function
-    void RecursiveAdd(wxXmlNode *xmlNode, ProjectTreePtr &ptp, ProjectTreeNode *nodeParent);
+    void RecursiveAdd(wxXmlNode* xmlNode, ProjectTreePtr& ptp, ProjectTreeNode* nodeParent);
 
     // Return the node representing a virtual dir by name
     // if no such virtual dir exist, create it.
-    wxXmlNode *GetVirtualDir(const wxString &vdFullPath);
+    wxXmlNode* GetVirtualDir(const wxString& vdFullPath);
 
     // Create virtual dir and return its xml node
-    wxXmlNode *CreateVD(const wxString &vdFullPath, bool mkpath = false);
+    wxXmlNode* CreateVD(const wxString& vdFullPath, bool mkpath = false);
 
-    void GetFiles(wxXmlNode *parent, std::vector<wxFileName> &files, bool absPath = false);
-    void GetFiles(wxXmlNode *parent, std::vector<wxFileName>& files, std::vector<wxFileName>& absFiles);
+    void GetFiles(wxXmlNode* parent, std::vector<wxFileName>& files, bool absPath = false);
+    void GetFiles(wxXmlNode* parent, std::vector<wxFileName>& files, std::vector<wxFileName>& absFiles);
     /**
      * Return list of projects that this projects depends on
      */
@@ -720,7 +692,7 @@ private:
      * @brief convert all the files paths to Unix format
      * @param parent
      */
-    void ConvertToUnixFormat(wxXmlNode *parent);
+    void ConvertToUnixFormat(wxXmlNode* parent);
 
     bool SaveXmlFile();
 };
@@ -728,12 +700,12 @@ private:
 class WXDLLIMPEXP_SDK ProjectData
 {
 public:
-    wxString m_name;            //< project name
-    wxString m_path;            //< project directoy
-    ProjectPtr m_srcProject;    //< source project
-    wxString m_cmpType;         //< Project compiler type
-    wxString m_debuggerType;    //< Selected debugger
-    wxString m_sourceTemplate;  //< The template selected by the user in the wizard
+    wxString m_name;           //< project name
+    wxString m_path;           //< project directoy
+    ProjectPtr m_srcProject;   //< source project
+    wxString m_cmpType;        //< Project compiler type
+    wxString m_debuggerType;   //< Selected debugger
+    wxString m_sourceTemplate; //< The template selected by the user in the wizard
 };
 
 //-----------------------------------------------------------------
@@ -750,19 +722,17 @@ public:
 class WXDLLIMPEXP_SDK FilewViewTreeItemData : public wxTreeItemData
 {
     ProjectItem m_item;
+
 public:
-    FilewViewTreeItemData(const ProjectItem &item) : m_item(item) { }
-    const ProjectItem &GetData() const {
-        return m_item;
+    FilewViewTreeItemData(const ProjectItem& item)
+        : m_item(item)
+    {
     }
+    const ProjectItem& GetData() const { return m_item; }
+    ProjectItem& GetData() { return m_item; }
+    void SetDisplayName(const wxString& displayName) { m_item.SetDisplayName(displayName); }
 
-    void SetDisplayName(const wxString &displayName) {
-        m_item.SetDisplayName(displayName);
-    }
-
-    void SetFile(const wxString &file) {
-        m_item.SetFile(file);
-    }
+    void SetFile(const wxString& file) { m_item.SetFile(file); }
 };
 
 #endif // PROJECT_H
