@@ -30,16 +30,12 @@
 #include <memory>
 #include "wx_xml_compatibility.h"
 
-//Session entry
-SessionEntry::SessionEntry()
-{
-}
+// Session entry
+SessionEntry::SessionEntry() {}
 
-SessionEntry::~SessionEntry()
-{
-}
+SessionEntry::~SessionEntry() {}
 
-void SessionEntry::DeSerialize(Archive &arch)
+void SessionEntry::DeSerialize(Archive& arch)
 {
     arch.Read(wxT("m_selectedTab"), m_selectedTab);
     arch.Read(wxT("m_tabs"), m_tabs);
@@ -47,8 +43,8 @@ void SessionEntry::DeSerialize(Archive &arch)
     arch.Read(wxT("TabInfoArray"), m_vTabInfoArr);
     arch.Read(wxT("m_breakpoints"), (SerializedObject*)&m_breakpoints);
     // initialize tab info array from m_tabs if in config file wasn't yet tab info array
-    if (m_vTabInfoArr.size() == 0 && m_tabs.GetCount() > 0) {
-        for (size_t i=0; i<m_tabs.GetCount(); i++) {
+    if(m_vTabInfoArr.size() == 0 && m_tabs.GetCount() > 0) {
+        for(size_t i = 0; i < m_tabs.GetCount(); i++) {
             TabInfo oTabInfo;
             oTabInfo.SetFileName(m_tabs.Item(i));
             oTabInfo.SetFirstVisibleLine(0);
@@ -58,55 +54,49 @@ void SessionEntry::DeSerialize(Archive &arch)
     }
 }
 
-void SessionEntry::Serialize(Archive &arch)
+void SessionEntry::Serialize(Archive& arch)
 {
     arch.Write(wxT("m_selectedTab"), m_selectedTab);
     // since tabs are saved in TabInfoArray we don't save tabs as string array,
     // there are only read due to read config saved in older version where wasn't TabInfoArray
-    //arch.Write(wxT("m_tabs"), m_tabs);
+    // arch.Write(wxT("m_tabs"), m_tabs);
     arch.Write(wxT("m_workspaceName"), m_workspaceName);
     arch.Write(wxT("TabInfoArray"), m_vTabInfoArr);
     arch.Write(wxT("m_breakpoints"), (SerializedObject*)&m_breakpoints);
 }
 
-
 //---------------------------------------------
 
-void TabGroupEntry::DeSerialize(Archive &arch)
+void TabGroupEntry::DeSerialize(Archive& arch)
 {
     arch.Read(wxT("m_TabgroupName"), m_tabgroupName);
     arch.Read(wxT("TabInfoArray"), m_vTabInfoArr);
 }
 
-void TabGroupEntry::Serialize(Archive &arch)
+void TabGroupEntry::Serialize(Archive& arch)
 {
     arch.Write(wxT("m_TabgroupName"), m_tabgroupName);
     arch.Write(wxT("TabInfoArray"), m_vTabInfoArr);
 }
 
-
 //---------------------------------------------
-SessionManager & SessionManager::Get()
+SessionManager& SessionManager::Get()
 {
     static SessionManager theManager;
     return theManager;
 }
 
-SessionManager::SessionManager()
-{
-}
+SessionManager::SessionManager() {}
 
-SessionManager::~SessionManager()
-{
-}
+SessionManager::~SessionManager() {}
 
-bool SessionManager::Load(const wxString &fileName)
+bool SessionManager::Load(const wxString& fileName)
 {
     m_fileName = wxFileName(fileName);
 
-    if (!m_fileName.FileExists()) {
-        //no such file or directory
-        //create an empty one
+    if(!m_fileName.FileExists()) {
+        // no such file or directory
+        // create an empty one
         wxFFile newFile(fileName, wxT("a+"));
         newFile.Write(wxT("<Sessions/>"));
         newFile.Close();
@@ -119,35 +109,35 @@ bool SessionManager::Load(const wxString &fileName)
 wxFileName SessionManager::GetSessionFileName(const wxString& name, const wxString& suffix /*=wxT("")*/) const
 {
     wxFileName sessionFileName(name);
-    if (suffix != "tabgroup") {
+    if(suffix != "tabgroup") {
         sessionFileName.AppendDir(".codelite");
     }
-    sessionFileName.SetExt( suffix.IsEmpty() ? wxString("session") : suffix);
+    sessionFileName.SetExt(suffix.IsEmpty() ? wxString("session") : suffix);
     return sessionFileName;
 }
 
-bool SessionManager::GetSession(const wxString& workspaceFile, SessionEntry& session, const wxString& suffix, const wxChar* Tag)
+bool SessionManager::GetSession(const wxString& workspaceFile,
+                                SessionEntry& session,
+                                const wxString& suffix,
+                                const wxChar* Tag)
 {
-    if (!m_doc.GetRoot()) {
+    if(!m_doc.GetRoot()) {
         return false;
     }
 
-    if (defaultSessionName == workspaceFile)
-        return false;
+    if(defaultSessionName == workspaceFile) return false;
 
     wxXmlDocument doc;
 
     const wxFileName& sessionFileName = GetSessionFileName(workspaceFile, suffix);
-    if (sessionFileName.FileExists()) {
-        if (!doc.Load(sessionFileName.GetFullPath()) || !doc.IsOk())
-            return false;
+    if(sessionFileName.FileExists()) {
+        if(!doc.Load(sessionFileName.GetFullPath()) || !doc.IsOk()) return false;
     } else {
         doc.SetRoot(new wxXmlNode(NULL, wxXML_ELEMENT_NODE, Tag));
     }
 
     wxXmlNode* const node = doc.GetRoot();
-    if (!node || node->GetName() != Tag)
-        return false;
+    if(!node || node->GetName() != Tag) return false;
 
     Archive arch;
     arch.SetXmlNode(node);
@@ -156,14 +146,16 @@ bool SessionManager::GetSession(const wxString& workspaceFile, SessionEntry& ses
     return true;
 }
 
-bool SessionManager::Save(const wxString &name, SessionEntry &session, const wxString& suffix /*=wxT("")*/, const wxChar* Tag /*=sessionTag*/)
+bool SessionManager::Save(const wxString& name,
+                          SessionEntry& session,
+                          const wxString& suffix /*=wxT("")*/,
+                          const wxChar* Tag /*=sessionTag*/)
 {
-    if (!m_doc.GetRoot()) {
+    if(!m_doc.GetRoot()) {
         return false;
     }
 
-    if (name.empty())
-        return false;
+    if(name.empty()) return false;
 
     std::auto_ptr<wxXmlNode> child(new wxXmlNode(NULL, wxXML_ELEMENT_NODE, Tag));
     child->AddProperty(wxT("Name"), name);
@@ -182,10 +174,13 @@ bool SessionManager::Save(const wxString &name, SessionEntry &session, const wxS
 
 void SessionManager::SetLastWorkspaceName(const wxString& name)
 {
+    if(!m_doc.GetRoot()) {
+        return;
+    }
     // first delete the old entry
-    wxXmlNode *node = m_doc.GetRoot()->GetChildren();
-    while (node) {
-        if (node->GetName() == wxT("LastActiveWorkspace")) {
+    wxXmlNode* node = m_doc.GetRoot()->GetChildren();
+    while(node) {
+        if(node->GetName() == wxT("LastActiveWorkspace")) {
             m_doc.GetRoot()->RemoveChild(node);
             delete node;
             break;
@@ -194,7 +189,7 @@ void SessionManager::SetLastWorkspaceName(const wxString& name)
     }
 
     // set new one
-    wxXmlNode *child = new wxXmlNode(NULL, wxXML_ELEMENT_NODE, wxT("LastActiveWorkspace"));
+    wxXmlNode* child = new wxXmlNode(NULL, wxXML_ELEMENT_NODE, wxT("LastActiveWorkspace"));
     m_doc.GetRoot()->AddChild(child);
     XmlUtils::SetNodeContent(child, name);
 
@@ -204,13 +199,16 @@ void SessionManager::SetLastWorkspaceName(const wxString& name)
 
 wxString SessionManager::GetLastSession()
 {
+    if(!m_doc.GetRoot()) {
+        return defaultSessionName;
+    }
     // try to locate the 'LastActiveWorkspace' entry
     // if it does not exist or it exist with value empty return 'Default'
     // otherwise, return its content
-    wxXmlNode *node = m_doc.GetRoot()->GetChildren();
-    while (node) {
-        if (node->GetName() == wxT("LastActiveWorkspace")) {
-            if (node->GetNodeContent().IsEmpty()) {
+    wxXmlNode* node = m_doc.GetRoot()->GetChildren();
+    while(node) {
+        if(node->GetName() == wxT("LastActiveWorkspace")) {
+            if(node->GetNodeContent().IsEmpty()) {
                 return defaultSessionName;
             } else {
                 return node->GetNodeContent();
