@@ -36,13 +36,14 @@
 #include <wx/regex.h>
 #include "cl_config.h"
 #include "macromanager.h"
+#include "clKeyboardManager.h"
 
 static AbbreviationPlugin* thePlugin = NULL;
 
-//Define the plugin entry point
-extern "C" EXPORT IPlugin *CreatePlugin(IManager *manager)
+// Define the plugin entry point
+extern "C" EXPORT IPlugin* CreatePlugin(IManager* manager)
 {
-    if (thePlugin == 0) {
+    if(thePlugin == 0) {
         thePlugin = new AbbreviationPlugin(manager);
     }
     return thePlugin;
@@ -52,60 +53,63 @@ extern "C" EXPORT PluginInfo GetPluginInfo()
 {
     PluginInfo info;
     info.SetAuthor(wxT("Eran Ifrah"));
-    info.SetName(wxT("abbreviation"));
+    info.SetName(wxT("Abbreviation"));
     info.SetDescription(_("Abbreviation plugin"));
     info.SetVersion(wxT("v1.0"));
     return info;
 }
 
-extern "C" EXPORT int GetPluginInterfaceVersion()
-{
-    return PLUGIN_INTERFACE_VERSION;
-}
+extern "C" EXPORT int GetPluginInterfaceVersion() { return PLUGIN_INTERFACE_VERSION; }
 
-AbbreviationPlugin::AbbreviationPlugin(IManager *manager)
+AbbreviationPlugin::AbbreviationPlugin(IManager* manager)
     : IPlugin(manager)
     , m_topWindow(NULL)
     , m_config("abbreviations.conf")
 {
     m_longName = _("Abbreviation plugin");
-    m_shortName = wxT("abbreviation");
+    m_shortName = wxT("Abbreviation");
     m_topWindow = m_mgr->GetTheApp();
-    EventNotifier::Get()->Connect(wxEVT_CCBOX_SELECTION_MADE, clCodeCompletionEventHandler(AbbreviationPlugin::OnAbbrevSelected), NULL, this);
+    EventNotifier::Get()->Connect(
+        wxEVT_CCBOX_SELECTION_MADE, clCodeCompletionEventHandler(AbbreviationPlugin::OnAbbrevSelected), NULL, this);
 
     InitDefaults();
 }
 
-AbbreviationPlugin::~AbbreviationPlugin()
-{
-}
+AbbreviationPlugin::~AbbreviationPlugin() {}
 
-clToolBar *AbbreviationPlugin::CreateToolBar(wxWindow *parent)
+clToolBar* AbbreviationPlugin::CreateToolBar(wxWindow* parent)
 {
     wxUnusedVar(parent);
     return NULL;
 }
 
-void AbbreviationPlugin::CreatePluginMenu(wxMenu *pluginsMenu)
+void AbbreviationPlugin::CreatePluginMenu(wxMenu* pluginsMenu)
 {
-    wxMenu *menu = new wxMenu();
-    wxMenuItem *item( NULL );
+    wxMenu* menu = new wxMenu();
+    wxMenuItem* item(NULL);
 
-    item = new wxMenuItem(menu, XRCID("abbrev_insert"), _( "Insert Expansion" ), _( "Insert Expansion" ), wxITEM_NORMAL );
-    menu->Append( item );
+    item = new wxMenuItem(menu, XRCID("abbrev_insert"), _("Insert Expansion"), _("Insert Expansion"), wxITEM_NORMAL);
+    menu->Append(item);
 
     menu->AppendSeparator();
-    item = new wxMenuItem(menu, XRCID("abbrev_settings"), _( "Settings..." ), _( "Settings..." ), wxITEM_NORMAL );
-    menu->Append( item );
-
+    item = new wxMenuItem(menu, XRCID("abbrev_settings"), _("Settings..."), _("Settings..."), wxITEM_NORMAL);
+    menu->Append(item);
 
     pluginsMenu->Append(wxID_ANY, wxT("Abbreviation"), menu);
 
-    m_topWindow->Connect( XRCID("abbrev_settings"), wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( AbbreviationPlugin::OnSettings ), NULL, this );
-    m_topWindow->Connect( XRCID("abbrev_insert"), wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( AbbreviationPlugin::OnAbbreviations), NULL, this );
+    m_topWindow->Connect(XRCID("abbrev_settings"),
+                         wxEVT_COMMAND_MENU_SELECTED,
+                         wxCommandEventHandler(AbbreviationPlugin::OnSettings),
+                         NULL,
+                         this);
+    m_topWindow->Connect(XRCID("abbrev_insert"),
+                         wxEVT_COMMAND_MENU_SELECTED,
+                         wxCommandEventHandler(AbbreviationPlugin::OnAbbreviations),
+                         NULL,
+                         this);
 }
 
-void AbbreviationPlugin::HookPopupMenu(wxMenu *menu, MenuType type)
+void AbbreviationPlugin::HookPopupMenu(wxMenu* menu, MenuType type)
 {
     wxUnusedVar(menu);
     wxUnusedVar(type);
@@ -113,9 +117,18 @@ void AbbreviationPlugin::HookPopupMenu(wxMenu *menu, MenuType type)
 
 void AbbreviationPlugin::UnPlug()
 {
-    EventNotifier::Get()->Disconnect(wxEVT_CCBOX_SELECTION_MADE, clCodeCompletionEventHandler(AbbreviationPlugin::OnAbbrevSelected), NULL, this);
-    m_topWindow->Disconnect( XRCID("abbrev_settings"), wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( AbbreviationPlugin::OnSettings ), NULL, this );
-    m_topWindow->Disconnect( XRCID("abbrev_insert"), wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( AbbreviationPlugin::OnAbbreviations), NULL, this );
+    EventNotifier::Get()->Disconnect(
+        wxEVT_CCBOX_SELECTION_MADE, clCodeCompletionEventHandler(AbbreviationPlugin::OnAbbrevSelected), NULL, this);
+    m_topWindow->Disconnect(XRCID("abbrev_settings"),
+                            wxEVT_COMMAND_MENU_SELECTED,
+                            wxCommandEventHandler(AbbreviationPlugin::OnSettings),
+                            NULL,
+                            this);
+    m_topWindow->Disconnect(XRCID("abbrev_insert"),
+                            wxEVT_COMMAND_MENU_SELECTED,
+                            wxCommandEventHandler(AbbreviationPlugin::OnAbbreviations),
+                            NULL,
+                            this);
 }
 
 void AbbreviationPlugin::OnSettings(wxCommandEvent& e)
@@ -127,39 +140,39 @@ void AbbreviationPlugin::OnSettings(wxCommandEvent& e)
 
 void AbbreviationPlugin::OnAbbreviations(wxCommandEvent& e)
 {
-    IEditor *editor = m_mgr->GetActiveEditor();
-    if (!editor) {
+    IEditor* editor = m_mgr->GetActiveEditor();
+    if(!editor) {
         return;
     }
 
     AbbreviationJSONEntry jsonData;
-    if ( !m_config.ReadItem( &jsonData ) ) {
+    if(!m_config.ReadItem(&jsonData)) {
         // merge the data from the old configuration
         AbbreviationEntry data;
         m_mgr->GetConfigTool()->ReadObject(wxT("AbbreviationsData"), &data);
-    
-        jsonData.SetAutoInsert( data.GetAutoInsert() );
-        jsonData.SetEntries( data.GetEntries() );
-        m_config.WriteItem( &jsonData );
+
+        jsonData.SetAutoInsert(data.GetAutoInsert());
+        jsonData.SetEntries(data.GetEntries());
+        m_config.WriteItem(&jsonData);
     }
-    
+
     wxString wordAtCaret = editor->GetWordAtCaret();
-    
+
     bool autoInsert = (jsonData.IsAutoInsert() && wordAtCaret.IsEmpty() == false);
-    if  ( autoInsert ){
+    if(autoInsert) {
         autoInsert = InsertExpansion(wordAtCaret);
     }
-    
-    if ( !autoInsert ) {
-        static wxBitmap bmp = LoadBitmapFile(wxT("abbrev.png")) ;
-        if (bmp.IsOk()) {
+
+    if(!autoInsert) {
+        static wxBitmap bmp = LoadBitmapFile(wxT("abbrev.png"));
+        if(bmp.IsOk()) {
             editor->RegisterImageForKind(wxT("Abbreviation"), bmp);
             std::vector<TagEntryPtr> tags;
 
             // search for the old item
             const JSONElement::wxStringMap_t& entries = jsonData.GetEntries();
             JSONElement::wxStringMap_t::const_iterator iter = entries.begin();
-            for (; iter != entries.end(); ++iter) {
+            for(; iter != entries.end(); ++iter) {
                 TagEntryPtr t(new TagEntry());
                 t->SetName(iter->first);
                 t->SetKind(wxT("Abbreviation"));
@@ -178,93 +191,94 @@ void AbbreviationPlugin::OnAbbrevSelected(clCodeCompletionEvent& e)
     }
 
     wxString wordAtCaret = e.GetWord();
-    InsertExpansion( wordAtCaret );
+    InsertExpansion(wordAtCaret);
 }
 
 void AbbreviationPlugin::InitDefaults()
 {
     // check to see if there are any abbreviations configured
     AbbreviationJSONEntry jsonData;
-    if ( !m_config.ReadItem(&jsonData) ) {
+    if(!m_config.ReadItem(&jsonData)) {
         // merge the data from the old configuration
         AbbreviationEntry data;
         m_mgr->GetConfigTool()->ReadObject(wxT("AbbreviationsData"), &data);
-    
-        jsonData.SetAutoInsert( data.GetAutoInsert() );
-        jsonData.SetEntries( data.GetEntries() );
-        m_config.WriteItem( &jsonData );
+
+        jsonData.SetAutoInsert(data.GetAutoInsert());
+        jsonData.SetEntries(data.GetEntries());
+        m_config.WriteItem(&jsonData);
     }
 
     // search for the old item
-    if (jsonData.GetEntries().empty()) {
+    if(jsonData.GetEntries().empty()) {
         // fill some default abbreviations
         JSONElement::wxStringMap_t entries;
         entries[wxT("main")] = wxT("int main(int argc, char **argv) {\n    |\n}\n");
-        entries[wxT("while")] = wxT("while ( | ) {\n    \n}\n");
-        entries[wxT("dowhile")] = wxT("do {\n    \n} while ( | );\n");
-        entries[wxT("for_size")] = wxT("for ( size_t i=0; i<|; ++i ) {    \n}\n");
-        entries[wxT("for_int")] = wxT("for ( int i=0; i<|; ++i ) {    \n}\n");
+        entries[wxT("while")] = wxT("while(|) {\n    \n}\n");
+        entries[wxT("dowhile")] = wxT("do {\n    \n} while( | );\n");
+        entries[wxT("for_size")] = wxT("for(size_t i=0; i<|; ++i) {\n}\n");
+        entries[wxT("for_int")] = wxT("for(int i=0; i<|; ++i) {\n}\n");
         jsonData.SetEntries(entries);
-        m_config.WriteItem( &jsonData );
+        m_config.WriteItem(&jsonData);
     }
+    clKeyboardManager::Get()->AddGlobalAccelerator(
+        "abbrev_insert", "Ctrl-Alt-SPACE", _("Plugins::Abbreviations::Show abbrevations completion box"));
 }
 
 bool AbbreviationPlugin::InsertExpansion(const wxString& abbreviation)
 {
     // get the active editor
-    IEditor *editor = m_mgr->GetActiveEditor();
+    IEditor* editor = m_mgr->GetActiveEditor();
 
-    if (!editor || !abbreviation)
-        return false;
+    if(!editor || !abbreviation) return false;
 
     // hide the completion box
-    if (editor->IsCompletionBoxShown()) {
+    if(editor->IsCompletionBoxShown()) {
         editor->HideCompletionBox();
     }
 
     // search for abbreviation that matches str
     // prepate list of abbreviations
     AbbreviationJSONEntry jsonData;
-    if ( !m_config.ReadItem(&jsonData) ) {
+    if(!m_config.ReadItem(&jsonData)) {
         // merge the data from the old configuration
         AbbreviationEntry data;
         m_mgr->GetConfigTool()->ReadObject(wxT("AbbreviationsData"), &data);
-    
-        jsonData.SetAutoInsert( data.GetAutoInsert() );
-        jsonData.SetEntries( data.GetEntries() );
-        m_config.WriteItem( &jsonData );
+
+        jsonData.SetAutoInsert(data.GetAutoInsert());
+        jsonData.SetEntries(data.GetEntries());
+        m_config.WriteItem(&jsonData);
     }
 
     // search for the old item
     const JSONElement::wxStringMap_t& entries = jsonData.GetEntries();
     JSONElement::wxStringMap_t::const_iterator iter = entries.find(abbreviation);
 
-    if (iter != entries.end()) {
+    if(iter != entries.end()) {
 
         wxString text = iter->second;
         int selStart = editor->WordStartPos(editor->GetCurrentPosition(), true);
-        int selEnd   = editor->WordEndPos(editor->GetCurrentPosition(), true);
-        int curPos   = editor->GetCurrentPosition();
-        int typedWordLen = curPos - selStart;    
+        int selEnd = editor->WordEndPos(editor->GetCurrentPosition(), true);
+        int curPos = editor->GetCurrentPosition();
+        int typedWordLen = curPos - selStart;
 
-        if (typedWordLen < 0) {
+        if(typedWordLen < 0) {
             typedWordLen = 0;
         }
 
         // format the text to insert
         bool appendEol(false);
-        if (text.EndsWith(wxT("\r")) || text.EndsWith(wxT("\n"))) {
+        if(text.EndsWith(wxT("\r")) || text.EndsWith(wxT("\n"))) {
             appendEol = true;
-        }            
+        }
 
-        text = editor->FormatTextKeepIndent(text, selStart, Format_Text_Save_Empty_Lines);    
+        text = editor->FormatTextKeepIndent(text, selStart, Format_Text_Save_Empty_Lines);
 
         // remove the first line indenation that might have been placed by CL
         text.Trim(false).Trim();
 
-        if (appendEol) {
+        if(appendEol) {
             wxString eol;
-            switch (editor->GetEOL()) {
+            switch(editor->GetEOL()) {
             case 1:
                 eol = wxT("\r");
                 break;
@@ -283,17 +297,17 @@ bool AbbreviationPlugin::InsertExpansion(const wxString& abbreviation)
         //--------------------------------------------
         wxString project;
         text = MacroManager::Instance()->Expand(text, m_mgr, editor->GetProjectName());
-        
+
         // locate the caret
         int where = text.Find(wxT("|"));
-        if (where == wxNOT_FOUND) {
+        if(where == wxNOT_FOUND) {
             where = text.length();
         }
 
         // remove the pipe (|) character
         text.Replace(wxT("|"), wxT(""));
 
-        if (selEnd - selStart >= 0) {
+        if(selEnd - selStart >= 0) {
             editor->SelectText(selStart, selEnd - selStart);
             editor->ReplaceSelection(text);
             editor->SetCaretAt(curPos + where - typedWordLen);
